/* ------------------------------------------------------------- */
/* li.h, li.cc                                                   */
/* version 0.9                                                   */
/* Stefan Bauberger (bauberger@physik.uni-wuerzburg.de)          */
/* last revision 4.12.95                                         */
/* -> small changes by A. Freitas 29.1.02			 */
/* ------------------------------------------------------------- */
/* Calculation of poly-logarithms Li_2 and Li_3 for real or      */
/* complex values with simple taylor series                      */
/* adapted for use with double or quad-precision                 */ 
/* ------------------------------------------------------------- */

// Li_2: li2(Cplx x), li2(Double x)=li2(x-I*eps), li2c(Double x)=li2(x+I*eps)
// Li_3: li3(Cplx x), li3(Double x)=li3(x-I*eps), li3c(Double x)=li3(x+I*eps)

#include "li.h"

#define MIN_EVAL 6   // ??

#ifdef QUADPRECISION
#define MINERROR 1e-30
static Double NUMUNIT=Double(1.)+Double(1e-32);
#define MINNUMBER 1e-31
#else
#define MINERROR 1e-15
static Double NUMUNIT=1.+1e-16;
#define MINNUMBER 5e-16
#endif

static Cplx series(Cplx x,Cplx *data,Double error)
  // only for well behaved series!
  // data: 0. element: point the series is about
  //       1. element: number of coefficients
  //       2. element: convergence constant = approximation for a_{n+1}/a_n
  // error: relative error requested
{
  Cplx dx=x-data[0],r=data[3]+dx*data[4],xn=dx,inc1=Cplx(0),inc2=Cplx(0);
  if (dx==0) return(r);
  Double rerror=2*abs(r*error*(1-data[2]*dx)/(data[2]*dx));
  Double maxpoint=abs(data[1]);
  int i;
  for (i=2; ( (i<=maxpoint)
              &&((i<MIN_EVAL)||(abs(inc1+inc2)>rerror))); i++) {
    xn*=dx;
    inc2=inc1;
    inc1=data[i+3]*xn;
    r+=inc1; };
  if (i>maxpoint-.5)
    cerr << "Warning: precision of series calculation may be insufficient!\n"; 
  return(r);
}

static Cplx multiseries(Cplx x, Cplx **multidata, int datacount, Double error)
  // choose the best series out of multidata
{
  int bestseries=0;
  Cplx dx=x-multidata[bestseries][0];
  Double bestconv=abs(multidata[bestseries][2]*dx
                   /(1-multidata[bestseries][2]*dx));
  Double conv;
  for (int i=1; i<datacount; i++) {
    dx=x-multidata[i][0];
    conv=abs(multidata[i][2]*dx
             /(1-multidata[i][2]*dx));
    if (conv < bestconv) { bestconv=conv; bestseries=i; };
  };
  return(series(x,multidata[bestseries],error));
}

static Cplx multiseries(Cplx x, Cplx **multidata, int datacount)
{
  return(multiseries(x,multidata,datacount,MINERROR));
}

static Double series(Double x,Double *data,Double error)
  // only for well behaved series!
  // data: 0. element: point the series is about
  //       1. element: number of coefficients
  //       2. element: convergence constant = approximation for a_{n+1}/a_n
  // error: relative error requested
{
  Double dx=x-data[0],r=data[3]+dx*data[4],xn=dx,inc1=0,inc2=0;
  if (dx==0) return(r);
  Double rerror=2*fabs(r*error*(1-data[2]*dx)/(data[2]*dx));
  Double maxpoint=fabs(data[1]);
  int i;
  for (i=2; ( (i<=maxpoint)
               &&((i<MIN_EVAL)||(fabs(inc1+inc2)>rerror))); i++) {
    xn*=dx;
    inc2=inc1;
    inc1=data[i+3]*xn;
    r+=inc1; };
  if (i>maxpoint-.5)
    cerr << "Warning: precision of series calculation may be insufficient!\n"; 
  return(r);
}

static Double multiseries(Double x, Double **multidata, int datacount, Double error)
  // choose the best series out of multidata
{
  int bestseries=0;
  Double dx=x-multidata[bestseries][0];
  Double bestconv=fabs(multidata[bestseries][2]*dx
                   /(1-multidata[bestseries][2]*dx));
  Double conv;
  for (int i=1; i<datacount; i++) {
    dx=x-multidata[i][0];
    conv=fabs(multidata[i][2]*dx
             /(1-multidata[i][2]*dx));
    if (conv < bestconv) { bestconv=conv; bestseries=i; };
  };
  return(series(x,multidata[bestseries],error));
}

static Double multiseries(Double x, Double **multidata, int datacount)
{
  return(multiseries(x,multidata,datacount,MINERROR));
}

// these are the series for an evaluation of li2 and li3:

static Cplx li2s1[64] = {
    SCplx("-1.",
          "0"),
    SCplx("60.",
          "0"),
    SCplx("0.450498187509539899844359424303392",
          "0"),
    SCplx("-0.822467033424113218236207583323013",
          "0"),
    SCplx("0.693147180559945309417232121458177",
          "0"),
    SCplx("0.0965735902799726547086160607290883",
          "0"),
    SCplx("0.02271572685331510313907737381939219",
          "0"),
    SCplx("0.00662012847331966068764136369787748",
          "0"),
    SCplx("0.00217110277865572855011309095830198",
          "0"),
    SCplx("0.000767585648879773791760909131918317",
          "0"),
    SCplx("0.0002859067466588537262712554464061764",
          "0"),
    SCplx("0.0001106594747550684390587770870339758",
          "0"),
    SCplx("0.0000441105053378386124966907440302007",
          "0"),
    SCplx("0.00001799806591516586235813278073829173",
          "0"),
    SCplx("7.48403719560532941648434612571975e-6",
          "0"),
    SCplx("3.161267050517006510565196069788561e-6",
          "0"),
    SCplx("1.353088655605441907188386115702262e-6",
          "0"),
    SCplx("5.85723463172086166565039854690562e-7",
          "0"),
    SCplx("2.560316311034708983178467215207148e-7",
          "0"),
    SCplx("1.128730786386706338396479680923368e-7",
          "0"),
    SCplx("5.01349965772047142020216170280817e-8",
          "0"),
    SCplx("2.241705712275216472020995856573726e-8",
          "0"),
    SCplx("1.008312643902544260043282624356396e-8",
          "0"),
    SCplx("4.55963160967285468093750072085944e-9",
          "0"),
    SCplx("2.071853160625933029464286400818519e-9",
          "0"),
    SCplx("9.45562955915392783536256066582179e-10",
          "0"),
    SCplx("4.33268560398196852236260743529199e-10",
          "0"),
    SCplx("1.992568458330885594800397342879461e-10",
          "0"),
    SCplx("9.19454973741139754341714782497616e-11",
          "0"),
    SCplx("4.25594053401937263790110367786169e-11",
          "0"),
    SCplx("1.975640572097336578662601262442309e-11",
          "0"),
    SCplx("9.1955544625208406527121206391593e-12",
          "0"),
    SCplx("4.29067044353993227737229381908977e-12",
          "0"),
    SCplx("2.006676659524282774735746094085627e-12",
          "0"),
    SCplx("9.40523031135888152298033854491467e-13",
          "0"),
    SCplx("4.41715066142993202163216264280544e-13",
          "0"),
    SCplx("2.078461970421926232091699380902249e-13",
          "0"),
    SCplx("9.79761022745213477911417670055748e-14",
          "0"),
    SCplx("4.62627842990582107731070442507937e-14",
          "0"),
    SCplx("2.187942881715286078077371365652563e-14",
          "0"),
    SCplx("1.036323162061805988381539632046337e-14",
          "0"),
    SCplx("4.91558070728499152035772764062187e-15",
          "0"),
    SCplx("2.334763653325111203600811378581638e-15",
          "0"),
    SCplx("1.110375713565152349260741013988892e-15",
          "0"),
    SCplx("5.28723438982509463964723512123309e-16",
          "0"),
    SCplx("2.520538618136668350564347808532419e-16",
          "0"),
    SCplx("1.202930990011496332008810563677291e-16",
          "0"),
    SCplx("5.74709843189797262415693395409255e-17",
          "0"),
    SCplx("2.748505392966501774443853532574837e-17",
          "0"),
    SCplx("1.315725834645780362204978904904128e-17",
          "0"),
    SCplx("6.30430339773483290787921751906052e-18",
          "0"),
    SCplx("3.023394879430515972869658166588405e-18",
          "0"),
    SCplx("1.451185426618795864003431580752151e-18",
          "0"),
    SCplx("6.97118110167950369303848390383919e-19",
          "0"),
    SCplx("3.35143864988137525851261035877311e-19",
          "0"),
    SCplx("1.612443374751444527034982228810545e-19",
          "0"),
    SCplx("7.76342828765454615477260018331667e-20",
          "0"),
    SCplx("3.74047512710344330696013879595678e-20",
          "0"),
    SCplx("1.803404157410053192248352319379083e-20",
          "0"),
    SCplx("8.70045459286532323211748894770999e-21",
          "0"),
    SCplx("4.20013715395087622200032878724413e-21",
          "0"),
    SCplx("2.02884201732582228301009386091608e-21",
          "0"),
    SCplx("9.80589595070266502402719691799497e-22",
          "0"),
    SCplx("4.74211554932991695042921685243543e-22",
          "0") };

static Cplx li2s2[64] = {
    SCplx("-0.5",
          "0"),
    SCplx("60.",
          "0"),
    SCplx("0.600546184524101630412111535537401",
          "0"),
    SCplx("-0.448414206923646202443064405915774",
          "0"),
    SCplx("0.810930216216328763956026230928698",
          "0"),
    SCplx("0.1442635495496620972893595642620316",
          "0"),
    SCplx("0.044203251251401314904331270867894",
          "0"),
    SCplx("0.01692216082771925630711419025245827",
          "0"),
    SCplx("0.00732237090459772367162961798418015",
          "0"),
    SCplx("0.00342480198777261215504799156485444",
          "0"),
    SCplx("0.001690541731471972917700665662554046",
          "0"),
    SCplx("0.000868174334863985789071076399442799",
          "0"),
    SCplx("0.000459575420018658608842238075291831",
          "0"),
    SCplx("0.0002491847588391650428459793673203583",
          "0"),
    SCplx("0.0001377626539651616489544811215615948",
          "0"),
    SCplx("0.0000773978967560022797286550355280944",
          "0"),
    SCplx("0.0000440762885077613962392179855552961",
          "0"),
    SCplx("0.00002539188650152801884523397139586122",
          "0"),
    SCplx("0.00001477449870016896057769675827658118",
          "0"),
    SCplx("8.67169955847374089980531746554652e-6",
          "0"),
    SCplx("5.1287959310428886447064185804151e-6",
          "0"),
    SCplx("3.054005210281688073246815295714548e-6",
          "0"),
    SCplx("1.829580137616389319627914246478101e-6",
          "0"),
    SCplx("1.102028631299685805273406122119768e-6",
          "0"),
    SCplx("6.67060917610270608826392995225466e-7",
          "0"),
    SCplx("4.05576153470350688262161750335027e-7",
          "0"),
    SCplx("2.475955578524275893924887593575491e-7",
          "0"),
    SCplx("1.517147174225017854597903369698604e-7",
          "0"),
    SCplx("9.32816172393729791900765121011054e-8",
          "0"),
    SCplx("5.75350237915139145084727171907248e-8",
          "0"),
    SCplx("3.5590476889323873756974640560664e-8",
          "0"),
    SCplx("2.207542818970887025436033768774108e-8",
          "0"),
    SCplx("1.372702422740637176755575007885976e-8",
          "0"),
    SCplx("8.55582712408945692410836553150902e-9",
          "0"),
    SCplx("5.34440722759988810468680524361655e-9",
          "0"),
    SCplx("3.34525264481004763425788335832909e-9",
          "0"),
    SCplx("2.097952056225409500262625183092425e-9",
          "0"),
    SCplx("1.318104172603367626069627776975981e-9",
          "0"),
    SCplx("8.29556623972277597808175824954876e-10",
          "0"),
    SCplx("5.22929168553515641197775644464023e-10",
          "0"),
    SCplx("3.30142958449158361489548671952625e-10",
          "0"),
    SCplx("2.087316956445044031090662666190506e-10",
          "0"),
    SCplx("1.32150719466653473360970748562225e-10",
          "0"),
    SCplx("8.37751975019621924308054688302701e-11",
          "0"),
    SCplx("5.31738892255771048357112864366786e-11",
          "0"),
    SCplx("3.37903483113638311414947839719158e-11",
          "0"),
    SCplx("2.149682077501501851929976736024515e-11",
          "0"),
    SCplx("1.369054768012467755645440153169966e-11",
          "0"),
    SCplx("8.72793734375571673411729026798007e-12",
          "0"),
    SCplx("5.56964080080822763115083103956149e-12",
          "0"),
    SCplx("3.55753623774067450689259022686071e-12",
          "0"),
    SCplx("2.274369422128359605806341177439299e-12",
          "0"),
    SCplx("1.455278844595946965584204164538795e-12",
          "0"),
    SCplx("9.3194423481545365785073486980351e-13",
          "0"),
    SCplx("5.97280032591902370426003544164608e-13",
          "0"),
    SCplx("3.83086727839793099991639100985078e-13",
          "0"),
    SCplx("2.458865043358627956830993822590931e-13",
          "0"),
    SCplx("1.579351860774173210736818387319204e-13",
          "0"),
    SCplx("1.015122624017817983204924395389475e-13",
          "0"),
    SCplx("6.52894362393861351230776949701434e-14",
          "0"),
    SCplx("4.20186491701491594774467409307682e-14",
          "0"),
    SCplx("2.705867261930432244136722687043166e-14",
          "0"),
    SCplx("1.743520620413210087375592889965158e-14",
          "0"),
    SCplx("1.12407504025634834706416670074209e-14",
          "0") };

static Cplx li2s3[64] = {
    SCplx("-0.5",
          "0.5"),
    SCplx("60.",
          "0"),
    SCplx("0.569568005811491678582884662471362",
          "0"),
    SCplx("-0.483472806361078515041877273029679",
          "0.400156153742007570186900153806013"),
    SCplx("0.779895920333719725993168220242667",
          "0.1363948115404353391903589915253442"),
    SCplx("0.1217505543966421934014046143586613",
          "0.0581453659370775325917636058840055"),
    SCplx("0.02907012563970977387309400564977052",
          "0.02659728022247981732877881349511124"),
    SCplx("0.0071879673962558007415697274493278",
          "0.01241722106330886006807128102532799"),
    SCplx("0.00125659706635755253879875713919985",
          "0.00576415076765172864771280677972463"),
    SCplx("-0.0002576280844118134240950413671039809",
          "0.002607956528341067655426303265770397"),
    SCplx("-0.0004935487156929456872087715900828",
          "0.001124662475748884579236319722666452"),
    SCplx("-0.000399249078225887197425169184369881",
          "0.000446167397191803673381247473153552"),
    SCplx("-0.0002605302003712807740501481400208297",
          "0.0001503629501919257564054029233632636"),
    SCplx("-0.000151532546617996988521107068156795",
          "0.00003155738594969159523084041611930162"),
    SCplx("-0.0000806826005160805306835886220691788",
          "-9.18550606209581208206059276135762e-6"),
    SCplx("-0.00003930474385554659811200675413823",
          "-0.00001814388799969195056548147723102198"),
    SCplx("-0.00001708473996950685414551051201690994",
          "-0.00001597814058432276288178400844341206"),
    SCplx("-6.12006385986874408554823683473155e-6",
          "-0.0000112265396615231059209493074604089"),
    SCplx("-1.257675513122595620292334082701143e-6",
          "-6.9460171350133457203500889611787e-6"),
    SCplx("5.52641906789244885470811865239377e-7",
          "-3.89193605709411167351893827030402e-6"),
    SCplx("9.82033220407864996696235421687905e-7",
          "-1.975177017133992271104118969472606e-6"),
    SCplx("8.78079000667178922857197447860744e-7",
          "-8.8428643635271497484927563826725e-7"),
    SCplx("6.32035290588297142856424795045234e-7",
          "-3.19717489512425967384307993250609e-7"),
    SCplx("4.00365759838524849465538254144209e-7",
          "-5.95332726445834359330679856635268e-8"),
    SCplx("2.289695905363728432367678474359387e-7",
          "4.005385720484172717378120807684e-8"),
    SCplx("1.180486631790774852462707964445076e-7",
          "6.35814687215507739200262629461805e-8"),
    SCplx("5.32629424744345997666054431090718e-8",
          "5.65128290416962289258651714329902e-8"),
    SCplx("1.901605894864554857744855745769415e-8",
          "4.0943972971148429091153904153534e-8"),
    SCplx("2.988693756117404520176200505327049e-9",
          "2.616333876895419125519169648011238e-8"),
    SCplx("-3.17252503039687276889951536037051e-9",
          "1.507903723021365831816143940907637e-8"),
    SCplx("-4.55999963605061321728376841046451e-9",
          "7.80914094388978666886190976769966e-9"),
    SCplx("-3.99680504720150137203200977762128e-9",
          "3.51314827972021835927045641458257e-9"),
    SCplx("-2.891570572982812694798440264393864e-9",
          "1.222052363725805411315938624849328e-9"),
    SCplx("-1.85051346316704963878394556994658e-9",
          "1.457481168438869797934897944172937e-10"),
    SCplx("-1.06778758177176250686604282572848e-9",
          "-2.643520117676651463375335462111376e-10"),
    SCplx("-5.52050492284333497648019170984039e-10",
          "-3.49196260837518674862177513542311e-10"),
    SCplx("-2.460217121902702917662270617616751e-10",
          "-3.008646790974034169801276940861572e-10"),
    SCplx("-8.24905890329304631456398176458458e-11",
          "-2.164673571164018796324520295171919e-10"),
    SCplx("-5.90461873540450951351790914010409e-12",
          "-1.381859906415017839719679133785476e-10"),
    SCplx("2.275530562551297926883337002547087e-11",
          "-7.95232463456273294291975899248796e-11"),
    SCplx("2.797812675545060119004441806580648e-11",
          "-4.08850049683940650233089858961214e-11"),
    SCplx("2.366960121555284767725358643632952e-11",
          "-1.79653550807729359368209881511388e-11"),
    SCplx("1.689765902387195290114207044792461e-11",
          "-5.74613088230857210043620186473995e-12"),
    SCplx("1.073372832912279449042826565688896e-11",
          "-6.7854725709894303584150767620597e-14"),
    SCplx("6.14514967713168174348376334391957e-12",
          "2.003465554531484199759238708999382e-12"),
    SCplx("3.133229623086484847041879060512543e-12",
          "2.316548296957670976517379888430361e-12"),
    SCplx("1.352337379414484537527155091201529e-12",
          "1.924043581889195084419953367811642e-12"),
    SCplx("4.0784863044199786107596761119217e-13",
          "1.361107907926621126974794106525516e-12"),
    SCplx("-2.611458978604217192678820021966216e-14",
          "8.58969390062648708329314029073502e-13"),
    SCplx("-1.793358077013325427172502210691883e-13",
          "4.88370679068763533170817657185298e-13"),
    SCplx("-1.966254535970681547698925743534404e-13",
          "2.464244108839868067010245857213227e-13"),
    SCplx("-1.603767247983122084959410317934846e-13",
          "1.041088248329578862951769794961038e-13"),
    SCplx("-1.123363405992863077204497471131348e-13",
          "2.918978643042732515882288386971914e-14"),
    SCplx("-7.03541121970186842382910576245347e-14",
          "-4.74513403449819605222506141811032e-15"),
    SCplx("-3.96714946556451741686571108489576e-14",
          "-1.625694331400665388741858021208855e-14"),
    SCplx("-1.977516954923575494461628472432966e-14",
          "-1.701436435721646286531344269987372e-14"),
    SCplx("-8.14959099381287857417118674075746e-15",
          "-1.363524538236766182051857884241711e-14"),
    SCplx("-2.085207137748006498231612513468254e-15",
          "-9.45231252379170191958744405611826e-15"),
    SCplx("6.15495728879612791768191176834071e-16",
          "-5.87009036081725712082543328674066e-15"),
    SCplx("1.488433744964267776565162790049522e-15",
          "-3.27938207238443039231080309153402e-15"),
    SCplx("1.495058526117230488694813492218305e-15",
          "-1.612320540400329015502756952043233e-15"),
    SCplx("1.177892037642348529168327347854799e-15",
          "-6.45789754408524747077776313293464e-16"),
    SCplx("8.07892101341592310437015504798215e-16",
          "-1.469195229505211968243546658332625e-16"),
    SCplx("4.97201733114964739403413909069878e-16",
          "7.09444567357391922031226103539253e-17") };

static Cplx li2s4[64] = {
    SCplx("-0.5",
          "-0.5"),
    SCplx("60.",
          "0"),
    SCplx("0.569568005811491678582884662471362",
          "0"),
    SCplx("-0.483472806361078515041877273029679",
          "-0.400156153742007570186900153806013"),
    SCplx("0.779895920333719725993168220242667",
          "-0.1363948115404353391903589915253442"),
    SCplx("0.1217505543966421934014046143586613",
          "-0.0581453659370775325917636058840055"),
    SCplx("0.02907012563970977387309400564977052",
          "-0.02659728022247981732877881349511124"),
    SCplx("0.0071879673962558007415697274493278",
          "-0.01241722106330886006807128102532799"),
    SCplx("0.00125659706635755253879875713919985",
          "-0.00576415076765172864771280677972463"),
    SCplx("-0.0002576280844118134240950413671039809",
          "-0.002607956528341067655426303265770397"),
    SCplx("-0.0004935487156929456872087715900828",
          "-0.001124662475748884579236319722666452"),
    SCplx("-0.000399249078225887197425169184369881",
          "-0.000446167397191803673381247473153552"),
    SCplx("-0.0002605302003712807740501481400208297",
          "-0.0001503629501919257564054029233632636"),
    SCplx("-0.000151532546617996988521107068156795",
          "-0.00003155738594969159523084041611930162"),
    SCplx("-0.0000806826005160805306835886220691788",
          "9.18550606209581208206059276135762e-6"),
    SCplx("-0.00003930474385554659811200675413823",
          "0.00001814388799969195056548147723102198"),
    SCplx("-0.00001708473996950685414551051201690994",
          "0.00001597814058432276288178400844341206"),
    SCplx("-6.12006385986874408554823683473155e-6",
          "0.0000112265396615231059209493074604089"),
    SCplx("-1.257675513122595620292334082701143e-6",
          "6.9460171350133457203500889611787e-6"),
    SCplx("5.52641906789244885470811865239377e-7",
          "3.89193605709411167351893827030402e-6"),
    SCplx("9.82033220407864996696235421687905e-7",
          "1.975177017133992271104118969472606e-6"),
    SCplx("8.78079000667178922857197447860744e-7",
          "8.8428643635271497484927563826725e-7"),
    SCplx("6.32035290588297142856424795045234e-7",
          "3.19717489512425967384307993250609e-7"),
    SCplx("4.00365759838524849465538254144209e-7",
          "5.95332726445834359330679856635268e-8"),
    SCplx("2.289695905363728432367678474359387e-7",
          "-4.005385720484172717378120807684e-8"),
    SCplx("1.180486631790774852462707964445076e-7",
          "-6.35814687215507739200262629461805e-8"),
    SCplx("5.32629424744345997666054431090718e-8",
          "-5.65128290416962289258651714329902e-8"),
    SCplx("1.901605894864554857744855745769415e-8",
          "-4.0943972971148429091153904153534e-8"),
    SCplx("2.988693756117404520176200505327049e-9",
          "-2.616333876895419125519169648011238e-8"),
    SCplx("-3.17252503039687276889951536037051e-9",
          "-1.507903723021365831816143940907637e-8"),
    SCplx("-4.55999963605061321728376841046451e-9",
          "-7.80914094388978666886190976769966e-9"),
    SCplx("-3.99680504720150137203200977762128e-9",
          "-3.51314827972021835927045641458257e-9"),
    SCplx("-2.891570572982812694798440264393864e-9",
          "-1.222052363725805411315938624849328e-9"),
    SCplx("-1.85051346316704963878394556994658e-9",
          "-1.457481168438869797934897944172937e-10"),
    SCplx("-1.06778758177176250686604282572848e-9",
          "2.643520117676651463375335462111376e-10"),
    SCplx("-5.52050492284333497648019170984039e-10",
          "3.49196260837518674862177513542311e-10"),
    SCplx("-2.460217121902702917662270617616751e-10",
          "3.008646790974034169801276940861572e-10"),
    SCplx("-8.24905890329304631456398176458458e-11",
          "2.164673571164018796324520295171919e-10"),
    SCplx("-5.90461873540450951351790914010409e-12",
          "1.381859906415017839719679133785476e-10"),
    SCplx("2.275530562551297926883337002547087e-11",
          "7.95232463456273294291975899248796e-11"),
    SCplx("2.797812675545060119004441806580648e-11",
          "4.08850049683940650233089858961214e-11"),
    SCplx("2.366960121555284767725358643632952e-11",
          "1.79653550807729359368209881511388e-11"),
    SCplx("1.689765902387195290114207044792461e-11",
          "5.74613088230857210043620186473995e-12"),
    SCplx("1.073372832912279449042826565688896e-11",
          "6.7854725709894303584150767620597e-14"),
    SCplx("6.14514967713168174348376334391957e-12",
          "-2.003465554531484199759238708999382e-12"),
    SCplx("3.133229623086484847041879060512543e-12",
          "-2.316548296957670976517379888430361e-12"),
    SCplx("1.352337379414484537527155091201529e-12",
          "-1.924043581889195084419953367811642e-12"),
    SCplx("4.0784863044199786107596761119217e-13",
          "-1.361107907926621126974794106525516e-12"),
    SCplx("-2.611458978604217192678820021966216e-14",
          "-8.58969390062648708329314029073502e-13"),
    SCplx("-1.793358077013325427172502210691883e-13",
          "-4.88370679068763533170817657185298e-13"),
    SCplx("-1.966254535970681547698925743534404e-13",
          "-2.464244108839868067010245857213227e-13"),
    SCplx("-1.603767247983122084959410317934846e-13",
          "-1.041088248329578862951769794961038e-13"),
    SCplx("-1.123363405992863077204497471131348e-13",
          "-2.918978643042732515882288386971914e-14"),
    SCplx("-7.03541121970186842382910576245347e-14",
          "4.74513403449819605222506141811032e-15"),
    SCplx("-3.96714946556451741686571108489576e-14",
          "1.625694331400665388741858021208855e-14"),
    SCplx("-1.977516954923575494461628472432966e-14",
          "1.701436435721646286531344269987372e-14"),
    SCplx("-8.14959099381287857417118674075746e-15",
          "1.363524538236766182051857884241711e-14"),
    SCplx("-2.085207137748006498231612513468254e-15",
          "9.45231252379170191958744405611826e-15"),
    SCplx("6.15495728879612791768191176834071e-16",
          "5.87009036081725712082543328674066e-15"),
    SCplx("1.488433744964267776565162790049522e-15",
          "3.27938207238443039231080309153402e-15"),
    SCplx("1.495058526117230488694813492218305e-15",
          "1.612320540400329015502756952043233e-15"),
    SCplx("1.177892037642348529168327347854799e-15",
          "6.45789754408524747077776313293464e-16"),
    SCplx("8.07892101341592310437015504798215e-16",
          "1.469195229505211968243546658332625e-16"),
    SCplx("4.97201733114964739403413909069878e-16",
          "-7.09444567357391922031226103539253e-17") };

static Cplx li2s5[64] = {
    SCplx("0",
          "0"),
    SCplx("60.",
          "0"),
    SCplx("0.901227809639395403924248942006443",
          "0"),
    SCplx("0",
          "0"),
    SCplx("1.",
          "0"),
    SCplx("0.25",
          "0"),
    SCplx("0.1111111111111111111111111111111111",
          "0"),
    SCplx("0.0625",
          "0"),
    SCplx("0.04",
          "0"),
    SCplx("0.02777777777777777777777777777777778",
          "0"),
    SCplx("0.02040816326530612244897959183673469",
          "0"),
    SCplx("0.015625",
          "0"),
    SCplx("0.01234567901234567901234567901234568",
          "0"),
    SCplx("0.01",
          "0"),
    SCplx("0.00826446280991735537190082644628099",
          "0"),
    SCplx("0.00694444444444444444444444444444444",
          "0"),
    SCplx("0.00591715976331360946745562130177515",
          "0"),
    SCplx("0.00510204081632653061224489795918367",
          "0"),
    SCplx("0.00444444444444444444444444444444444",
          "0"),
    SCplx("0.00390625",
          "0"),
    SCplx("0.00346020761245674740484429065743945",
          "0"),
    SCplx("0.00308641975308641975308641975308642",
          "0"),
    SCplx("0.002770083102493074792243767313019391",
          "0"),
    SCplx("0.0025",
          "0"),
    SCplx("0.00226757369614512471655328798185941",
          "0"),
    SCplx("0.002066115702479338842975206611570248",
          "0"),
    SCplx("0.001890359168241965973534971644612476",
          "0"),
    SCplx("0.001736111111111111111111111111111111",
          "0"),
    SCplx("0.0016",
          "0"),
    SCplx("0.001479289940828402366863905325443787",
          "0"),
    SCplx("0.001371742112482853223593964334705075",
          "0"),
    SCplx("0.001275510204081632653061224489795918",
          "0"),
    SCplx("0.001189060642092746730083234244946492",
          "0"),
    SCplx("0.001111111111111111111111111111111111",
          "0"),
    SCplx("0.001040582726326742976066597294484912",
          "0"),
    SCplx("0.0009765625",
          "0"),
    SCplx("0.000918273645546372819100091827364555",
          "0"),
    SCplx("0.000865051903114186851211072664359862",
          "0"),
    SCplx("0.000816326530612244897959183673469388",
          "0"),
    SCplx("0.000771604938271604938271604938271605",
          "0"),
    SCplx("0.000730460189919649379108838568298028",
          "0"),
    SCplx("0.000692520775623268698060941828254848",
          "0"),
    SCplx("0.00065746219592373438527284681130835",
          "0"),
    SCplx("0.000625",
          "0"),
    SCplx("0.000594883997620464009518143961927424",
          "0"),
    SCplx("0.000566893424036281179138321995464853",
          "0"),
    SCplx("0.0005408328826392644672796106003245",
          "0"),
    SCplx("0.000516528925619834710743801652892562",
          "0"),
    SCplx("0.000493827160493827160493827160493827",
          "0"),
    SCplx("0.000472589792060491493383742911153119",
          "0"),
    SCplx("0.000452693526482571299230421004979629",
          "0"),
    SCplx("0.000434027777777777777777777777777778",
          "0"),
    SCplx("0.000416493127863390254060807996668055",
          "0"),
    SCplx("0.0004",
          "0"),
    SCplx("0.000384467512495194156093810073048827",
          "0"),
    SCplx("0.000369822485207100591715976331360947",
          "0"),
    SCplx("0.000355998576005695977216091135635457",
          "0"),
    SCplx("0.000342935528120713305898491083676269",
          "0"),
    SCplx("0.00033057851239669421487603305785124",
          "0"),
    SCplx("0.00031887755102040816326530612244898",
          "0"),
    SCplx("0.0003077870113881194213604185903354878",
          "0"),
    SCplx("0.0002972651605231866825208085612366231",
          "0"),
    SCplx("0.0002872737719046251077276644642344154",
          "0"),
    SCplx("0.0002777777777777777777777777777777778",
          "0") };

static Cplx li2s6[64] = {
    SCplx("0",
          "1."),
    SCplx("60.",
          "0"),
    SCplx("0.635842776760887987505909819506124",
          "0"),
    SCplx("-0.2056167583560283045590518958307531",
          "0.915965594177219015054603514932384"),
    SCplx("0.785398163397448309615660845819876",
          "0.346573590279972654708616060729088"),
    SCplx("0.0767132048600136726456919696354559",
          "0.1426990816987241548078304229099379"),
    SCplx("-0.01179938779914943653855361527329191",
          "0.0511421365733424484304613130903039"),
    SCplx("-0.0175232690966735029895126514843946",
          "0.0119837924839712559294181218783644"),
    SCplx("-0.00958703398717700474353449750269152",
          "-0.001518615277338802391610121187515677"),
    SCplx("-0.00290115393555099800699156567707027",
          "-0.00382252832264750395294541458557627"),
    SCplx("0.000300262371793098626334164882874897",
          "-0.002486703373329426863135627723203088"),
    SCplx("0.001059794023091819933815102829231274",
          "-0.000853341853252467273386177156055894"),
    SCplx("0.000758526091779970909676601916494128",
          "0.0000739835760816177189467580704277988"),
    SCplx("0.0002806370037487662751701399588372033",
          "0.000335451260379751596486719502622493"),
    SCplx("-0.00002086478216341054226065409329317522",
          "0.0002551245488625147956092181443974576"),
    SCplx("-0.0001154929576694264414296620869097907",
          "0.0000992451618047524574731882932691348"),
    SCplx("-0.0000916109185890022684367891937868937",
          "-6.44862759229107414020090073724266e-6"),
    SCplx("-0.0000369378128401253212654178449198131",
          "-0.0000421414573711065020099855700548628"),
    SCplx("2.129645927318449495034151098824354e-6",
          "-0.0000344752919841169665143899885918256"),
    SCplx("0.00001604454456844298944057394763816982",
          "-0.00001427949860980562026507215001151883"),
    SCplx("0.00001343952810334646613183261177554714",
          "7.39534593828695944069597777101009e-7"),
    SCplx("5.68431209929250611818263477914316e-6",
          "6.31012621525205461470465621938929e-6"),
    SCplx("-2.671224963206599273810193423454103e-7",
          "5.38513777827711105933091715918826e-6"),
    SCplx("-2.545979573573781822153844985439374e-6",
          "2.316134944284846753198557940561334e-6"),
    SCplx("-2.205842804080806431617674229106032e-6",
          "-9.95936414988398306227095099422611e-8"),
    SCplx("-9.61819164716475399773560835747755e-7",
          "-1.048691399566310901176178214363117e-6"),
    SCplx("3.81134138144159608088344975331004e-8",
          "-9.20000940163585165000797321150027e-7"),
    SCplx("4.39383826714740130951851055957181e-7",
          "-4.0575838603654702306544665000904e-7"),
    SCplx("3.89528050595085142142828784008678e-7",
          "1.490743197948385904711034705222736e-8"),
    SCplx("1.734664115581885970700862047574737e-7",
          "1.867457217260434059065661384698827e-7"),
    SCplx("-5.93987946838367862227736411059932e-9",
          "1.670417296486260564378607897664562e-7"),
    SCplx("-8.0341619925725390401058883253633e-8",
          "7.50065927480797596353965629145147e-8"),
    SCplx("-7.24201585153873541307277159174624e-8",
          "-2.404770654887569057180005505970761e-9"),
    SCplx("-3.27530643726891430148409372062972e-8",
          "-3.49284772257939825562551828581447e-8"),
    SCplx("9.87152019585574516806090937989524e-10",
          "-3.1696513909054009369200906973836e-8"),
    SCplx("1.53241540363920393183488625018714e-8",
          "-1.442554029403050694490861553285491e-8"),
    SCplx("1.398840270936291582536593021367748e-8",
          "4.10174877618795702641321213935899e-10"),
    SCplx("6.40170596214182841339001889306935e-9",
          "6.77716222749217052925445454785631e-9"),
    SCplx("-1.7227311237894885026735248514445e-10",
          "6.21880007750920474443601835326736e-9"),
    SCplx("-3.018518118510933184074700383136922e-9",
          "2.860049764254593379700391433093689e-9"),
    SCplx("-2.782751121977442207276056529496563e-9",
          "-7.30497116855626175381469193284169e-11"),
    SCplx("-1.28545062412159656940986974924566e-9",
          "-1.352942854320496715334936976444377e-9"),
    SCplx("3.124213820937736635873751281085067e-11",
          "-1.252490351708222298399360268495771e-9"),
    SCplx("6.0984840291151033068296600537312e-10",
          "-5.80868605249863478056641181419677e-10"),
    SCplx("5.66701078292549734689406030653343e-10",
          "1.346532210497959091021073694938551e-11"),
    SCplx("2.637641996194275886643064757189797e-10",
          "2.762992766589146945487175014682174e-10"),
    SCplx("-5.8442778644521158272080136156896e-12",
          "2.576301484654874121837412088417941e-10"),
    SCplx("-1.257608696676129625410874710087089e-10",
          "1.203025947833988043527972425077114e-10"),
    SCplx("-1.176292037882121642560684148964289e-10",
          "-2.552759886331411858356234279222446e-12"),
    SCplx("-5.50917636622995850177916065625964e-11",
          "-5.74830184156272379799703092585838e-11"),
    SCplx("1.121543670992592768555584824774922e-12",
          "-5.39195984779953385280513596144561e-11"),
    SCplx("2.63757749390518961916956796934102e-11",
          "-2.53223203928049590311439331214859e-11"),
    SCplx("2.480553834397220476520222020063925e-11",
          "4.95382943956183599348148815313395e-13"),
    SCplx("1.167873793439041456243473252833981e-11",
          "1.214521435762528618010225742927953e-11"),
    SCplx("-2.198876495560403726492719894897338e-13",
          "1.144974307293177898277914953758805e-11"),
    SCplx("-5.61071664360780576327623225764198e-12",
          "5.40318002162609171973576302991599e-12"),
    SCplx("-5.30123322876522206464640901048361e-12",
          "-9.8046665626941412880599428397642e-14"),
    SCplx("-2.507046650306691018944233475063251e-12",
          "-2.599784606106806657788875929576682e-12"),
    SCplx("4.39027994894343734385057948301704e-14",
          "-2.461463983937478454963429230062101e-12"),
    SCplx("1.207999432775635799923497863940862e-12",
          "-1.166391016235836065859909081376213e-12"),
    SCplx("1.145928015950996836634296641352068e-12",
          "1.973556476268164350253424226771399e-14"),
    SCplx("5.44018239357835563070255973040592e-13",
          "5.6275710060309488535233810881817e-13"),
    SCplx("-8.90407282228350761989053128706147e-15",
          "5.34797591233126485730082142989057e-13"),
    SCplx("-2.627988249906877912998350112273746e-13",
          "2.543298014466411371751867402795873e-13") };

static Cplx li2s7[64] = {
    SCplx("0",
          "-1."),
    SCplx("60.",
          "0"),
    SCplx("0.635842776760887987505909819506124",
          "0"),
    SCplx("-0.2056167583560283045590518958307531",
          "-0.915965594177219015054603514932384"),
    SCplx("0.785398163397448309615660845819876",
          "-0.346573590279972654708616060729088"),
    SCplx("0.0767132048600136726456919696354559",
          "-0.1426990816987241548078304229099379"),
    SCplx("-0.01179938779914943653855361527329191",
          "-0.0511421365733424484304613130903039"),
    SCplx("-0.0175232690966735029895126514843946",
          "-0.0119837924839712559294181218783644"),
    SCplx("-0.00958703398717700474353449750269152",
          "0.001518615277338802391610121187515677"),
    SCplx("-0.00290115393555099800699156567707027",
          "0.00382252832264750395294541458557627"),
    SCplx("0.000300262371793098626334164882874897",
          "0.002486703373329426863135627723203088"),
    SCplx("0.001059794023091819933815102829231274",
          "0.000853341853252467273386177156055894"),
    SCplx("0.000758526091779970909676601916494128",
          "-0.0000739835760816177189467580704277988"),
    SCplx("0.0002806370037487662751701399588372033",
          "-0.000335451260379751596486719502622493"),
    SCplx("-0.00002086478216341054226065409329317522",
          "-0.0002551245488625147956092181443974576"),
    SCplx("-0.0001154929576694264414296620869097907",
          "-0.0000992451618047524574731882932691348"),
    SCplx("-0.0000916109185890022684367891937868937",
          "6.44862759229107414020090073724266e-6"),
    SCplx("-0.0000369378128401253212654178449198131",
          "0.0000421414573711065020099855700548628"),
    SCplx("2.129645927318449495034151098824354e-6",
          "0.0000344752919841169665143899885918256"),
    SCplx("0.00001604454456844298944057394763816982",
          "0.00001427949860980562026507215001151883"),
    SCplx("0.00001343952810334646613183261177554714",
          "-7.39534593828695944069597777101009e-7"),
    SCplx("5.68431209929250611818263477914316e-6",
          "-6.31012621525205461470465621938929e-6"),
    SCplx("-2.671224963206599273810193423454103e-7",
          "-5.38513777827711105933091715918826e-6"),
    SCplx("-2.545979573573781822153844985439374e-6",
          "-2.316134944284846753198557940561334e-6"),
    SCplx("-2.205842804080806431617674229106032e-6",
          "9.95936414988398306227095099422611e-8"),
    SCplx("-9.61819164716475399773560835747755e-7",
          "1.048691399566310901176178214363117e-6"),
    SCplx("3.81134138144159608088344975331004e-8",
          "9.20000940163585165000797321150027e-7"),
    SCplx("4.39383826714740130951851055957181e-7",
          "4.0575838603654702306544665000904e-7"),
    SCplx("3.89528050595085142142828784008678e-7",
          "-1.490743197948385904711034705222736e-8"),
    SCplx("1.734664115581885970700862047574737e-7",
          "-1.867457217260434059065661384698827e-7"),
    SCplx("-5.93987946838367862227736411059932e-9",
          "-1.670417296486260564378607897664562e-7"),
    SCplx("-8.0341619925725390401058883253633e-8",
          "-7.50065927480797596353965629145147e-8"),
    SCplx("-7.24201585153873541307277159174624e-8",
          "2.404770654887569057180005505970761e-9"),
    SCplx("-3.27530643726891430148409372062972e-8",
          "3.49284772257939825562551828581447e-8"),
    SCplx("9.87152019585574516806090937989524e-10",
          "3.1696513909054009369200906973836e-8"),
    SCplx("1.53241540363920393183488625018714e-8",
          "1.442554029403050694490861553285491e-8"),
    SCplx("1.398840270936291582536593021367748e-8",
          "-4.10174877618795702641321213935899e-10"),
    SCplx("6.40170596214182841339001889306935e-9",
          "-6.77716222749217052925445454785631e-9"),
    SCplx("-1.7227311237894885026735248514445e-10",
          "-6.21880007750920474443601835326736e-9"),
    SCplx("-3.018518118510933184074700383136922e-9",
          "-2.860049764254593379700391433093689e-9"),
    SCplx("-2.782751121977442207276056529496563e-9",
          "7.30497116855626175381469193284169e-11"),
    SCplx("-1.28545062412159656940986974924566e-9",
          "1.352942854320496715334936976444377e-9"),
    SCplx("3.124213820937736635873751281085067e-11",
          "1.252490351708222298399360268495771e-9"),
    SCplx("6.0984840291151033068296600537312e-10",
          "5.80868605249863478056641181419677e-10"),
    SCplx("5.66701078292549734689406030653343e-10",
          "-1.346532210497959091021073694938551e-11"),
    SCplx("2.637641996194275886643064757189797e-10",
          "-2.762992766589146945487175014682174e-10"),
    SCplx("-5.8442778644521158272080136156896e-12",
          "-2.576301484654874121837412088417941e-10"),
    SCplx("-1.257608696676129625410874710087089e-10",
          "-1.203025947833988043527972425077114e-10"),
    SCplx("-1.176292037882121642560684148964289e-10",
          "2.552759886331411858356234279222446e-12"),
    SCplx("-5.50917636622995850177916065625964e-11",
          "5.74830184156272379799703092585838e-11"),
    SCplx("1.121543670992592768555584824774922e-12",
          "5.39195984779953385280513596144561e-11"),
    SCplx("2.63757749390518961916956796934102e-11",
          "2.53223203928049590311439331214859e-11"),
    SCplx("2.480553834397220476520222020063925e-11",
          "-4.95382943956183599348148815313395e-13"),
    SCplx("1.167873793439041456243473252833981e-11",
          "-1.214521435762528618010225742927953e-11"),
    SCplx("-2.198876495560403726492719894897338e-13",
          "-1.144974307293177898277914953758805e-11"),
    SCplx("-5.61071664360780576327623225764198e-12",
          "-5.40318002162609171973576302991599e-12"),
    SCplx("-5.30123322876522206464640901048361e-12",
          "9.8046665626941412880599428397642e-14"),
    SCplx("-2.507046650306691018944233475063251e-12",
          "2.599784606106806657788875929576682e-12"),
    SCplx("4.39027994894343734385057948301704e-14",
          "2.461463983937478454963429230062101e-12"),
    SCplx("1.207999432775635799923497863940862e-12",
          "1.166391016235836065859909081376213e-12"),
    SCplx("1.145928015950996836634296641352068e-12",
          "-1.973556476268164350253424226771399e-14"),
    SCplx("5.44018239357835563070255973040592e-13",
          "-5.6275710060309488535233810881817e-13"),
    SCplx("-8.90407282228350761989053128706147e-15",
          "-5.34797591233126485730082142989057e-13"),
    SCplx("-2.627988249906877912998350112273746e-13",
          "-2.543298014466411371751867402795873e-13") };

static Cplx li2s8[64] = {
    SCplx("0",
          "0.5"),
    SCplx("60.",
          "0"),
    SCplx("0.805507910646843395967212785631611",
          "0"),
    SCplx("-0.058975074421565863455270698487258",
          "0.487222358294522357110234497693338"),
    SCplx("0.927295218001612232428512462922429",
          "0.2231435513142097557662950903098345"),
    SCplx("0.1768564486857902442337049096901655",
          "0.1272952180016122324285124629224288"),
    SCplx("0.0436063759978503567619833827700949",
          "0.0758085982477203256449398795868873"),
    SCplx("0.00362043596175284486592351395300234",
          "0.0440762306634422018096417408218091"),
    SCplx("-0.00908196906150752289542678531489449",
          "0.02371269753880455178547762232480374"),
    SCplx("-0.01153182923134091964246270387467291",
          "0.01080471823082079517428869114184251"),
    SCplx("-0.00994027887188326791782823243363478",
          "0.003051721317701280612921079071989302"),
    SCplx("-0.00703742659169152678689760266169557",
          "-0.001128516597224290284770835330289436"),
    SCplx("-0.00411044160493459504929629274615211",
          "-0.002917238385229380954484626954125449"),
    SCplx("-0.001733652151031558726372115927018636",
          "-0.00321614173332671553317777138751825"),
    SCplx("-0.0000931292412241535760404156590577306",
          "-0.002700253889148288593403847140033884"),
    SCplx("0.00083941204283246848184644702945606",
          "-0.001849729543456402768195307496151294"),
    SCplx("0.001200292798996435879745183069817774",
          "-0.00097829853179646844377066189433753"),
    SCplx("0.001164999197626408428541119342231236",
          "-0.0002636472424439817178358688044043545"),
    SCplx("0.000904356118518670635198383672983366",
          "0.00022037835337805763803866086740307"),
    SCplx("0.000559341192352675262010844206952577",
          "0.000471942061106774107663636053510479"),
    SCplx("0.0002300479570891781502802144875096869",
          "0.000532324344206824022608647918969557"),
    SCplx("-0.000025102548089800670156204239099359",
          "0.000462020575017202649875699260720912"),
    SCplx("-0.000183485059430943593916529593412722",
          "0.000322990779936872835493507757495951"),
    SCplx("-0.0002488976538053974695429278971370444",
          "0.0001672689534885411673480674567263545"),
    SCplx("-0.000241276050357263767139176108050199",
          "0.00003133310240680956810870876735801061"),
    SCplx("-0.0001873671632732716784066691186358558",
          "-0.0000649163786031415293349639119053583"),
    SCplx("-0.0001134957624503902828279741764340182",
          "-0.0001159906318022548821882523850583169"),
    SCplx("-0.0000408846042138397231426611895077911",
          "-0.0001268868791709048934539070265709986"),
    SCplx("0.00001654964846425486002798149101631738",
          "-0.0001086400875788911727266028171882922"),
    SCplx("0.0000523676742919182860689389561313312",
          "-0.0000742745976993943192651703634301589"),
    SCplx("0.0000663768928439564226477077084865738",
          "-0.0000357205015652609904074670816388037"),
    SCplx("0.0000626628366775744053813893294039363",
          "-1.922052052844458444137377019279583e-6"),
    SCplx("0.000047463178156542169858931463012599",
          "0.0000219062910272461310054374912627736"),
    SCplx("0.00002731223536333199565693262365059173",
          "0.0000341030565516718789970782949737833"),
    SCplx("7.70567936545358995000720969375266e-6",
          "0.000035779041931278287775632189672113"),
    SCplx("-7.63194137746812359446637631552542e-6",
          "0.00002975909017664038365151238153003288"),
    SCplx("-0.00001692590073041183484697764105703346",
          "0.00001952359709184947692884826795534464"),
    SCplx("-0.00002010958631525096270806837498657096",
          "8.34424419730755682522550166553042e-6"),
    SCplx("-0.00001833200268906909993924910688204835",
          "-1.284121923153571008677568527288795e-6"),
    SCplx("-0.00001337980727765910125338026154593553",
          "-7.89720321960331495689850925349859e-6"),
    SCplx("-7.14665628577869975549675529081443e-6",
          "-0.00001104502882215298998843450055681024"),
    SCplx("-1.235577132485186969712078218746479e-6",
          "-0.0000110869971689487922334691714444582"),
    SCplx("3.26906125296412495002895219795913e-6",
          "-8.89093751093979845843053370277199e-6"),
    SCplx("5.86528315621286436784555331100244e-6",
          "-5.52034191882826442130179913135313e-6"),
    SCplx("6.56735919666865340785854428404645e-6",
          "-1.972331801137025547409744471427836e-6"),
    SCplx("5.75882205037743983328250049284849e-6",
          "9.98134374632845896412965634429174e-7"),
    SCplx("4.0151834224751039473481178374975e-6",
          "2.958399576410140993328452084543555e-6"),
    SCplx("1.938589671080882815530491521786867e-6",
          "3.79380569936728707165962757553561e-6"),
    SCplx("3.27626920675054070045941403420934e-8",
          "3.64302736991770157964056867039493e-6"),
    SCplx("-1.368822320761547220317810983974766e-6",
          "2.801962903855271541094727658234072e-6"),
    SCplx("-2.122209906108272117207554089127133e-6",
          "1.62320205490234032264920520557572e-6"),
    SCplx("-2.250196314953763614998708903601468e-6",
          "4.31616770827484847137914197130563e-7"),
    SCplx("-1.893222519738108810874264850683176e-6",
          "-5.31989142159558496058810964081607e-7"),
    SCplx("-1.250461237261081617163628772789278e-6",
          "-1.135799726042719299876384875155833e-6"),
    SCplx("-5.25103124599756030888920378840491e-7",
          "-1.354026185999670215596628496474029e-6"),
    SCplx("1.166738975917818041463151908087943e-7",
          "-1.244026984819050299813815757581865e-6"),
    SCplx("5.68703607839186116404876272223474e-7",
          "-9.13198863114712651628970004304184e-7"),
    SCplx("7.90066380988593862708461827071822e-7",
          "-4.84752708376836646974174302570052e-7"),
    SCplx("7.96184666285674385848656109437794e-7",
          "-6.93187388828969285785758651862788e-8"),
    SCplx("6.41191044317010718386925698819739e-7",
          "2.536098914766493657649101788981963e-7"),
    SCplx("3.9726513276141868697961764936643e-7",
          "4.43329334659786301175620288633697e-7"),
    SCplx("1.357508818398077957175049958231693e-7",
          "4.9599487445622905458680082872686e-7"),
    SCplx("-8.67178429759176398898765271662648e-8",
          "4.35948183409053458163705703080625e-7"),
    SCplx("-2.356554541792419991496551487840884e-7",
          "3.037227684629582555673663449118356e-7") };

static Cplx li2s9[64] = {
    SCplx("0",
          "-0.5"),
    SCplx("60.",
          "0"),
    SCplx("0.805507910646843395967212785631611",
          "0"),
    SCplx("-0.058975074421565863455270698487258",
          "-0.487222358294522357110234497693338"),
    SCplx("0.927295218001612232428512462922429",
          "-0.2231435513142097557662950903098345"),
    SCplx("0.1768564486857902442337049096901655",
          "-0.1272952180016122324285124629224288"),
    SCplx("0.0436063759978503567619833827700949",
          "-0.0758085982477203256449398795868873"),
    SCplx("0.00362043596175284486592351395300234",
          "-0.0440762306634422018096417408218091"),
    SCplx("-0.00908196906150752289542678531489449",
          "-0.02371269753880455178547762232480374"),
    SCplx("-0.01153182923134091964246270387467291",
          "-0.01080471823082079517428869114184251"),
    SCplx("-0.00994027887188326791782823243363478",
          "-0.003051721317701280612921079071989302"),
    SCplx("-0.00703742659169152678689760266169557",
          "0.001128516597224290284770835330289436"),
    SCplx("-0.00411044160493459504929629274615211",
          "0.002917238385229380954484626954125449"),
    SCplx("-0.001733652151031558726372115927018636",
          "0.00321614173332671553317777138751825"),
    SCplx("-0.0000931292412241535760404156590577306",
          "0.002700253889148288593403847140033884"),
    SCplx("0.00083941204283246848184644702945606",
          "0.001849729543456402768195307496151294"),
    SCplx("0.001200292798996435879745183069817774",
          "0.00097829853179646844377066189433753"),
    SCplx("0.001164999197626408428541119342231236",
          "0.0002636472424439817178358688044043545"),
    SCplx("0.000904356118518670635198383672983366",
          "-0.00022037835337805763803866086740307"),
    SCplx("0.000559341192352675262010844206952577",
          "-0.000471942061106774107663636053510479"),
    SCplx("0.0002300479570891781502802144875096869",
          "-0.000532324344206824022608647918969557"),
    SCplx("-0.000025102548089800670156204239099359",
          "-0.000462020575017202649875699260720912"),
    SCplx("-0.000183485059430943593916529593412722",
          "-0.000322990779936872835493507757495951"),
    SCplx("-0.0002488976538053974695429278971370444",
          "-0.0001672689534885411673480674567263545"),
    SCplx("-0.000241276050357263767139176108050199",
          "-0.00003133310240680956810870876735801061"),
    SCplx("-0.0001873671632732716784066691186358558",
          "0.0000649163786031415293349639119053583"),
    SCplx("-0.0001134957624503902828279741764340182",
          "0.0001159906318022548821882523850583169"),
    SCplx("-0.0000408846042138397231426611895077911",
          "0.0001268868791709048934539070265709986"),
    SCplx("0.00001654964846425486002798149101631738",
          "0.0001086400875788911727266028171882922"),
    SCplx("0.0000523676742919182860689389561313312",
          "0.0000742745976993943192651703634301589"),
    SCplx("0.0000663768928439564226477077084865738",
          "0.0000357205015652609904074670816388037"),
    SCplx("0.0000626628366775744053813893294039363",
          "1.922052052844458444137377019279583e-6"),
    SCplx("0.000047463178156542169858931463012599",
          "-0.0000219062910272461310054374912627736"),
    SCplx("0.00002731223536333199565693262365059173",
          "-0.0000341030565516718789970782949737833"),
    SCplx("7.70567936545358995000720969375266e-6",
          "-0.000035779041931278287775632189672113"),
    SCplx("-7.63194137746812359446637631552542e-6",
          "-0.00002975909017664038365151238153003288"),
    SCplx("-0.00001692590073041183484697764105703346",
          "-0.00001952359709184947692884826795534464"),
    SCplx("-0.00002010958631525096270806837498657096",
          "-8.34424419730755682522550166553042e-6"),
    SCplx("-0.00001833200268906909993924910688204835",
          "1.284121923153571008677568527288795e-6"),
    SCplx("-0.00001337980727765910125338026154593553",
          "7.89720321960331495689850925349859e-6"),
    SCplx("-7.14665628577869975549675529081443e-6",
          "0.00001104502882215298998843450055681024"),
    SCplx("-1.235577132485186969712078218746479e-6",
          "0.0000110869971689487922334691714444582"),
    SCplx("3.26906125296412495002895219795913e-6",
          "8.89093751093979845843053370277199e-6"),
    SCplx("5.86528315621286436784555331100244e-6",
          "5.52034191882826442130179913135313e-6"),
    SCplx("6.56735919666865340785854428404645e-6",
          "1.972331801137025547409744471427836e-6"),
    SCplx("5.75882205037743983328250049284849e-6",
          "-9.98134374632845896412965634429174e-7"),
    SCplx("4.0151834224751039473481178374975e-6",
          "-2.958399576410140993328452084543555e-6"),
    SCplx("1.938589671080882815530491521786867e-6",
          "-3.79380569936728707165962757553561e-6"),
    SCplx("3.27626920675054070045941403420934e-8",
          "-3.64302736991770157964056867039493e-6"),
    SCplx("-1.368822320761547220317810983974766e-6",
          "-2.801962903855271541094727658234072e-6"),
    SCplx("-2.122209906108272117207554089127133e-6",
          "-1.62320205490234032264920520557572e-6"),
    SCplx("-2.250196314953763614998708903601468e-6",
          "-4.31616770827484847137914197130563e-7"),
    SCplx("-1.893222519738108810874264850683176e-6",
          "5.31989142159558496058810964081607e-7"),
    SCplx("-1.250461237261081617163628772789278e-6",
          "1.135799726042719299876384875155833e-6"),
    SCplx("-5.25103124599756030888920378840491e-7",
          "1.354026185999670215596628496474029e-6"),
    SCplx("1.166738975917818041463151908087943e-7",
          "1.244026984819050299813815757581865e-6"),
    SCplx("5.68703607839186116404876272223474e-7",
          "9.13198863114712651628970004304184e-7"),
    SCplx("7.90066380988593862708461827071822e-7",
          "4.84752708376836646974174302570052e-7"),
    SCplx("7.96184666285674385848656109437794e-7",
          "6.93187388828969285785758651862788e-8"),
    SCplx("6.41191044317010718386925698819739e-7",
          "-2.536098914766493657649101788981963e-7"),
    SCplx("3.9726513276141868697961764936643e-7",
          "-4.43329334659786301175620288633697e-7"),
    SCplx("1.357508818398077957175049958231693e-7",
          "-4.9599487445622905458680082872686e-7"),
    SCplx("-8.67178429759176398898765271662648e-8",
          "-4.35948183409053458163705703080625e-7"),
    SCplx("-2.356554541792419991496551487840884e-7",
          "-3.037227684629582555673663449118356e-7") };

static Cplx li2s10[64] = {
    SCplx("0.25",
          "0"),
    SCplx("60.",
          "0"),
    SCplx("1.202523359207318580502808171013234",
          "0"),
    SCplx("0.2676526390827326069191838284878116",
          "0"),
    SCplx("1.15072828980712370975687602397531",
          "0"),
    SCplx("0.365210087052419247152914618716047",
          "0"),
    SCplx("0.2112916197120671927774128686090593",
          "0"),
    SCplx("0.1562485976539218784578848509629456",
          "0"),
    SCplx("0.1321032529395487543668672423506728",
          "0"),
    SCplx("0.1215213928078141658278636503262896",
          "0"),
    SCplx("0.1184652906331863651464558574481489",
          "0"),
    SCplx("0.1204815487581112271151071574983351",
          "0"),
    SCplx("0.1265501172778037163157550859271037",
          "0"),
    SCplx("0.1363437989269931652070120389042824",
          "0"),
    SCplx("0.1499398814950283562767529657028157",
          "0"),
    SCplx("0.1677043389146978984321850024131372",
          "0"),
    SCplx("0.1902529997366184180195977322753987",
          "0"),
    SCplx("0.2184534528008272877073974898263889",
          "0"),
    SCplx("0.2534534983163058525209186422136865",
          "0"),
    SCplx("0.2967312793264798452242914633029146",
          "0"),
    SCplx("0.350166828432813279364710222394014",
          "0"),
    SCplx("0.416137547332424663562840418726562",
          "0"),
    SCplx("0.497642289064083138451279915070527",
          "0"),
    SCplx("0.598460789987146520649272861762681",
          "0"),
    SCplx("0.723357516251034619019823653068071",
          "0"),
    SCplx("0.87834178010028909686561564242373",
          "0"),
    SCplx("1.070999463419074735320182972365176",
          "0"),
    SCplx("1.310916102217729233455831136728467",
          "0"),
    SCplx("1.610216729748250136429888339404521",
          "0"),
    SCplx("1.984255116062829189608466269295641",
          "0"),
    SCplx("2.452494348406546472543692933374947",
          "0"),
    SCplx("3.039632674515288566091549887325601",
          "0"),
    SCplx("3.7770439596503923849840639959765",
          "0"),
    SCplx("4.70462199588984455564040911806482",
          "0"),
    SCplx("5.87314355238065153586300013821693",
          "0"),
    SCplx("7.34729815511294079403902359555875",
          "0"),
    SCplx("9.20957531908624703567702456129251",
          "0"),
    SCplx("11.56525515489353927094704615851561",
          "0"),
    SCplx("14.54881960398817810394100694802528",
          "0"),
    SCplx("18.33219377811333650853517372606707",
          "0"),
    SCplx("23.13534615681704140628678427749709",
          "0"),
    SCplx("29.23993073548814277648223255180395",
          "0"),
    SCplx("37.0068540015220989445248927188446",
          "0"),
    SCplx("46.898908332897372503316393805521",
          "0"),
    SCplx("59.5099485745308642827189685947662",
          "0"),
    SCplx("75.6025229046958210353327682751412",
          "0"),
    SCplx("96.1564322225038393066551215127011",
          "0"),
    SCplx("122.4314226012310432551875992744055",
          "0"),
    SCplx("156.048162835836787962765414107317",
          "0"),
    SCplx("199.0928887672667003289200631314219",
          "0"),
    SCplx("254.2526924600129747093924293512457",
          "0"),
    SCplx("324.990507501292801126798000763028",
          "0"),
    SCplx("415.771534949351112520306130496003",
          "0"),
    SCplx("532.356354336115487536634196460382",
          "0"),
    SCplx("682.180513598005162135956802697352",
          "0"),
    SCplx("874.846307406150708228336289610171",
          "0"),
    SCplx("1122.760147574292617288717191094205",
          "0"),
    SCplx("1441.958939674406069207253723609769",
          "0"),
    SCplx("1853.181907618943984063807381354608",
          "0"),
    SCplx("2383.261266817584142218122670569032",
          "0"),
    SCplx("3066.927228808500315461900190070976",
          "0"),
    SCplx("3949.15158141563053524153056410675",
          "0"),
    SCplx("5088.19155819551969125027409395441",
          "0"),
    SCplx("6559.54453839471967229448619848081",
          "0") };

static Cplx li2s11[64] = {
    SCplx("0.25",
          "0.5"),
    SCplx("60.",
          "0"),
    SCplx("0.999419237488133274838156864848736",
          "0"),
    SCplx("0.1845853342047610073468488302462845",
          "0.552346828251386057009577899838716"),
    SCplx("1.023859911587405882639154146707092",
          "0.3042905910154584397041360290861582"),
    SCplx("0.2085620240911324336425679795866983",
          "0.2050640005560490225373612134235178"),
    SCplx("0.0361069372486123837373662211051644",
          "0.1383452403907865175932905152875093"),
    SCplx("-0.02648894998364000268193624662334269",
          "0.0846118799024913826401381041130302"),
    SCplx("-0.0479680437700611747223682676283933",
          "0.0402965901113145200734977812554835"),
    SCplx("-0.0477114027446127998770174178682522",
          "0.00596316191752434583283503130808585"),
    SCplx("-0.0351218424544675096378849230957472",
          "-0.0171191210562816482528773701370102"),
    SCplx("-0.01693699861049812567964958209228049",
          "-0.02844388140298074336279909217865161"),
    SCplx("0.001294989312556369897430779208377539",
          "-0.0289293551845192917139222525056181"),
    SCplx("0.01525585394613717466621305649175867",
          "-0.02102523192457376475645218454456426"),
    SCplx("0.02226332636366762531301989747014379",
          "-0.00836131831737699910507573149251581"),
    SCplx("0.021581563485058839535816853579508",
          "0.00494463707555649760558724765581028"),
    SCplx("0.01441096811180761147465845937550302",
          "0.01514521183162298602634196034501542"),
    SCplx("0.00348114454381898263118265427828852",
          "0.01967253553632893923147561093901025"),
    SCplx("-0.00770002448776372664401394626747089",
          "0.01768670527342890527957845578924426"),
    SCplx("-0.01578056916284628342505485611556135",
          "0.01020777429301455534331887916481074"),
    SCplx("-0.0184551887100455703917457265212095",
          "-0.0002230742878924127746876841209414141"),
    SCplx("-0.01507936851606803575765494016086782",
          "-0.01028374395781777920672005443668565"),
    SCplx("-0.00683263486035044775287138688524883",
          "-0.01682897846099057667339451441422554"),
    SCplx("0.00362997196475718079520695970535177",
          "-0.0178098241954861395182551428837549"),
    SCplx("0.01295912627094181315828217068268624",
          "-0.01289396711040288135696342339570355"),
    SCplx("0.01811755238113415642869397481692754",
          "-0.00359574542190006107033392175327439"),
    SCplx("0.01732558977441398850462339603359778",
          "0.00714454055808325638136269410090005"),
    SCplx("0.0106599082242268453999814505261167",
          "0.01583342651467621031403843091275241"),
    SCplx("0.0001044886657457163797527398716491711",
          "0.01950837904195550530301026136003566"),
    SCplx("-0.01099419147942210407522988444932204",
          "0.01671143130023920182989019706948209"),
    SCplx("-0.01893565550012342736805014000709021",
          "0.008041375360861513342123326466193"),
    SCplx("-0.02085088679232896178353495811262615",
          "-0.00391860000104693846110137512741031"),
    SCplx("-0.01569954205894419913486883541311038",
          "-0.01532017383150417023661137364720427"),
    SCplx("-0.00474342576228877331454414413168419",
          "-0.0222343630944222353335926545618193"),
    SCplx("0.00869997386740286480079110913164082",
          "-0.0219544597244695912833843962025523"),
    SCplx("0.02020454778341272359966646379633184",
          "-0.01400130042203843465366416358816846"),
    SCplx("0.02563353016596710705560308262834636",
          "-0.000473219424005588912646012969666898"),
    SCplx("0.0225665515474810257643649685992712",
          "0.01443602505400158243207112316069217"),
    SCplx("0.0112825226806147195390677729466176",
          "0.0256704673578564126971578678035783"),
    SCplx("-0.00507551799064007862189980248512523",
          "0.02895728148798445625884383966737837"),
    SCplx("-0.02129311982099566917243030607167049",
          "0.02235175544250854594180923164957882"),
    SCplx("-0.031667309517172471826203579748306",
          "0.007147827591496076722413967378607"),
    SCplx("-0.0319267657534752676543049663759621",
          "-0.01222461080808693489805913261341002"),
    SCplx("-0.02087061625200104355980888886758432",
          "-0.02939344897218082198127124478382659"),
    SCplx("-0.001131465275086980955628325280309896",
          "-0.0380440589365989530422420396877397"),
    SCplx("0.02130232000554192587052289610265472",
          "-0.0341303893371103193408694438890664"),
    SCplx("0.0387878622571520036060491502672556",
          "-0.01755857190760504083289691312493274"),
    SCplx("0.0445114984248418275157664728686793",
          "0.00730477451636377323681113793573486"),
    SCplx("0.0349881548561923379451127916620137",
          "0.0326218731574605438193150947080754"),
    SCplx("0.01170664628507893769196604474832924",
          "0.0494144833299951301376822326924639"),
    SCplx("-0.01876396521808395346092933449843291",
          "0.0505927708179964614634905837176356"),
    SCplx("-0.0464446093939434249159913075537801",
          "0.0337112259521203207968310812729987"),
    SCplx("-0.0610407394850069054359770407207384",
          "0.002446850464216891694104605978291647"),
    SCplx("-0.0555617885138140729739575093973786",
          "-0.033892455023395085581972722951953"),
    SCplx("-0.0292587994752226311404380732681947",
          "-0.0629233205374694460537634441405661"),
    SCplx("0.01125310263831136529473758422203868",
          "-0.0731858926613163418379110022872063"),
    SCplx("0.0533382488418121297985641829609507",
          "-0.0583695275321351389168514796608345"),
    SCplx("0.0820202133759996117215507858536354",
          "-0.02029593001154059391243678792843259"),
    SCplx("0.0850211066720839050058031317693631",
          "0.03057907294926788457640505786382308"),
    SCplx("0.0575594845037690601011860365582091",
          "0.0776814264780681619989445240555663"),
    SCplx("0.00515822750827609129835628605652963",
          "0.1033929762043261271032530958338434"),
    SCplx("-0.0568344310898902979019113477063064",
          "0.0952446237432061522637767970027559"),
    SCplx("-0.1073266084873834229486895538886402",
          "0.0511756609392527173567347689739879"),
    SCplx("-0.1262418320895555408400973238645278",
          "-0.01816751082255048690168162824914039") };

static Cplx li2s12[64] = {
    SCplx("0.25",
          "0.25"),
    SCplx("60.",
          "0"),
    SCplx("1.140477654284739752217074160112777",
          "0"),
    SCplx("0.2454094040383964319645602444734965",
          "0.284502867048803695506096946485656"),
    SCplx("1.113504738039019940453746259865665",
          "0.1734974795475488331518721975689806"),
    SCplx("0.3129977824134312263943815425653547",
          "0.1400072584914711073018740622966841"),
    SCplx("0.1426599454601302217383258601839482",
          "0.1239873652292801587900099736915608"),
    SCplx("0.0693623672992177625408295825200699",
          "0.1133422036796084277558071630719144"),
    SCplx("0.02511268643387809552538120705282514",
          "0.1037122617913749356560358711170487"),
    SCplx("-0.007177580375421718635695130283123",
          "0.0929153744041719331155755598929608"),
    SCplx("-0.033071265954047986727414069807341",
          "0.0796334108540299303311550073171897"),
    SCplx("-0.0543331250035398298779752120708067",
          "0.0630383584430065022903612578892142"),
    SCplx("-0.0711087527812740842886863036771689",
          "0.0427065538728065205896240534044074"),
    SCplx("-0.082720942942536163119465727286807",
          "0.01864224784487713344126357947538484"),
    SCplx("-0.0880533007242563096759960948883234",
          "-0.00865451101711508465587146684034878"),
    SCplx("-0.0858097640596069891794549247095556",
          "-0.0381089213188498216278042423303776"),
    SCplx("-0.0747518305497207595353164095673027",
          "-0.0680061476551414375312525418282261"),
    SCplx("-0.0539516328709526230302181012544576",
          "-0.0959633362093703892163383917352083"),
    SCplx("-0.02307090547964999618738026070500468",
          "-0.1189633974463241697859087911025986"),
    SCplx("0.01734136312244902786658363880592287",
          "-0.1334753468081136578360923388378447"),
    SCplx("0.0655539356392640564131928471189117",
          "-0.1356841681074004975008452185529081"),
    SCplx("0.1183956178648062564335394466955881",
          "-0.1218478651872330431296928040578044"),
    SCplx("0.171081947924374704523705776522562",
          "-0.0887894560166605301375014664087768"),
    SCplx("0.2171839293237958485904223370995976",
          "-0.0345162725131430658321272910620352"),
    SCplx("0.2488030861717641981320094361189288",
          "0.0410623470219280684680945298316815"),
    SCplx("0.2570172817750991023328577966051121",
          "0.135374739658032750637828890357905"),
    SCplx("0.2326524894156224068277076818573113",
          "0.2424708628899604180350624135322065"),
    SCplx("0.1674140336764227534379376070251635",
          "0.352470192834023015320182851246306"),
    SCplx("0.0553741347038412209800985334521121",
          "0.451323647796996130216035157762073"),
    SCplx("-0.1052406923420646939776269151042025",
          "0.52106186672583920387016294463469"),
    SCplx("-0.3100885127317852129733160208621357",
          "0.540709084141827248071658106257859"),
    SCplx("-0.546786531338371567390291103908684",
          "0.488025059262930630406379796194507"),
    SCplx("-0.793321351840727539475317743432723",
          "0.34218830709381051292401919573374"),
    SCplx("-1.017182438615685673436995852741598",
          "0.0874443202484382925675898425446555"),
    SCplx("-1.175675604675829689636805374688275",
          "-0.2823929044801788669082333306784941"),
    SCplx("-1.217904981662474342405711985943832",
          "-0.758879840920604323543208357390654"),
    SCplx("-1.088882767113071061632224494506188",
          "-1.313839581157952012474882926438513"),
    SCplx("-0.736111322768440742169263793923934",
          "-1.89498003373886415373901945975135"),
    SCplx("-0.1187586408687252822108284752833194",
          "-2.423245595228806831441168365340034"),
    SCplx("0.780801481761037218276265332924586",
          "-2.793118589739958630802476604422193"),
    SCplx("1.943794530539885307308531072489097",
          "-2.877196946503674682482105087888244"),
    SCplx("3.3015054929555911735824889139625",
          "-2.536326157342673313072791165119031"),
    SCplx("4.72338384960969409442436969371819",
          "-1.636286720854796846477317847766391"),
    SCplx("6.00947164648774961040237784219608",
          "-0.0714658216283239120957038509208224"),
    SCplx("6.89042284409698088294799098196691",
          "2.204978367766432869558682967865542"),
    SCplx("7.03872810702209649801328983736411",
          "5.14624083691614653598149402764338"),
    SCplx("6.09468384195989726306527040892002",
          "8.57569292849396049002493897621126"),
    SCplx("3.70995111535071279848468870251301",
          "12.15468487686367545128920347836721"),
    SCplx("-0.389953408387590761205136900954351",
          "15.36152811374213240564060693532176"),
    SCplx("-6.32536043319078317235199974117464",
          "17.4905346417480338543203153527182"),
    SCplx("-13.96897421269872407767031488664317",
          "17.68102353122288900342402709208232"),
    SCplx("-22.848322791926494857576181331582",
          "14.98609794611352943197156664528657"),
    SCplx("-32.058408803291102475845814576345",
          "8.48919587851461486396359700465686"),
    SCplx("-40.2042003411842490479605946054344",
          "-2.527625371177148752645256798506209"),
    SCplx("-45.3973408659080594123131559833813",
          "-18.36644578161972340483950468741491"),
    SCplx("-45.3344549118286595430541499834092",
          "-38.6597019638501855051153519813229"),
    SCplx("-37.4842907635684529563256304383776",
          "-62.1046868740589846824389308842153"),
    SCplx("-19.40610386883035852974498597384871",
          "-86.2255767439473451904624487933601"),
    SCplx("10.78942119890393765830358022286489",
          "-107.2172645240831101374643769041004"),
    SCplx("53.8440818985220087412488459053112",
          "-119.9386471617432578286776756442609"),
    SCplx("108.65516611527461644611256996364",
          "-118.1315706581014344097241430379971"),
    SCplx("171.5465181768861334107927068279335",
          "-94.9414440202545364929885925342732"),
    SCplx("235.6171384325314199573559446395683",
          "-43.8021334802658406324965051783215"),
    SCplx("290.3191083800530435117558700089482",
          "40.283331411150262423989733798564") };

static Cplx li2s13[64] = {
    SCplx("0.25",
          "-0.25"),
    SCplx("60.",
          "0"),
    SCplx("1.140477654284739752217074160112777",
          "0"),
    SCplx("0.2454094040383964319645602444734965",
          "-0.284502867048803695506096946485656"),
    SCplx("1.113504738039019940453746259865665",
          "-0.1734974795475488331518721975689806"),
    SCplx("0.3129977824134312263943815425653547",
          "-0.1400072584914711073018740622966841"),
    SCplx("0.1426599454601302217383258601839482",
          "-0.1239873652292801587900099736915608"),
    SCplx("0.0693623672992177625408295825200699",
          "-0.1133422036796084277558071630719144"),
    SCplx("0.02511268643387809552538120705282514",
          "-0.1037122617913749356560358711170487"),
    SCplx("-0.007177580375421718635695130283123",
          "-0.0929153744041719331155755598929608"),
    SCplx("-0.033071265954047986727414069807341",
          "-0.0796334108540299303311550073171897"),
    SCplx("-0.0543331250035398298779752120708067",
          "-0.0630383584430065022903612578892142"),
    SCplx("-0.0711087527812740842886863036771689",
          "-0.0427065538728065205896240534044074"),
    SCplx("-0.082720942942536163119465727286807",
          "-0.01864224784487713344126357947538484"),
    SCplx("-0.0880533007242563096759960948883234",
          "0.00865451101711508465587146684034878"),
    SCplx("-0.0858097640596069891794549247095556",
          "0.0381089213188498216278042423303776"),
    SCplx("-0.0747518305497207595353164095673027",
          "0.0680061476551414375312525418282261"),
    SCplx("-0.0539516328709526230302181012544576",
          "0.0959633362093703892163383917352083"),
    SCplx("-0.02307090547964999618738026070500468",
          "0.1189633974463241697859087911025986"),
    SCplx("0.01734136312244902786658363880592287",
          "0.1334753468081136578360923388378447"),
    SCplx("0.0655539356392640564131928471189117",
          "0.1356841681074004975008452185529081"),
    SCplx("0.1183956178648062564335394466955881",
          "0.1218478651872330431296928040578044"),
    SCplx("0.171081947924374704523705776522562",
          "0.0887894560166605301375014664087768"),
    SCplx("0.2171839293237958485904223370995976",
          "0.0345162725131430658321272910620352"),
    SCplx("0.2488030861717641981320094361189288",
          "-0.0410623470219280684680945298316815"),
    SCplx("0.2570172817750991023328577966051121",
          "-0.135374739658032750637828890357905"),
    SCplx("0.2326524894156224068277076818573113",
          "-0.2424708628899604180350624135322065"),
    SCplx("0.1674140336764227534379376070251635",
          "-0.352470192834023015320182851246306"),
    SCplx("0.0553741347038412209800985334521121",
          "-0.451323647796996130216035157762073"),
    SCplx("-0.1052406923420646939776269151042025",
          "-0.52106186672583920387016294463469"),
    SCplx("-0.3100885127317852129733160208621357",
          "-0.540709084141827248071658106257859"),
    SCplx("-0.546786531338371567390291103908684",
          "-0.488025059262930630406379796194507"),
    SCplx("-0.793321351840727539475317743432723",
          "-0.34218830709381051292401919573374"),
    SCplx("-1.017182438615685673436995852741598",
          "-0.0874443202484382925675898425446555"),
    SCplx("-1.175675604675829689636805374688275",
          "0.2823929044801788669082333306784941"),
    SCplx("-1.217904981662474342405711985943832",
          "0.758879840920604323543208357390654"),
    SCplx("-1.088882767113071061632224494506188",
          "1.313839581157952012474882926438513"),
    SCplx("-0.736111322768440742169263793923934",
          "1.89498003373886415373901945975135"),
    SCplx("-0.1187586408687252822108284752833194",
          "2.423245595228806831441168365340034"),
    SCplx("0.780801481761037218276265332924586",
          "2.793118589739958630802476604422193"),
    SCplx("1.943794530539885307308531072489097",
          "2.877196946503674682482105087888244"),
    SCplx("3.3015054929555911735824889139625",
          "2.536326157342673313072791165119031"),
    SCplx("4.72338384960969409442436969371819",
          "1.636286720854796846477317847766391"),
    SCplx("6.00947164648774961040237784219608",
          "0.0714658216283239120957038509208224"),
    SCplx("6.89042284409698088294799098196691",
          "-2.204978367766432869558682967865542"),
    SCplx("7.03872810702209649801328983736411",
          "-5.14624083691614653598149402764338"),
    SCplx("6.09468384195989726306527040892002",
          "-8.57569292849396049002493897621126"),
    SCplx("3.70995111535071279848468870251301",
          "-12.15468487686367545128920347836721"),
    SCplx("-0.389953408387590761205136900954351",
          "-15.36152811374213240564060693532176"),
    SCplx("-6.32536043319078317235199974117464",
          "-17.4905346417480338543203153527182"),
    SCplx("-13.96897421269872407767031488664317",
          "-17.68102353122288900342402709208232"),
    SCplx("-22.848322791926494857576181331582",
          "-14.98609794611352943197156664528657"),
    SCplx("-32.058408803291102475845814576345",
          "-8.48919587851461486396359700465686"),
    SCplx("-40.2042003411842490479605946054344",
          "2.527625371177148752645256798506209"),
    SCplx("-45.3973408659080594123131559833813",
          "18.36644578161972340483950468741491"),
    SCplx("-45.3344549118286595430541499834092",
          "38.6597019638501855051153519813229"),
    SCplx("-37.4842907635684529563256304383776",
          "62.1046868740589846824389308842153"),
    SCplx("-19.40610386883035852974498597384871",
          "86.2255767439473451904624487933601"),
    SCplx("10.78942119890393765830358022286489",
          "107.2172645240831101374643769041004"),
    SCplx("53.8440818985220087412488459053112",
          "119.9386471617432578286776756442609"),
    SCplx("108.65516611527461644611256996364",
          "118.1315706581014344097241430379971"),
    SCplx("171.5465181768861334107927068279335",
          "94.9414440202545364929885925342732"),
    SCplx("235.6171384325314199573559446395683",
          "43.8021334802658406324965051783215"),
    SCplx("290.3191083800530435117558700089482",
          "-40.283331411150262423989733798564") };

static Cplx li2s14[64] = {
    SCplx("0.25",
          "-0.5"),
    SCplx("60.",
          "0"),
    SCplx("0.999419237488133274838156864848736",
          "0"),
    SCplx("0.1845853342047610073468488302462845",
          "-0.552346828251386057009577899838716"),
    SCplx("1.023859911587405882639154146707092",
          "-0.3042905910154584397041360290861582"),
    SCplx("0.2085620240911324336425679795866983",
          "-0.2050640005560490225373612134235178"),
    SCplx("0.0361069372486123837373662211051644",
          "-0.1383452403907865175932905152875093"),
    SCplx("-0.02648894998364000268193624662334269",
          "-0.0846118799024913826401381041130302"),
    SCplx("-0.0479680437700611747223682676283933",
          "-0.0402965901113145200734977812554835"),
    SCplx("-0.0477114027446127998770174178682522",
          "-0.00596316191752434583283503130808585"),
    SCplx("-0.0351218424544675096378849230957472",
          "0.0171191210562816482528773701370102"),
    SCplx("-0.01693699861049812567964958209228049",
          "0.02844388140298074336279909217865161"),
    SCplx("0.001294989312556369897430779208377539",
          "0.0289293551845192917139222525056181"),
    SCplx("0.01525585394613717466621305649175867",
          "0.02102523192457376475645218454456426"),
    SCplx("0.02226332636366762531301989747014379",
          "0.00836131831737699910507573149251581"),
    SCplx("0.021581563485058839535816853579508",
          "-0.00494463707555649760558724765581028"),
    SCplx("0.01441096811180761147465845937550302",
          "-0.01514521183162298602634196034501542"),
    SCplx("0.00348114454381898263118265427828852",
          "-0.01967253553632893923147561093901025"),
    SCplx("-0.00770002448776372664401394626747089",
          "-0.01768670527342890527957845578924426"),
    SCplx("-0.01578056916284628342505485611556135",
          "-0.01020777429301455534331887916481074"),
    SCplx("-0.0184551887100455703917457265212095",
          "0.0002230742878924127746876841209414141"),
    SCplx("-0.01507936851606803575765494016086782",
          "0.01028374395781777920672005443668565"),
    SCplx("-0.00683263486035044775287138688524883",
          "0.01682897846099057667339451441422554"),
    SCplx("0.00362997196475718079520695970535177",
          "0.0178098241954861395182551428837549"),
    SCplx("0.01295912627094181315828217068268624",
          "0.01289396711040288135696342339570355"),
    SCplx("0.01811755238113415642869397481692754",
          "0.00359574542190006107033392175327439"),
    SCplx("0.01732558977441398850462339603359778",
          "-0.00714454055808325638136269410090005"),
    SCplx("0.0106599082242268453999814505261167",
          "-0.01583342651467621031403843091275241"),
    SCplx("0.0001044886657457163797527398716491711",
          "-0.01950837904195550530301026136003566"),
    SCplx("-0.01099419147942210407522988444932204",
          "-0.01671143130023920182989019706948209"),
    SCplx("-0.01893565550012342736805014000709021",
          "-0.008041375360861513342123326466193"),
    SCplx("-0.02085088679232896178353495811262615",
          "0.00391860000104693846110137512741031"),
    SCplx("-0.01569954205894419913486883541311038",
          "0.01532017383150417023661137364720427"),
    SCplx("-0.00474342576228877331454414413168419",
          "0.0222343630944222353335926545618193"),
    SCplx("0.00869997386740286480079110913164082",
          "0.0219544597244695912833843962025523"),
    SCplx("0.02020454778341272359966646379633184",
          "0.01400130042203843465366416358816846"),
    SCplx("0.02563353016596710705560308262834636",
          "0.000473219424005588912646012969666898"),
    SCplx("0.0225665515474810257643649685992712",
          "-0.01443602505400158243207112316069217"),
    SCplx("0.0112825226806147195390677729466176",
          "-0.0256704673578564126971578678035783"),
    SCplx("-0.00507551799064007862189980248512523",
          "-0.02895728148798445625884383966737837"),
    SCplx("-0.02129311982099566917243030607167049",
          "-0.02235175544250854594180923164957882"),
    SCplx("-0.031667309517172471826203579748306",
          "-0.007147827591496076722413967378607"),
    SCplx("-0.0319267657534752676543049663759621",
          "0.01222461080808693489805913261341002"),
    SCplx("-0.02087061625200104355980888886758432",
          "0.02939344897218082198127124478382659"),
    SCplx("-0.001131465275086980955628325280309896",
          "0.0380440589365989530422420396877397"),
    SCplx("0.02130232000554192587052289610265472",
          "0.0341303893371103193408694438890664"),
    SCplx("0.0387878622571520036060491502672556",
          "0.01755857190760504083289691312493274"),
    SCplx("0.0445114984248418275157664728686793",
          "-0.00730477451636377323681113793573486"),
    SCplx("0.0349881548561923379451127916620137",
          "-0.0326218731574605438193150947080754"),
    SCplx("0.01170664628507893769196604474832924",
          "-0.0494144833299951301376822326924639"),
    SCplx("-0.01876396521808395346092933449843291",
          "-0.0505927708179964614634905837176356"),
    SCplx("-0.0464446093939434249159913075537801",
          "-0.0337112259521203207968310812729987"),
    SCplx("-0.0610407394850069054359770407207384",
          "-0.002446850464216891694104605978291647"),
    SCplx("-0.0555617885138140729739575093973786",
          "0.033892455023395085581972722951953"),
    SCplx("-0.0292587994752226311404380732681947",
          "0.0629233205374694460537634441405661"),
    SCplx("0.01125310263831136529473758422203868",
          "0.0731858926613163418379110022872063"),
    SCplx("0.0533382488418121297985641829609507",
          "0.0583695275321351389168514796608345"),
    SCplx("0.0820202133759996117215507858536354",
          "0.02029593001154059391243678792843259"),
    SCplx("0.0850211066720839050058031317693631",
          "-0.03057907294926788457640505786382308"),
    SCplx("0.0575594845037690601011860365582091",
          "-0.0776814264780681619989445240555663"),
    SCplx("0.00515822750827609129835628605652963",
          "-0.1033929762043261271032530958338434"),
    SCplx("-0.0568344310898902979019113477063064",
          "-0.0952446237432061522637767970027559"),
    SCplx("-0.1073266084873834229486895538886402",
          "-0.0511756609392527173567347689739879"),
    SCplx("-0.1262418320895555408400973238645278",
          "0.01816751082255048690168162824914039") };

static Double rli2s1[64] = {
     SDouble("-1."),
     SDouble("60."),
     SDouble("0.450498187509539899844359424303392"),
     SDouble("-0.822467033424113218236207583323013"),
     SDouble("0.693147180559945309417232121458177"),
     SDouble("0.0965735902799726547086160607290883"),
     SDouble("0.02271572685331510313907737381939219"),
     SDouble("0.00662012847331966068764136369787748"),
     SDouble("0.00217110277865572855011309095830198"),
     SDouble("0.000767585648879773791760909131918317"),
     SDouble("0.0002859067466588537262712554464061764"),
     SDouble("0.0001106594747550684390587770870339758"),
     SDouble("0.0000441105053378386124966907440302007"),
     SDouble("0.00001799806591516586235813278073829173"),
     SDouble("7.48403719560532941648434612571975e-6"),
     SDouble("3.161267050517006510565196069788561e-6"),
     SDouble("1.353088655605441907188386115702262e-6"),
     SDouble("5.85723463172086166565039854690562e-7"),
     SDouble("2.560316311034708983178467215207148e-7"),
     SDouble("1.128730786386706338396479680923368e-7"),
     SDouble("5.01349965772047142020216170280817e-8"),
     SDouble("2.241705712275216472020995856573726e-8"),
     SDouble("1.008312643902544260043282624356396e-8"),
     SDouble("4.55963160967285468093750072085944e-9"),
     SDouble("2.071853160625933029464286400818519e-9"),
     SDouble("9.45562955915392783536256066582179e-10"),
     SDouble("4.33268560398196852236260743529199e-10"),
     SDouble("1.992568458330885594800397342879461e-10"),
     SDouble("9.19454973741139754341714782497616e-11"),
     SDouble("4.25594053401937263790110367786169e-11"),
     SDouble("1.975640572097336578662601262442309e-11"),
     SDouble("9.1955544625208406527121206391593e-12"),
     SDouble("4.29067044353993227737229381908977e-12"),
     SDouble("2.006676659524282774735746094085627e-12"),
     SDouble("9.40523031135888152298033854491467e-13"),
     SDouble("4.41715066142993202163216264280544e-13"),
     SDouble("2.078461970421926232091699380902249e-13"),
     SDouble("9.79761022745213477911417670055748e-14"),
     SDouble("4.62627842990582107731070442507937e-14"),
     SDouble("2.187942881715286078077371365652563e-14"),
     SDouble("1.036323162061805988381539632046337e-14"),
     SDouble("4.91558070728499152035772764062187e-15"),
     SDouble("2.334763653325111203600811378581638e-15"),
     SDouble("1.110375713565152349260741013988892e-15"),
     SDouble("5.28723438982509463964723512123309e-16"),
     SDouble("2.520538618136668350564347808532419e-16"),
     SDouble("1.202930990011496332008810563677291e-16"),
     SDouble("5.74709843189797262415693395409255e-17"),
     SDouble("2.748505392966501774443853532574837e-17"),
     SDouble("1.315725834645780362204978904904128e-17"),
     SDouble("6.30430339773483290787921751906052e-18"),
     SDouble("3.023394879430515972869658166588405e-18"),
     SDouble("1.451185426618795864003431580752151e-18"),
     SDouble("6.97118110167950369303848390383919e-19"),
     SDouble("3.35143864988137525851261035877311e-19"),
     SDouble("1.612443374751444527034982228810545e-19"),
     SDouble("7.76342828765454615477260018331667e-20"),
     SDouble("3.74047512710344330696013879595678e-20"),
     SDouble("1.803404157410053192248352319379083e-20"),
     SDouble("8.70045459286532323211748894770999e-21"),
     SDouble("4.20013715395087622200032878724413e-21"),
     SDouble("2.02884201732582228301009386091608e-21"),
     SDouble("9.80589595070266502402719691799497e-22"),
     SDouble("4.74211554932991695042921685243543e-22") };

static Double rli2s2[64] = {
     SDouble("-0.5"),
     SDouble("60."),
     SDouble("0.600546184524101630412111535537401"),
     SDouble("-0.448414206923646202443064405915774"),
     SDouble("0.810930216216328763956026230928698"),
     SDouble("0.1442635495496620972893595642620316"),
     SDouble("0.044203251251401314904331270867894"),
     SDouble("0.01692216082771925630711419025245827"),
     SDouble("0.00732237090459772367162961798418015"),
     SDouble("0.00342480198777261215504799156485444"),
     SDouble("0.001690541731471972917700665662554046"),
     SDouble("0.000868174334863985789071076399442799"),
     SDouble("0.000459575420018658608842238075291831"),
     SDouble("0.0002491847588391650428459793673203583"),
     SDouble("0.0001377626539651616489544811215615948"),
     SDouble("0.0000773978967560022797286550355280944"),
     SDouble("0.0000440762885077613962392179855552961"),
     SDouble("0.00002539188650152801884523397139586122"),
     SDouble("0.00001477449870016896057769675827658118"),
     SDouble("8.67169955847374089980531746554652e-6"),
     SDouble("5.1287959310428886447064185804151e-6"),
     SDouble("3.054005210281688073246815295714548e-6"),
     SDouble("1.829580137616389319627914246478101e-6"),
     SDouble("1.102028631299685805273406122119768e-6"),
     SDouble("6.67060917610270608826392995225466e-7"),
     SDouble("4.05576153470350688262161750335027e-7"),
     SDouble("2.475955578524275893924887593575491e-7"),
     SDouble("1.517147174225017854597903369698604e-7"),
     SDouble("9.32816172393729791900765121011054e-8"),
     SDouble("5.75350237915139145084727171907248e-8"),
     SDouble("3.5590476889323873756974640560664e-8"),
     SDouble("2.207542818970887025436033768774108e-8"),
     SDouble("1.372702422740637176755575007885976e-8"),
     SDouble("8.55582712408945692410836553150902e-9"),
     SDouble("5.34440722759988810468680524361655e-9"),
     SDouble("3.34525264481004763425788335832909e-9"),
     SDouble("2.097952056225409500262625183092425e-9"),
     SDouble("1.318104172603367626069627776975981e-9"),
     SDouble("8.29556623972277597808175824954876e-10"),
     SDouble("5.22929168553515641197775644464023e-10"),
     SDouble("3.30142958449158361489548671952625e-10"),
     SDouble("2.087316956445044031090662666190506e-10"),
     SDouble("1.32150719466653473360970748562225e-10"),
     SDouble("8.37751975019621924308054688302701e-11"),
     SDouble("5.31738892255771048357112864366786e-11"),
     SDouble("3.37903483113638311414947839719158e-11"),
     SDouble("2.149682077501501851929976736024515e-11"),
     SDouble("1.369054768012467755645440153169966e-11"),
     SDouble("8.72793734375571673411729026798007e-12"),
     SDouble("5.56964080080822763115083103956149e-12"),
     SDouble("3.55753623774067450689259022686071e-12"),
     SDouble("2.274369422128359605806341177439299e-12"),
     SDouble("1.455278844595946965584204164538795e-12"),
     SDouble("9.3194423481545365785073486980351e-13"),
     SDouble("5.97280032591902370426003544164608e-13"),
     SDouble("3.83086727839793099991639100985078e-13"),
     SDouble("2.458865043358627956830993822590931e-13"),
     SDouble("1.579351860774173210736818387319204e-13"),
     SDouble("1.015122624017817983204924395389475e-13"),
     SDouble("6.52894362393861351230776949701434e-14"),
     SDouble("4.20186491701491594774467409307682e-14"),
     SDouble("2.705867261930432244136722687043166e-14"),
     SDouble("1.743520620413210087375592889965158e-14"),
     SDouble("1.12407504025634834706416670074209e-14") };

static Double rli2s3[64] = {
     SDouble("0"),
     SDouble("60."),
     SDouble("0.901227809639395403924248942006443"),
     SDouble("0"),
     SDouble("1."),
     SDouble("0.25"),
     SDouble("0.1111111111111111111111111111111111"),
     SDouble("0.0625"),
     SDouble("0.04"),
     SDouble("0.02777777777777777777777777777777778"),
     SDouble("0.02040816326530612244897959183673469"),
     SDouble("0.015625"),
     SDouble("0.01234567901234567901234567901234568"),
     SDouble("0.01"),
     SDouble("0.00826446280991735537190082644628099"),
     SDouble("0.00694444444444444444444444444444444"),
     SDouble("0.00591715976331360946745562130177515"),
     SDouble("0.00510204081632653061224489795918367"),
     SDouble("0.00444444444444444444444444444444444"),
     SDouble("0.00390625"),
     SDouble("0.00346020761245674740484429065743945"),
     SDouble("0.00308641975308641975308641975308642"),
     SDouble("0.002770083102493074792243767313019391"),
     SDouble("0.0025"),
     SDouble("0.00226757369614512471655328798185941"),
     SDouble("0.002066115702479338842975206611570248"),
     SDouble("0.001890359168241965973534971644612476"),
     SDouble("0.001736111111111111111111111111111111"),
     SDouble("0.0016"),
     SDouble("0.001479289940828402366863905325443787"),
     SDouble("0.001371742112482853223593964334705075"),
     SDouble("0.001275510204081632653061224489795918"),
     SDouble("0.001189060642092746730083234244946492"),
     SDouble("0.001111111111111111111111111111111111"),
     SDouble("0.001040582726326742976066597294484912"),
     SDouble("0.0009765625"),
     SDouble("0.000918273645546372819100091827364555"),
     SDouble("0.000865051903114186851211072664359862"),
     SDouble("0.000816326530612244897959183673469388"),
     SDouble("0.000771604938271604938271604938271605"),
     SDouble("0.000730460189919649379108838568298028"),
     SDouble("0.000692520775623268698060941828254848"),
     SDouble("0.00065746219592373438527284681130835"),
     SDouble("0.000625"),
     SDouble("0.000594883997620464009518143961927424"),
     SDouble("0.000566893424036281179138321995464853"),
     SDouble("0.0005408328826392644672796106003245"),
     SDouble("0.000516528925619834710743801652892562"),
     SDouble("0.000493827160493827160493827160493827"),
     SDouble("0.000472589792060491493383742911153119"),
     SDouble("0.000452693526482571299230421004979629"),
     SDouble("0.000434027777777777777777777777777778"),
     SDouble("0.000416493127863390254060807996668055"),
     SDouble("0.0004"),
     SDouble("0.000384467512495194156093810073048827"),
     SDouble("0.000369822485207100591715976331360947"),
     SDouble("0.000355998576005695977216091135635457"),
     SDouble("0.000342935528120713305898491083676269"),
     SDouble("0.00033057851239669421487603305785124"),
     SDouble("0.00031887755102040816326530612244898"),
     SDouble("0.0003077870113881194213604185903354878"),
     SDouble("0.0002972651605231866825208085612366231"),
     SDouble("0.0002872737719046251077276644642344154"),
     SDouble("0.0002777777777777777777777777777777778") };

static Double rli2s4[64] = {
     SDouble("0.25"),
     SDouble("60."),
     SDouble("1.202523359207318580502808171013234"),
     SDouble("0.2676526390827326069191838284878116"),
     SDouble("1.15072828980712370975687602397531"),
     SDouble("0.365210087052419247152914618716047"),
     SDouble("0.2112916197120671927774128686090593"),
     SDouble("0.1562485976539218784578848509629456"),
     SDouble("0.1321032529395487543668672423506728"),
     SDouble("0.1215213928078141658278636503262896"),
     SDouble("0.1184652906331863651464558574481489"),
     SDouble("0.1204815487581112271151071574983351"),
     SDouble("0.1265501172778037163157550859271037"),
     SDouble("0.1363437989269931652070120389042824"),
     SDouble("0.1499398814950283562767529657028157"),
     SDouble("0.1677043389146978984321850024131372"),
     SDouble("0.1902529997366184180195977322753987"),
     SDouble("0.2184534528008272877073974898263889"),
     SDouble("0.2534534983163058525209186422136865"),
     SDouble("0.2967312793264798452242914633029146"),
     SDouble("0.350166828432813279364710222394014"),
     SDouble("0.416137547332424663562840418726562"),
     SDouble("0.497642289064083138451279915070527"),
     SDouble("0.598460789987146520649272861762681"),
     SDouble("0.723357516251034619019823653068071"),
     SDouble("0.87834178010028909686561564242373"),
     SDouble("1.070999463419074735320182972365176"),
     SDouble("1.310916102217729233455831136728467"),
     SDouble("1.610216729748250136429888339404521"),
     SDouble("1.984255116062829189608466269295641"),
     SDouble("2.452494348406546472543692933374947"),
     SDouble("3.039632674515288566091549887325601"),
     SDouble("3.7770439596503923849840639959765"),
     SDouble("4.70462199588984455564040911806482"),
     SDouble("5.87314355238065153586300013821693"),
     SDouble("7.34729815511294079403902359555875"),
     SDouble("9.20957531908624703567702456129251"),
     SDouble("11.56525515489353927094704615851561"),
     SDouble("14.54881960398817810394100694802528"),
     SDouble("18.33219377811333650853517372606707"),
     SDouble("23.13534615681704140628678427749709"),
     SDouble("29.23993073548814277648223255180395"),
     SDouble("37.0068540015220989445248927188446"),
     SDouble("46.898908332897372503316393805521"),
     SDouble("59.5099485745308642827189685947662"),
     SDouble("75.6025229046958210353327682751412"),
     SDouble("96.1564322225038393066551215127011"),
     SDouble("122.4314226012310432551875992744055"),
     SDouble("156.048162835836787962765414107317"),
     SDouble("199.0928887672667003289200631314219"),
     SDouble("254.2526924600129747093924293512457"),
     SDouble("324.990507501292801126798000763028"),
     SDouble("415.771534949351112520306130496003"),
     SDouble("532.356354336115487536634196460382"),
     SDouble("682.180513598005162135956802697352"),
     SDouble("874.846307406150708228336289610171"),
     SDouble("1122.760147574292617288717191094205"),
     SDouble("1441.958939674406069207253723609769"),
     SDouble("1853.181907618943984063807381354608"),
     SDouble("2383.261266817584142218122670569032"),
     SDouble("3066.927228808500315461900190070976"),
     SDouble("3949.15158141563053524153056410675"),
     SDouble("5088.19155819551969125027409395441"),
     SDouble("6559.54453839471967229448619848081") };

static Cplx li3s1[64] = {
    SCplx("-1.",
          "0"),
    SCplx("60.",
          "0"),
    SCplx("0.428906220392100540146530350746658",
          "0"),
    SCplx("-0.901542677369695714049803621133587",
          "0"),
    SCplx("0.822467033424113218236207583323013",
          "0"),
    SCplx("0.064659926432083954409487730932418",
          "0"),
    SCplx("0.01091542086139841803678646704524925",
          "0"),
    SCplx("0.002507633932720037742820506829088888",
          "0"),
    SCplx("0.000682081451512098056728132723695616",
          "0"),
    SCplx("0.0002065507464841269555879287766960163",
          "0"),
    SCplx("0.0000673884042892839916809519326082544",
          "0"),
    SCplx("0.00002322651042076677693692601023145053",
          "0"),
    SCplx("8.3502898456739751596256660908476e-6",
          "0"),
    SCplx("3.104210327322716393994025078742775e-6",
          "0"),
    SCplx("1.185821578005572871073406368103275e-6",
          "0"),
    SCplx("4.63333346871331013776926993618023e-7",
          "0"),
    SCplx("1.845179316876127426736867579713624e-7",
          "0"),
    SCplx("7.46888897381088391121101241375321e-8",
          "0"),
    SCplx("3.066139954409583873363345888232584e-8",
          "0"),
    SCplx("1.27430851286229176679159476071358e-8",
          "0"),
    SCplx("5.3538990246644734615886584483433e-9",
          "0"),
    SCplx("2.271182602338407480276976477430797e-9",
          "0"),
    SCplx("9.71801564175745785514506212000899e-10",
          "0"),
    SCplx("4.19055164015686366217139589222656e-10",
          "0"),
    SCplx("1.819748414590891734954900506473183e-10",
          "0"),
    SCplx("7.95281140915881642700456664897803e-11",
          "0"),
    SCplx("3.49589371347629056697716780953473e-11",
          "0"),
    SCplx("1.544945807088958242368699386099118e-11",
          "0"),
    SCplx("6.86120591473045674753792473503369e-12",
          "0"),
    SCplx("3.060948095928747817472178466387716e-12",
          "0"),
    SCplx("1.371305376072359884269096420276435e-12",
          "0"),
    SCplx("6.16744265463583967451413954394309e-13",
          "0"),
    SCplx("2.783891369123969115837058649614259e-13",
          "0"),
    SCplx("1.260871508973192719518392088263861e-13",
          "0"),
    SCplx("5.72883183030740446393364571195469e-14",
          "0"),
    SCplx("2.610671363310647598504363488170274e-14",
          "0"),
    SCplx("1.19302960641337584653993955131498e-14",
          "0"),
    SCplx("5.46628156100651194555912099540348e-15",
          "0"),
    SCplx("2.510784879991430238796238481089816e-15",
          "0"),
    SCplx("1.155963513906717988465591738537496e-15",
          "0"),
    SCplx("5.33385342796999643351015917049303e-16",
          "0"),
    SCplx("2.466322648123928136887419107989695e-16",
          "0"),
    SCplx("1.142678296304085999952426915317684e-16",
          "0"),
    SCplx("5.30420425565206049053413397789332e-17",
          "0"),
    SCplx("2.466599972428467919397347749191308e-17",
          "0"),
    SCplx("1.149006070745624721400450154869351e-17",
          "0"),
    SCplx("5.36113227673245460306405312074152e-18",
          "0"),
    SCplx("2.505354293144225334792573359639917e-18",
          "0"),
    SCplx("1.172546768430359744206753072960686e-18",
          "0"),
    SCplx("5.49555448906547190105768542553967e-19",
          "0"),
    SCplx("2.579211128349652579322460406051322e-19",
          "0"),
    SCplx("1.212081021980944628111738831120978e-19",
          "0"),
    SCplx("5.70325311444493518789120045467814e-20",
          "0"),
    SCplx("2.686817198918444756126513284080277e-20",
          "0"),
    SCplx("1.26723625351229805639099657187494e-20",
          "0"),
    SCplx("5.98358892890643236361821568805594e-21",
          "0"),
    SCplx("2.828345034490377928389603639582158e-21",
          "0"),
    SCplx("1.338296369471195715868944278975699e-21",
          "0"),
    SCplx("6.33877321462002465224029147365816e-22",
          "0"),
    SCplx("3.005216268983857797292514269880188e-22",
          "0"),
    SCplx("1.42609763393759305837203350238931e-22",
          "0"),
    SCplx("6.77348165429897277710390030409471e-23",
          "0"),
    SCplx("3.21996159689420665713587850077772e-23",
          "0"),
    SCplx("1.53197957849552570884574770609893e-23",
          "0") };

static Cplx li3s2[64] = {
    SCplx("-0.5",
          "0"),
    SCplx("60.",
          "0"),
    SCplx("0.570681515425557045484379679066931",
          "0"),
    SCplx("-0.472597844658896874618623193126548",
          "0"),
    SCplx("0.896828413847292404886128811831549",
          "0"),
    SCplx("0.0858981976309636409301025809028504",
          "0"),
    SCplx("0.01835523047484345638056373169577942",
          "0"),
    SCplx("0.00543122008656452711867996210972213",
          "0"),
    SCplx("0.001921087807415540867042263274572104",
          "0"),
    SCplx("0.000761022710826660221193899462893456",
          "0"),
    SCplx("0.000326095507767814049175830060716084",
          "0"),
    SCplx("0.0001480317057256813566325361906146358",
          "0"),
    SCplx("0.0000702398468758811253309362501053971",
          "0"),
    SCplx("0.0000345166403728543038272376351313486",
          "0"),
    SCplx("0.00001745120816170509007752672436238687",
          "0"),
    SCplx("9.03343930226572364971880773744345e-6",
          "0"),
    SCplx("4.76974998018252370276471651095801e-6",
          "0"),
    SCplx("2.561494462087344556674761298165445e-6",
          "0"),
    SCplx("1.395871462359307326428358237127334e-6",
          "0"),
    SCplx("7.70446654402581164841076910041103e-7",
          "0"),
    SCplx("4.30052577878536204429636834718956e-7",
          "0"),
    SCplx("2.424553214324696478441564010896848e-7",
          "0"),
    SCplx("1.379147974213437460997894656736608e-7",
          "0"),
    SCplx("7.90801013389141856268085601321454e-8",
          "0"),
    SCplx("4.5673656712247419739310960049823e-8",
          "0"),
    SCplx("2.65532612133568368817397423473469e-8",
          "0"),
    SCplx("1.55300515846521498379228331570961e-8",
          "0"),
    SCplx("9.13296904954765473997803360463844e-9",
          "0"),
    SCplx("5.39812318133135426397459756331697e-9",
          "0"),
    SCplx("3.20549709953160595456064822937068e-9",
          "0"),
    SCplx("1.911696355282062245192899020215779e-9",
          "0"),
    SCplx("1.14466605023512906165954521322586e-9",
          "0"),
    SCplx("6.87946290818947825662546778109173e-10",
          "0"),
    SCplx("4.14894547089541011777207099087083e-10",
          "0"),
    SCplx("2.510328573288240922069578994260305e-10",
          "0"),
    SCplx("1.523507093496036721080556024118993e-10",
          "0"),
    SCplx("9.27254578410466589818118738697994e-11",
          "0"),
    SCplx("5.65875325017135438904215679182915e-11",
          "0"),
    SCplx("3.46212532831367352116974589854816e-11",
          "0"),
    SCplx("2.123262449652822970006862441872118e-11",
          "0"),
    SCplx("1.305109801737841232457809916810484e-11",
          "0"),
    SCplx("8.03935095757067865893899985617128e-12",
          "0"),
    SCplx("4.96223798682981466310849886745939e-12",
          "0"),
    SCplx("3.068828100985464925013035363434558e-12",
          "0"),
    SCplx("1.901362270119824613156875400346937e-12",
          "0"),
    SCplx("1.180093516635033538272409760835518e-12",
          "0"),
    SCplx("7.33654855223608254230066324798881e-13",
          "0"),
    SCplx("4.56833545436369836936049300277579e-13",
          "0"),
    SCplx("2.848945919589153452769674524672815e-13",
          "0"),
    SCplx("1.779269258432814697107063083933737e-13",
          "0"),
    SCplx("1.112765016162859564060280487886683e-13",
          "0"),
    SCplx("6.96858057593652268412803360919458e-14",
          "0"),
    SCplx("4.36958879314763788806169369377183e-14",
          "0"),
    SCplx("2.743278656185582398264102981637609e-14",
          "0"),
    SCplx("1.724294483440539377573790670648215e-14",
          "0"),
    SCplx("1.085039053702971969756268068715313e-14",
          "0"),
    SCplx("6.83522943719820091628755829233526e-15",
          "0"),
    SCplx("4.31039466057932788444967434202502e-15",
          "0"),
    SCplx("2.720950021595141261330930026815656e-15",
          "0"),
    SCplx("1.719285313783963251882453997711202e-15",
          "0"),
    SCplx("1.087387415175993227450516803567857e-15",
          "0"),
    SCplx("6.88359775685601878870093685262058e-16",
          "0"),
    SCplx("4.36142182049511407901634131348057e-16",
          "0"),
    SCplx("2.765727512263024064146828283294596e-16",
          "0") };

static Cplx li3s3[64] = {
    SCplx("-0.5",
          "0.5"),
    SCplx("60.",
          "0"),
    SCplx("0.541330275163399132123007371926486",
          "0"),
    SCplx("-0.49374428718990121350268245263964",
          "0.446177418695905583034332993780869"),
    SCplx("0.883628960103086085228777426835692",
          "0.0833166526190709448549771192236654"),
    SCplx("0.0784055993453653767854955394473521",
          "0.02532744042400098245011366714567322"),
    SCplx("0.01418370979438804262037424537623396",
          "0.00919005306833766415935006431446124"),
    SCplx("0.003127031190230294709689337757664722",
          "0.00361347068149688228432502748180096"),
    SCplx("0.000656699140397341805591758935891044",
          "0.001471363805468809433283290496641392"),
    SCplx("0.0000723717293228063284093986394621729",
          "0.000603261149220245834643947207289617"),
    SCplx("-0.0000456788438045365654122781105843265",
          "0.0002433526896184369638555447402634746"),
    SCplx("-0.0000506261928148730548037085803981695",
          "0.0000940753950801704871344147843962982"),
    SCplx("-0.0000346884697491841627442855845369231",
          "0.0000334083665729403314099523714668175"),
    SCplx("-0.00002019783763359139169325905406495728",
          "9.86463215931605356357462990266159e-6"),
    SCplx("-0.00001068497866921689716512630503637201",
          "1.51300962959563745394749185586695e-6"),
    SCplx("-5.22339806941276351735697804223395e-6",
          "-9.18629404804792838109810846251606e-7"),
    SCplx("-2.345874470726230815726209957275396e-6",
          "-1.250438295028625199085633484044211e-6"),
    SCplx("-9.38147921348912982328642184179109e-7",
          "-9.77798957213107940375674591202349e-7"),
    SCplx("-3.034240866370421615161744618234663e-7",
          "-6.31776851898429527424192704013331e-7"),
    SCplx("-4.76906339356212257148425778518493e-8",
          "-3.64020089368508374591442777729507e-7"),
    SCplx("3.62760778260492837079913566175957e-8",
          "-1.910633777977180480501434873080623e-7"),
    SCplx("5.04200282256770762271076641986487e-8",
          "-9.10133501551245399671501485529573e-8"),
    SCplx("4.1233440728133431252114081231627e-8",
          "-3.81301241602378050172992909458447e-8"),
    SCplx("2.780774763891651894390606415380592e-8",
          "-1.266773931429271385053178931823805e-8"),
    SCplx("1.664812888481316049953099188729256e-8",
          "-1.811062890545967222142131989015458e-9"),
    SCplx("9.03305881595502573146131645651681e-9",
          "1.934315369927113109755318288683663e-9"),
    SCplx("4.42196353717771158049075766060879e-9",
          "2.593569573425165014802995869727057e-9"),
    SCplx("1.887622822232091673753260396424925e-9",
          "2.149228751155638874970238193985935e-9"),
    SCplx("6.25974869133509907379915182175025e-10",
          "1.476976233660462220030460182345299e-9"),
    SCplx("7.30619576793453430289181142510956e-11",
          "9.00836347876065669611211043368026e-10"),
    SCplx("-1.211322920186739779288393106516044e-10",
          "4.96846064615700028865979038866345e-10"),
    SCplx("-1.541526803281320820469434735293016e-10",
          "2.462546625814474972758796894486727e-10"),
    SCplx("-1.276362853291899479219511162475666e-10",
          "1.056038713991074013507506003027965e-10"),
    SCplx("-8.83447202804001674264656963572445e-11",
          "3.43526068428204477639228892382068e-11"),
    SCplx("-5.43438139898607044236845872096666e-11",
          "2.741998167605518358521663288972713e-12"),
    SCplx("-3.019451896491736080374639018563992e-11",
          "-8.35989677970259733801482092505919e-12"),
    SCplx("-1.502586904485023054901722905748048e-11",
          "-1.007559244563595418261097184897037e-11"),
    SCplx("-6.41770866709424250897962118250929e-12",
          "-8.27828934995207021756987864897193e-12"),
    SCplx("-2.020486424751579268421241657474754e-12",
          "-5.73445675514977971213117563163782e-12"),
    SCplx("-6.36780650600071924611754206315582e-14",
          "-3.53701116443447974538468840556357e-12"),
    SCplx("6.15174043414613600195013716410862e-13",
          "-1.969104636261815664921266968746374e-12"),
    SCplx("7.04083669057453068314446878654996e-13",
          "-9.78646150589552962147547434371026e-13"),
    SCplx("5.72019919237447321627723315577448e-13",
          "-4.13785139307684812976677420574356e-13"),
    SCplx("3.95065184426990706199833909931395e-13",
          "-1.245092931075660740828769669516011e-13"),
    SCplx("2.434486840621849370072199670929339e-13",
          "3.81370852107524628863811780300964e-15"),
    SCplx("1.353178541567928518032697901420644e-13",
          "4.7360544386916704092551891138446e-14"),
    SCplx("6.69192019582787054261779671179021e-14",
          "5.16910422974801284666337596474077e-14"),
    SCplx("2.787538790656930354893634540548575e-14",
          "4.14513532203170508055408134521626e-14"),
    SCplx("7.90926230399383081351622002843478e-15",
          "2.847600158254179118991629493375201e-14"),
    SCplx("-8.78680167086246449606546553176331e-16",
          "1.748874075255427073373776835749055e-14"),
    SCplx("-3.77010373475250456480362994970618e-15",
          "9.68144501200208780035039929536904e-15"),
    SCplx("-3.94110263784189332690254613424525e-15",
          "4.75071005716274500290762808079733e-15"),
    SCplx("-3.116764484264337653872864306784809e-15",
          "1.941409308015412298959346647589399e-15"),
    SCplx("-2.126487775839882296190114115629645e-15",
          "5.11083010653232803417289958856811e-16"),
    SCplx("-1.299403160041867976358906029762714e-15",
          "-1.111959221140312617279429175685622e-16"),
    SCplx("-7.15077265243868310864242078558321e-16",
          "-3.079252926980583285837231779394024e-16"),
    SCplx("-3.4737919585590239621290831712694e-16",
          "-3.095584737080748573842352059184571e-16"),
    SCplx("-1.38706530784993385264204944364986e-16",
          "-2.413492613094491489992377988561386e-16"),
    SCplx("-3.31708715949651669029828618205049e-17",
          "-1.633726020283670624073973011700765e-16"),
    SCplx("1.206266221678989893123517322592329e-17",
          "-9.92017217383147907681011938317033e-17"),
    SCplx("2.566648568661692025064685392357105e-17",
          "-5.41901579962321285459448570603366e-17"),
    SCplx("2.490430385180752202083029451415854e-17",
          "-2.601012598905117837972487446501217e-17"),
    SCplx("1.91416125206598533387473921973498e-17",
          "-1.01057621558297601848548588425567e-17"),
    SCplx("1.284639136034622817718604401205009e-17",
          "-2.130956781101593625550022850535993e-18") };

static Cplx li3s4[64] = {
    SCplx("-0.5",
          "-0.5"),
    SCplx("60.",
          "0"),
    SCplx("0.541330275163399132123007371926486",
          "0"),
    SCplx("-0.49374428718990121350268245263964",
          "-0.446177418695905583034332993780869"),
    SCplx("0.883628960103086085228777426835692",
          "-0.0833166526190709448549771192236654"),
    SCplx("0.0784055993453653767854955394473521",
          "-0.02532744042400098245011366714567322"),
    SCplx("0.01418370979438804262037424537623396",
          "-0.00919005306833766415935006431446124"),
    SCplx("0.003127031190230294709689337757664722",
          "-0.00361347068149688228432502748180096"),
    SCplx("0.000656699140397341805591758935891044",
          "-0.001471363805468809433283290496641392"),
    SCplx("0.0000723717293228063284093986394621729",
          "-0.000603261149220245834643947207289617"),
    SCplx("-0.0000456788438045365654122781105843265",
          "-0.0002433526896184369638555447402634746"),
    SCplx("-0.0000506261928148730548037085803981695",
          "-0.0000940753950801704871344147843962982"),
    SCplx("-0.0000346884697491841627442855845369231",
          "-0.0000334083665729403314099523714668175"),
    SCplx("-0.00002019783763359139169325905406495728",
          "-9.86463215931605356357462990266159e-6"),
    SCplx("-0.00001068497866921689716512630503637201",
          "-1.51300962959563745394749185586695e-6"),
    SCplx("-5.22339806941276351735697804223395e-6",
          "9.18629404804792838109810846251606e-7"),
    SCplx("-2.345874470726230815726209957275396e-6",
          "1.250438295028625199085633484044211e-6"),
    SCplx("-9.38147921348912982328642184179109e-7",
          "9.77798957213107940375674591202349e-7"),
    SCplx("-3.034240866370421615161744618234663e-7",
          "6.31776851898429527424192704013331e-7"),
    SCplx("-4.76906339356212257148425778518493e-8",
          "3.64020089368508374591442777729507e-7"),
    SCplx("3.62760778260492837079913566175957e-8",
          "1.910633777977180480501434873080623e-7"),
    SCplx("5.04200282256770762271076641986487e-8",
          "9.10133501551245399671501485529573e-8"),
    SCplx("4.1233440728133431252114081231627e-8",
          "3.81301241602378050172992909458447e-8"),
    SCplx("2.780774763891651894390606415380592e-8",
          "1.266773931429271385053178931823805e-8"),
    SCplx("1.664812888481316049953099188729256e-8",
          "1.811062890545967222142131989015458e-9"),
    SCplx("9.03305881595502573146131645651681e-9",
          "-1.934315369927113109755318288683663e-9"),
    SCplx("4.42196353717771158049075766060879e-9",
          "-2.593569573425165014802995869727057e-9"),
    SCplx("1.887622822232091673753260396424925e-9",
          "-2.149228751155638874970238193985935e-9"),
    SCplx("6.25974869133509907379915182175025e-10",
          "-1.476976233660462220030460182345299e-9"),
    SCplx("7.30619576793453430289181142510956e-11",
          "-9.00836347876065669611211043368026e-10"),
    SCplx("-1.211322920186739779288393106516044e-10",
          "-4.96846064615700028865979038866345e-10"),
    SCplx("-1.541526803281320820469434735293016e-10",
          "-2.462546625814474972758796894486727e-10"),
    SCplx("-1.276362853291899479219511162475666e-10",
          "-1.056038713991074013507506003027965e-10"),
    SCplx("-8.83447202804001674264656963572445e-11",
          "-3.43526068428204477639228892382068e-11"),
    SCplx("-5.43438139898607044236845872096666e-11",
          "-2.741998167605518358521663288972713e-12"),
    SCplx("-3.019451896491736080374639018563992e-11",
          "8.35989677970259733801482092505919e-12"),
    SCplx("-1.502586904485023054901722905748048e-11",
          "1.007559244563595418261097184897037e-11"),
    SCplx("-6.41770866709424250897962118250929e-12",
          "8.27828934995207021756987864897193e-12"),
    SCplx("-2.020486424751579268421241657474754e-12",
          "5.73445675514977971213117563163782e-12"),
    SCplx("-6.36780650600071924611754206315582e-14",
          "3.53701116443447974538468840556357e-12"),
    SCplx("6.15174043414613600195013716410862e-13",
          "1.969104636261815664921266968746374e-12"),
    SCplx("7.04083669057453068314446878654996e-13",
          "9.78646150589552962147547434371026e-13"),
    SCplx("5.72019919237447321627723315577448e-13",
          "4.13785139307684812976677420574356e-13"),
    SCplx("3.95065184426990706199833909931395e-13",
          "1.245092931075660740828769669516011e-13"),
    SCplx("2.434486840621849370072199670929339e-13",
          "-3.81370852107524628863811780300964e-15"),
    SCplx("1.353178541567928518032697901420644e-13",
          "-4.7360544386916704092551891138446e-14"),
    SCplx("6.69192019582787054261779671179021e-14",
          "-5.16910422974801284666337596474077e-14"),
    SCplx("2.787538790656930354893634540548575e-14",
          "-4.14513532203170508055408134521626e-14"),
    SCplx("7.90926230399383081351622002843478e-15",
          "-2.847600158254179118991629493375201e-14"),
    SCplx("-8.78680167086246449606546553176331e-16",
          "-1.748874075255427073373776835749055e-14"),
    SCplx("-3.77010373475250456480362994970618e-15",
          "-9.68144501200208780035039929536904e-15"),
    SCplx("-3.94110263784189332690254613424525e-15",
          "-4.75071005716274500290762808079733e-15"),
    SCplx("-3.116764484264337653872864306784809e-15",
          "-1.941409308015412298959346647589399e-15"),
    SCplx("-2.126487775839882296190114115629645e-15",
          "-5.11083010653232803417289958856811e-16"),
    SCplx("-1.299403160041867976358906029762714e-15",
          "1.111959221140312617279429175685622e-16"),
    SCplx("-7.15077265243868310864242078558321e-16",
          "3.079252926980583285837231779394024e-16"),
    SCplx("-3.4737919585590239621290831712694e-16",
          "3.095584737080748573842352059184571e-16"),
    SCplx("-1.38706530784993385264204944364986e-16",
          "2.413492613094491489992377988561386e-16"),
    SCplx("-3.31708715949651669029828618205049e-17",
          "1.633726020283670624073973011700765e-16"),
    SCplx("1.206266221678989893123517322592329e-17",
          "9.92017217383147907681011938317033e-17"),
    SCplx("2.566648568661692025064685392357105e-17",
          "5.41901579962321285459448570603366e-17"),
    SCplx("2.490430385180752202083029451415854e-17",
          "2.601012598905117837972487446501217e-17"),
    SCplx("1.91416125206598533387473921973498e-17",
          "1.01057621558297601848548588425567e-17"),
    SCplx("1.284639136034622817718604401205009e-17",
          "2.130956781101593625550022850535993e-18") };

static Cplx li3s5[64] = {
    SCplx("0",
          "0"),
    SCplx("60.",
          "0"),
    SCplx("0.854544147572749789985743353149954",
          "0"),
    SCplx("0",
          "0"),
    SCplx("1.",
          "0"),
    SCplx("0.125",
          "0"),
    SCplx("0.037037037037037037037037037037037",
          "0"),
    SCplx("0.015625",
          "0"),
    SCplx("0.008",
          "0"),
    SCplx("0.00462962962962962962962962962962963",
          "0"),
    SCplx("0.002915451895043731778425655976676385",
          "0"),
    SCplx("0.001953125",
          "0"),
    SCplx("0.001371742112482853223593964334705075",
          "0"),
    SCplx("0.001",
          "0"),
    SCplx("0.000751314800901577761081893313298272",
          "0"),
    SCplx("0.000578703703703703703703703703703704",
          "0"),
    SCplx("0.000455166135639508420573509330905781",
          "0"),
    SCplx("0.000364431486880466472303206997084548",
          "0"),
    SCplx("0.0002962962962962962962962962962962963",
          "0"),
    SCplx("0.000244140625",
          "0"),
    SCplx("0.0002035416242621616120496641563199674",
          "0"),
    SCplx("0.0001714677640603566529492455418381344",
          "0"),
    SCplx("0.0001457938474996355153812509112115469",
          "0"),
    SCplx("0.000125",
          "0"),
    SCplx("0.0001079796998164345103120613324694957",
          "0"),
    SCplx("0.000093914350112697220135236664162284",
          "0"),
    SCplx("0.0000821895290539985205884770280266294",
          "0"),
    SCplx("0.000072337962962962962962962962962963",
          "0"),
    SCplx("0.000064",
          "0"),
    SCplx("0.0000568957669549385525716886663632226",
          "0"),
    SCplx("0.0000508052634252908601331097901742621",
          "0"),
    SCplx("0.0000455539358600583090379008746355685",
          "0"),
    SCplx("0.0000410020911066464389683873877567756",
          "0"),
    SCplx("0.000037037037037037037037037037037037",
          "0"),
    SCplx("0.0000335671847202175153569870094995133",
          "0"),
    SCplx("0.000030517578125",
          "0"),
    SCplx("0.00002782647410746584300303308567771378",
          "0"),
    SCplx("0.00002544270303277020150620801953999593",
          "0"),
    SCplx("0.00002332361516034985422740524781341108",
          "0"),
    SCplx("0.0000214334705075445816186556927297668",
          "0"),
    SCplx("0.00001974216729512565889483347481886562",
          "0"),
    SCplx("0.00001822423093745443942265636390144336",
          "0"),
    SCplx("0.00001685800502368549705827812336688076",
          "0"),
    SCplx("0.000015625",
          "0"),
    SCplx("0.00001450936579562107340288156004701035",
          "0"),
    SCplx("0.00001349746247705431378900766655868697",
          "0"),
    SCplx("0.00001257750889858754575068861861219767",
          "0"),
    SCplx("0.0000117392937640871525169045830202855",
          "0"),
    SCplx("0.0000109739368998628257887517146776406",
          "0"),
    SCplx("0.00001027369113174981507355962850332868",
          "0"),
    SCplx("9.63177715920364466447704265914104e-6",
          "0"),
    SCplx("9.04224537037037037037037037037037e-6",
          "0"),
    SCplx("8.49985975231408681756751013608275e-6",
          "0"),
    SCplx("8.e-6",
          "0"),
    SCplx("7.53857867637635600183941319703583e-6",
          "0"),
    SCplx("7.11197086936731907146108329540282e-6",
          "0"),
    SCplx("6.7169542642584146644545497289709e-6",
          "0"),
    SCplx("6.35065792816135751663872377178276e-6",
          "0"),
    SCplx("6.01051840721262208865514650638618e-6",
          "0"),
    SCplx("5.69424198250728862973760932944606e-6",
          "0"),
    SCplx("5.39977212961613019930558930413137e-6",
          "0"),
    SCplx("5.12526138833080487104842346959695e-6",
          "0"),
    SCplx("4.86904698143432385979092312261721e-6",
          "0"),
    SCplx("4.62962962962962962962962962962963e-6",
          "0") };

static Cplx li3s6[64] = {
    SCplx("0",
          "1."),
    SCplx("60.",
          "0"),
    SCplx("0.603334384925279892553842597415471",
          "0"),
    SCplx("-0.1126928346712119642562254526416984",
          "0.968946146259369380483634845846919"),
    SCplx("0.915965594177219015054603514932384",
          "0.2056167583560283045590518958307531"),
    SCplx("0.0704784159619721750747820824491676",
          "0.0652837153898853527194713345562542"),
    SCplx("0.00404388363965114978962925126580982",
          "0.02141454235464355916795739842095976"),
    SCplx("-0.00327537262264705726835272054314384",
          "0.00598275967952572147686034226768034"),
    SCplx("-0.002389449246826325995604649438471395",
          "0.000884355721217054783220353862363845"),
    SCplx("-0.000990065647237346051285315083222483",
          "-0.000393368707825770872414791614944242"),
    SCplx("-0.0002089022965275541026366664137015452",
          "-0.000434177135410439757245760688894947"),
    SCplx("0.0000690670718179564296980871373826928",
          "-0.0002203223059357471680988537223482142"),
    SCplx("0.0001010262882481677857116280691922022",
          "-0.000056361938727574277358933970018859"),
    SCplx("0.000058124102462978621517716380059753",
          "0.0000150710502453539161728050706235692"),
    SCplx("0.00001679461435692840315987898148970916",
          "0.00002732763826191090363700216743275697"),
    SCplx("-3.78995600154209536648380811357242e-6",
          "0.00001713379500746858141827690747333133"),
    SCplx("-8.1815675603746553497026612623724e-6",
          "5.38565274237856131014279919591704e-6"),
    SCplx("-5.46157951737231222657552073458316e-6",
          "-1.053532835419160793524671615996246e-6"),
    SCplx("-1.826133178349216726709344495394359e-6",
          "-2.634953360205803327109296357623407e-6"),
    SCplx("3.155630261856302120155910482828451e-7",
          "-1.845102725159793774729644908108734e-6"),
    SCplx("8.96596764279475301800127559895347e-7",
          "-6.46796244086641532254381815626135e-7"),
    SCplx("6.51948374627866777355227146819184e-7",
          "1.001453827447007777094198190374314e-7"),
    SCplx("2.37237332939338979786057867195554e-7",
          "3.18460981263636624958497571768534e-7"),
    SCplx("-3.32810432865992407440268352206943e-8",
          "2.387315911084050271658059409530468e-7"),
    SCplx("-1.170712798992025614341695656428382e-7",
          "8.95408908496093812987289657631185e-8"),
    SCplx("-8.99978340609380380861826268621705e-8",
          "-1.148427608192942538635848406334408e-8"),
    SCplx("-3.46103185114723279424474593465021e-8",
          "-4.42666602010504973096720415313041e-8"),
    SCplx("4.08884351919067804673581808624869e-9",
          "-3.47562808157616459785469192709437e-8"),
    SCplx("1.713569414166929921678717649974434e-8",
          "-1.36500632901665543132076568754885e-8"),
    SCplx("1.369842362437106603374237572844e-8",
          "1.494780882563359164494254941728097e-9"),
    SCplx("5.4770895844220765788783522216649e-9",
          "6.76639269168367110397094682155431e-9"),
    SCplx("-5.58959750958323691762670514839647e-10",
          "5.4936177945635623661426026462697e-9"),
    SCplx("-2.71774846550689609022745900624265e-9",
          "2.230715410306631966610486511659409e-9"),
    SCplx("-2.236517251792663202962803811469787e-9",
          "-2.131515661437544161956198421191473e-10"),
    SCplx("-9.20449362628430647431825406276462e-10",
          "-1.107821070357766228194941197993432e-9"),
    SCplx("8.26856022511482407763209426237613e-11",
          "-9.22533820658341393349771204142495e-10"),
    SCplx("4.57440665667770231584365545445604e-10",
          "-3.84188326192584715560805828421546e-10"),
    SCplx("3.8495263652864974459258569270138e-10",
          "3.2562919343338288732886258412572e-11"),
    SCplx("1.620006562805333917810377646236818e-10",
          "1.910481051380646543645112759650739e-10"),
    SCplx("-1.299676673119605995338545293083949e-11",
          "1.622860022832671545167687290825921e-10"),
    SCplx("-8.06012518362979508892779138886385e-11",
          "6.89360680050777033987249750709919e-11"),
    SCplx("-6.90443217861430958760781841303978e-11",
          "-5.24987357804163093755858643113321e-12"),
    SCplx("-2.957558098345935230019771005285423e-11",
          "-3.43136821474831044584897755822938e-11"),
    SCplx("2.14358130109046938704352448034218e-12",
          "-2.961724491410730265166120512180414e-11"),
    SCplx("1.472734612962021043926358593786558e-11",
          "-1.278305246019247695612743966242519e-11"),
    SCplx("1.279929697554455109789132769306711e-11",
          "8.83812214806640317152404590455842e-13"),
    SCplx("5.56230613109385584251898857369935e-12",
          "6.36758775240566412667742528813579e-12"),
    SCplx("-3.67639201999003301440638148819198e-13",
          "5.56871457957927084217101187010822e-12"),
    SCplx("-2.771574371513091393393939550601116e-12",
          "2.43521655065904038394887538801476e-12"),
    SCplx("-2.437771840564961502957731016084492e-12",
          "-1.541661506494988792751927147961157e-13"),
    SCplx("-1.072156925228729564538541369743883e-12",
          "-1.213739170291247747197106812282771e-12"),
    SCplx("6.51279692852771997960970950590456e-14",
          "-1.07318581576547671462222977505703e-12"),
    SCplx("5.3450201559056986266781828737248e-13",
          "-4.74482294150175318397612635317878e-13"),
    SCplx("4.74900307146295484016623358917788e-13",
          "2.770120839931437011041751761224544e-14"),
    SCplx("2.109834105423444642074780695817109e-13",
          "2.365936749593011693803222630892078e-13"),
    SCplx("-1.185642980754962799264011307618359e-14",
          "2.111546459079924624467433372722498e-13"),
    SCplx("-1.052238031243304967451866133630378e-13",
          "9.42298545965136812765838939184986e-14"),
    SCplx("-9.43005362822623429729545519644087e-14",
          "-5.10422845970915301571262032884055e-15"),
    SCplx("-4.22573867142274980898253533058053e-14",
          "-4.70033147079177363926420423820876e-14"),
    SCplx("2.209255803535661546997912517012837e-15",
          "-4.22867690852133351496232183330261e-14"),
    SCplx("2.108189565852825793892966921532018e-14",
          "-1.902247557504629391739675022786216e-14"),
    SCplx("1.903477021621242063438187940096305e-14",
          "9.61035113536445963529215584847962e-16"),
    SCplx("8.59350955962679694012955262537268e-15",
          "9.49149886749974294447276325788585e-15"),
    SCplx("-4.20014032489305799896848153770141e-16",
          "8.5986856140044087847922356030675e-15") };

static Cplx li3s7[64] = {
    SCplx("0",
          "-1."),
    SCplx("60.",
          "0"),
    SCplx("0.603334384925279892553842597415471",
          "0"),
    SCplx("-0.1126928346712119642562254526416984",
          "-0.968946146259369380483634845846919"),
    SCplx("0.915965594177219015054603514932384",
          "-0.2056167583560283045590518958307531"),
    SCplx("0.0704784159619721750747820824491676",
          "-0.0652837153898853527194713345562542"),
    SCplx("0.00404388363965114978962925126580982",
          "-0.02141454235464355916795739842095976"),
    SCplx("-0.00327537262264705726835272054314384",
          "-0.00598275967952572147686034226768034"),
    SCplx("-0.002389449246826325995604649438471395",
          "-0.000884355721217054783220353862363845"),
    SCplx("-0.000990065647237346051285315083222483",
          "0.000393368707825770872414791614944242"),
    SCplx("-0.0002089022965275541026366664137015452",
          "0.000434177135410439757245760688894947"),
    SCplx("0.0000690670718179564296980871373826928",
          "0.0002203223059357471680988537223482142"),
    SCplx("0.0001010262882481677857116280691922022",
          "0.000056361938727574277358933970018859"),
    SCplx("0.000058124102462978621517716380059753",
          "-0.0000150710502453539161728050706235692"),
    SCplx("0.00001679461435692840315987898148970916",
          "-0.00002732763826191090363700216743275697"),
    SCplx("-3.78995600154209536648380811357242e-6",
          "-0.00001713379500746858141827690747333133"),
    SCplx("-8.1815675603746553497026612623724e-6",
          "-5.38565274237856131014279919591704e-6"),
    SCplx("-5.46157951737231222657552073458316e-6",
          "1.053532835419160793524671615996246e-6"),
    SCplx("-1.826133178349216726709344495394359e-6",
          "2.634953360205803327109296357623407e-6"),
    SCplx("3.155630261856302120155910482828451e-7",
          "1.845102725159793774729644908108734e-6"),
    SCplx("8.96596764279475301800127559895347e-7",
          "6.46796244086641532254381815626135e-7"),
    SCplx("6.51948374627866777355227146819184e-7",
          "-1.001453827447007777094198190374314e-7"),
    SCplx("2.37237332939338979786057867195554e-7",
          "-3.18460981263636624958497571768534e-7"),
    SCplx("-3.32810432865992407440268352206943e-8",
          "-2.387315911084050271658059409530468e-7"),
    SCplx("-1.170712798992025614341695656428382e-7",
          "-8.95408908496093812987289657631185e-8"),
    SCplx("-8.99978340609380380861826268621705e-8",
          "1.148427608192942538635848406334408e-8"),
    SCplx("-3.46103185114723279424474593465021e-8",
          "4.42666602010504973096720415313041e-8"),
    SCplx("4.08884351919067804673581808624869e-9",
          "3.47562808157616459785469192709437e-8"),
    SCplx("1.713569414166929921678717649974434e-8",
          "1.36500632901665543132076568754885e-8"),
    SCplx("1.369842362437106603374237572844e-8",
          "-1.494780882563359164494254941728097e-9"),
    SCplx("5.4770895844220765788783522216649e-9",
          "-6.76639269168367110397094682155431e-9"),
    SCplx("-5.58959750958323691762670514839647e-10",
          "-5.4936177945635623661426026462697e-9"),
    SCplx("-2.71774846550689609022745900624265e-9",
          "-2.230715410306631966610486511659409e-9"),
    SCplx("-2.236517251792663202962803811469787e-9",
          "2.131515661437544161956198421191473e-10"),
    SCplx("-9.20449362628430647431825406276462e-10",
          "1.107821070357766228194941197993432e-9"),
    SCplx("8.26856022511482407763209426237613e-11",
          "9.22533820658341393349771204142495e-10"),
    SCplx("4.57440665667770231584365545445604e-10",
          "3.84188326192584715560805828421546e-10"),
    SCplx("3.8495263652864974459258569270138e-10",
          "-3.2562919343338288732886258412572e-11"),
    SCplx("1.620006562805333917810377646236818e-10",
          "-1.910481051380646543645112759650739e-10"),
    SCplx("-1.299676673119605995338545293083949e-11",
          "-1.622860022832671545167687290825921e-10"),
    SCplx("-8.06012518362979508892779138886385e-11",
          "-6.89360680050777033987249750709919e-11"),
    SCplx("-6.90443217861430958760781841303978e-11",
          "5.24987357804163093755858643113321e-12"),
    SCplx("-2.957558098345935230019771005285423e-11",
          "3.43136821474831044584897755822938e-11"),
    SCplx("2.14358130109046938704352448034218e-12",
          "2.961724491410730265166120512180414e-11"),
    SCplx("1.472734612962021043926358593786558e-11",
          "1.278305246019247695612743966242519e-11"),
    SCplx("1.279929697554455109789132769306711e-11",
          "-8.83812214806640317152404590455842e-13"),
    SCplx("5.56230613109385584251898857369935e-12",
          "-6.36758775240566412667742528813579e-12"),
    SCplx("-3.67639201999003301440638148819198e-13",
          "-5.56871457957927084217101187010822e-12"),
    SCplx("-2.771574371513091393393939550601116e-12",
          "-2.43521655065904038394887538801476e-12"),
    SCplx("-2.437771840564961502957731016084492e-12",
          "1.541661506494988792751927147961157e-13"),
    SCplx("-1.072156925228729564538541369743883e-12",
          "1.213739170291247747197106812282771e-12"),
    SCplx("6.51279692852771997960970950590456e-14",
          "1.07318581576547671462222977505703e-12"),
    SCplx("5.3450201559056986266781828737248e-13",
          "4.74482294150175318397612635317878e-13"),
    SCplx("4.74900307146295484016623358917788e-13",
          "-2.770120839931437011041751761224544e-14"),
    SCplx("2.109834105423444642074780695817109e-13",
          "-2.365936749593011693803222630892078e-13"),
    SCplx("-1.185642980754962799264011307618359e-14",
          "-2.111546459079924624467433372722498e-13"),
    SCplx("-1.052238031243304967451866133630378e-13",
          "-9.42298545965136812765838939184986e-14"),
    SCplx("-9.43005362822623429729545519644087e-14",
          "5.10422845970915301571262032884055e-15"),
    SCplx("-4.22573867142274980898253533058053e-14",
          "4.70033147079177363926420423820876e-14"),
    SCplx("2.209255803535661546997912517012837e-15",
          "4.22867690852133351496232183330261e-14"),
    SCplx("2.108189565852825793892966921532018e-14",
          "1.902247557504629391739675022786216e-14"),
    SCplx("1.903477021621242063438187940096305e-14",
          "-9.61035113536445963529215584847962e-16"),
    SCplx("8.59350955962679694012955262537268e-15",
          "-9.49149886749974294447276325788585e-15"),
    SCplx("-4.20014032489305799896848153770141e-16",
          "-8.5986856140044087847922356030675e-15") };

static Cplx li3s8[64] = {
    SCplx("0",
          "0.5"),
    SCplx("60.",
          "0"),
    SCplx("0.763853895180629234896574269282546",
          "0"),
    SCplx("-0.03033900041736453814384386223817259",
          "0.495599953571453580645107055236821"),
    SCplx("0.974444716589044714220468995386676",
          "0.117950148843131726910541396974516"),
    SCplx("0.1051934024710780288557536933353185",
          "0.0471494985874324817919565324642471"),
    SCplx("0.02199748055116484589639959866262302",
          "0.02235357083757720898520165132031428"),
    SCplx("0.00437394286749434934466746281297224",
          "0.01119303282782209046360770660888707"),
    SCplx("-0.0002783602591384640179156342454956818",
          "0.00555013420328982100509853491955465"),
    SCplx("-0.00134599115921485108000501742432316",
          "0.002563389255271734268616204695805362"),
    SCplx("-0.001307319228802745839259582009425617",
          "0.00098739493601480376069502837963827"),
    SCplx("-0.000965010808600586427986029896369646",
          "0.0001972610675660117607527895919138656"),
    SCplx("-0.000601467808389418749065144903466747",
          "-0.0001517021949140365859979192242803568"),
    SCplx("-0.0003103837262006103361006707871204475",
          "-0.000260553734114034738458002277009722"),
    SCplx("-0.0001110189803975214815632270213492779",
          "-0.0002491245656317353881153803534883343"),
    SCplx("6.68605546680011264422279138963228e-6",
          "-0.0001880132571914304535258469292973877"),
    SCplx("0.0000625276219755019498638239469872859",
          "-0.0001167968272662872507870420819662266"),
    SCplx("0.0000771514603807522594944121673176309",
          "-0.0000553476733307015045022102512832938"),
    SCplx("0.0000681626912247785793593432951415678",
          "-0.0000113171669727835727492465333045872"),
    SCplx("0.0000487669822462264036596698583714848",
          "0.00001476053123162600689897071926751887"),
    SCplx("0.00002773806604714799968001229943884435",
          "0.00002599182630434672900516159141072695"),
    SCplx("0.00001005147744810329216898898499857763",
          "0.00002683324063470420491999940032785188"),
    SCplx("-2.208184884997161966767362650570732e-6",
          "0.00002168727812164841359979010200776383"),
    SCplx("-8.90675043744470229025041806515614e-6",
          "0.00001415295466159975165479497030518781"),
    SCplx("-0.00001102763235651941578550780470260969",
          "6.73929952919080226075424150799253e-6"),
    SCplx("-0.00001001747160965429812428457311907568",
          "8.8143371548691233122838266321777e-7"),
    SCplx("-7.33112350816118266278159395618689e-6",
          "-2.871061925141120028486216520331235e-6"),
    SCplx("-4.16301729366742679442245042422488e-6",
          "-4.59333985310974320133354037985668e-6"),
    SCplx("-1.33173781570168452975216459635506e-6",
          "-4.72222486673428159387820965388848e-6"),
    SCplx("7.2427185303583593233480185837844e-7",
          "-3.83408414283053640552196968655337e-6"),
    SCplx("1.882340001051824242844507290387322e-6",
          "-2.484193045406411246535859838036426e-6"),
    SCplx("2.23947933290800808921436671344141e-6",
          "-1.110979486825512006493286546151152e-6"),
    SCplx("2.012784384708267430184458363651908e-6",
          "2.936871989642835628478522236079844e-9"),
    SCplx("1.454741449303099251480774274528486e-6",
          "7.27171266666505707761188635553756e-7"),
    SCplx("7.92768938817852113822105542398108e-7",
          "1.053548910694256895967135779694377e-6"),
    SCplx("1.949391062347702500406862813492075e-7",
          "1.054384858618739098654878882536793e-6"),
    SCplx("-2.412863817672283336632571340087581e-7",
          "8.4060562284731949065262650416364e-7"),
    SCplx("-4.83316968359533309569906275415029e-7",
          "5.27261772476076460946479743220261e-7"),
    SCplx("-5.47580346678802448397417691654769e-7",
          "2.101033937729617247252320927119996e-7"),
    SCplx("-4.79874483622623965225593987344932e-7",
          "-4.62949691493880974811395736593642e-8"),
    SCplx("-3.36788342174342889058242410906026e-7",
          "-2.105769801489384591751957837017311e-7"),
    SCplx("-1.712463450864351052080135031497994e-7",
          "-2.797111776143151126135902059320275e-7"),
    SCplx("-2.348576510793938226424326251493109e-8",
          "-2.703478964512485655483299949203025e-7"),
    SCplx("8.26315225329447798977168049559903e-8",
          "-2.09250304608688042916721971802072e-7"),
    SCplx("1.39008305635085721725223401986817e-7",
          "-1.248791343851255205822868835494065e-7"),
    SCplx("1.498910813644343236411437025760871e-7",
          "-4.13342221728637531963992763136642e-8"),
    SCplx("1.271707770182848153796155925396777e-7",
          "2.495829613622333765793186117893814e-8"),
    SCplx("8.56905837523880670016991842658734e-8",
          "6.60527267868701415443342109867563e-8"),
    SCplx("3.94438098108889263870632129830368e-8",
          "8.1413156178852983668634337151625e-8"),
    SCplx("-8.941155708992471933902826707912e-10",
          "7.57482064966302730614456714736766e-8"),
    SCplx("-2.904062106339238381837332891723619e-8",
          "5.64975746595822063583769353667392e-8"),
    SCplx("-4.30076647540843073414379481942092e-8",
          "3.155419650536791990600031791737634e-8"),
    SCplx("-4.42034555685785840142898393021837e-8",
          "7.58483292888640255549744450120104e-9"),
    SCplx("-3.61458382269996888511274297856183e-8",
          "-1.090987212488967223303749100495304e-8"),
    SCplx("-2.314925959993081130292197352581101e-8",
          "-2.183649702309422844677422417614264e-8"),
    SCplx("-9.24480145468709864658242551887519e-9",
          "-2.521188903833520559846539503753348e-8"),
    SCplx("2.527971516014354388920180542259449e-9",
          "-2.254353106549097863277740821850204e-8"),
    SCplx("1.042993642060404503363824560283053e-8",
          "-1.610078212927501236267061864754531e-8"),
    SCplx("1.398871005832778256763778561445072e-8",
          "-8.24908415549001566879987507341721e-9"),
    SCplx("1.372788891675192618590775942327385e-8",
          "-9.57343324201655165306353594393013e-10"),
    SCplx("1.077968833796287912358126246260369e-8",
          "4.47616614109112800083890627661743e-9"),
    SCplx("6.48923671095144845268284934022427e-9",
          "7.48886560353329045050049348282691e-9"),
    SCplx("2.089514218688074862975329041454199e-9",
          "8.15677448797885473010509375965553e-9"),
    SCplx("-1.510050379389965697083160957968384e-9",
          "6.99997272928380189351403135373542e-9") };

static Cplx li3s9[64] = {
    SCplx("0",
          "-0.5"),
    SCplx("60.",
          "0"),
    SCplx("0.763853895180629234896574269282546",
          "0"),
    SCplx("-0.03033900041736453814384386223817259",
          "-0.495599953571453580645107055236821"),
    SCplx("0.974444716589044714220468995386676",
          "-0.117950148843131726910541396974516"),
    SCplx("0.1051934024710780288557536933353185",
          "-0.0471494985874324817919565324642471"),
    SCplx("0.02199748055116484589639959866262302",
          "-0.02235357083757720898520165132031428"),
    SCplx("0.00437394286749434934466746281297224",
          "-0.01119303282782209046360770660888707"),
    SCplx("-0.0002783602591384640179156342454956818",
          "-0.00555013420328982100509853491955465"),
    SCplx("-0.00134599115921485108000501742432316",
          "-0.002563389255271734268616204695805362"),
    SCplx("-0.001307319228802745839259582009425617",
          "-0.00098739493601480376069502837963827"),
    SCplx("-0.000965010808600586427986029896369646",
          "-0.0001972610675660117607527895919138656"),
    SCplx("-0.000601467808389418749065144903466747",
          "0.0001517021949140365859979192242803568"),
    SCplx("-0.0003103837262006103361006707871204475",
          "0.000260553734114034738458002277009722"),
    SCplx("-0.0001110189803975214815632270213492779",
          "0.0002491245656317353881153803534883343"),
    SCplx("6.68605546680011264422279138963228e-6",
          "0.0001880132571914304535258469292973877"),
    SCplx("0.0000625276219755019498638239469872859",
          "0.0001167968272662872507870420819662266"),
    SCplx("0.0000771514603807522594944121673176309",
          "0.0000553476733307015045022102512832938"),
    SCplx("0.0000681626912247785793593432951415678",
          "0.0000113171669727835727492465333045872"),
    SCplx("0.0000487669822462264036596698583714848",
          "-0.00001476053123162600689897071926751887"),
    SCplx("0.00002773806604714799968001229943884435",
          "-0.00002599182630434672900516159141072695"),
    SCplx("0.00001005147744810329216898898499857763",
          "-0.00002683324063470420491999940032785188"),
    SCplx("-2.208184884997161966767362650570732e-6",
          "-0.00002168727812164841359979010200776383"),
    SCplx("-8.90675043744470229025041806515614e-6",
          "-0.00001415295466159975165479497030518781"),
    SCplx("-0.00001102763235651941578550780470260969",
          "-6.73929952919080226075424150799253e-6"),
    SCplx("-0.00001001747160965429812428457311907568",
          "-8.8143371548691233122838266321777e-7"),
    SCplx("-7.33112350816118266278159395618689e-6",
          "2.871061925141120028486216520331235e-6"),
    SCplx("-4.16301729366742679442245042422488e-6",
          "4.59333985310974320133354037985668e-6"),
    SCplx("-1.33173781570168452975216459635506e-6",
          "4.72222486673428159387820965388848e-6"),
    SCplx("7.2427185303583593233480185837844e-7",
          "3.83408414283053640552196968655337e-6"),
    SCplx("1.882340001051824242844507290387322e-6",
          "2.484193045406411246535859838036426e-6"),
    SCplx("2.23947933290800808921436671344141e-6",
          "1.110979486825512006493286546151152e-6"),
    SCplx("2.012784384708267430184458363651908e-6",
          "-2.936871989642835628478522236079844e-9"),
    SCplx("1.454741449303099251480774274528486e-6",
          "-7.27171266666505707761188635553756e-7"),
    SCplx("7.92768938817852113822105542398108e-7",
          "-1.053548910694256895967135779694377e-6"),
    SCplx("1.949391062347702500406862813492075e-7",
          "-1.054384858618739098654878882536793e-6"),
    SCplx("-2.412863817672283336632571340087581e-7",
          "-8.4060562284731949065262650416364e-7"),
    SCplx("-4.83316968359533309569906275415029e-7",
          "-5.27261772476076460946479743220261e-7"),
    SCplx("-5.47580346678802448397417691654769e-7",
          "-2.101033937729617247252320927119996e-7"),
    SCplx("-4.79874483622623965225593987344932e-7",
          "4.62949691493880974811395736593642e-8"),
    SCplx("-3.36788342174342889058242410906026e-7",
          "2.105769801489384591751957837017311e-7"),
    SCplx("-1.712463450864351052080135031497994e-7",
          "2.797111776143151126135902059320275e-7"),
    SCplx("-2.348576510793938226424326251493109e-8",
          "2.703478964512485655483299949203025e-7"),
    SCplx("8.26315225329447798977168049559903e-8",
          "2.09250304608688042916721971802072e-7"),
    SCplx("1.39008305635085721725223401986817e-7",
          "1.248791343851255205822868835494065e-7"),
    SCplx("1.498910813644343236411437025760871e-7",
          "4.13342221728637531963992763136642e-8"),
    SCplx("1.271707770182848153796155925396777e-7",
          "-2.495829613622333765793186117893814e-8"),
    SCplx("8.56905837523880670016991842658734e-8",
          "-6.60527267868701415443342109867563e-8"),
    SCplx("3.94438098108889263870632129830368e-8",
          "-8.1413156178852983668634337151625e-8"),
    SCplx("-8.941155708992471933902826707912e-10",
          "-7.57482064966302730614456714736766e-8"),
    SCplx("-2.904062106339238381837332891723619e-8",
          "-5.64975746595822063583769353667392e-8"),
    SCplx("-4.30076647540843073414379481942092e-8",
          "-3.155419650536791990600031791737634e-8"),
    SCplx("-4.42034555685785840142898393021837e-8",
          "-7.58483292888640255549744450120104e-9"),
    SCplx("-3.61458382269996888511274297856183e-8",
          "1.090987212488967223303749100495304e-8"),
    SCplx("-2.314925959993081130292197352581101e-8",
          "2.183649702309422844677422417614264e-8"),
    SCplx("-9.24480145468709864658242551887519e-9",
          "2.521188903833520559846539503753348e-8"),
    SCplx("2.527971516014354388920180542259449e-9",
          "2.254353106549097863277740821850204e-8"),
    SCplx("1.042993642060404503363824560283053e-8",
          "1.610078212927501236267061864754531e-8"),
    SCplx("1.398871005832778256763778561445072e-8",
          "8.24908415549001566879987507341721e-9"),
    SCplx("1.372788891675192618590775942327385e-8",
          "9.57343324201655165306353594393013e-10"),
    SCplx("1.077968833796287912358126246260369e-8",
          "-4.47616614109112800083890627661743e-9"),
    SCplx("6.48923671095144845268284934022427e-9",
          "-7.48886560353329045050049348282691e-9"),
    SCplx("2.089514218688074862975329041454199e-9",
          "-8.15677448797885473010509375965553e-9"),
    SCplx("-1.510050379389965697083160957968384e-9",
          "-6.99997272928380189351403135373542e-9") };

static Cplx li3s10[64] = {
    SCplx("0.25",
          "0"),
    SCplx("60.",
          "0"),
    SCplx("1.138935590953552264079306462206453",
          "0"),
    SCplx("0.2584613957965733052880001298736726",
          "0"),
    SCplx("1.070610556330930427676735313951246",
          "0"),
    SCplx("0.1602354669523865641602814200481268",
          "0"),
    SCplx("0.0596522041968614917764690381597247",
          "0"),
    SCplx("0.0323350071214827174480057541298852",
          "0"),
    SCplx("0.0215268553343928069326894675547239",
          "0"),
    SCplx("0.01631265084505647980227993638470218",
          "0"),
    SCplx("0.01351170727855730686524801829604374",
          "0"),
    SCplx("0.01194166984164260854485986468792134",
          "0"),
    SCplx("0.01108808445554238166943477333109527",
          "0"),
    SCplx("0.0107029428711689125163368503788985",
          "0"),
    SCplx("0.01065977098738328728859764913283541",
          "0"),
    SCplx("0.01089413354460406536739294174720872",
          "0"),
    SCplx("0.01137684196290741969952913890665615",
          "0"),
    SCplx("0.0121011583482348462644911218539625",
          "0"),
    SCplx("0.01307659624681051733453914236557704",
          "0"),
    SCplx("0.01432613865353702312570787668250772",
          "0"),
    SCplx("0.01588542608703234710893304385477436",
          "0"),
    SCplx("0.0178032411007251952250774393028556",
          "0"),
    SCplx("0.02014299105670971568662031816319187",
          "0"),
    SCplx("0.02298509179731970808109877399397628",
          "0"),
    SCplx("0.02643027696014330648138997750155348",
          "0"),
    SCplx("0.03060394547055003325647893191553593",
          "0"),
    SCplx("0.035661735608380585256187676570772",
          "0"),
    SCplx("0.0417965907377202124046444018729032",
          "0"),
    SCplx("0.0492476679219910617190984786846063",
          "0"),
    SCplx("0.0583115433382267066849886726599019",
          "0"),
    SCplx("0.0693562947065088615998164118723245",
          "0"),
    SCplx("0.0828391987615438870498071161174552",
          "0"),
    SCplx("0.0993289805782151349926828463499112",
          "0"),
    SCplx("0.1195338030509537960261681935772096",
          "0"),
    SCplx("0.1443365037885458935297242981611015",
          "0"),
    SCplx("0.1748389918669661045551933619028474",
          "0"),
    SCplx("0.2124182321660636906997376987475917",
          "0"),
    SCplx("0.2587969008948406167747859414849395",
          "0"),
    SCplx("0.3161326313678809486404941883460194",
          "0"),
    SCplx("0.387130834012482766835967817323844",
          "0"),
    SCplx("0.475187432828535881344900789449587",
          "0"),
    SCplx("0.584569593911706715423732112406567",
          "0"),
    SCplx("0.720644735060850009269785874908142",
          "0"),
    SCplx("0.890170933414894858300324359742701",
          "0"),
    SCplx("1.101665463053812504517406772274432",
          "0"),
    SCplx("1.365872818030909675952884850620426",
          "0"),
    SCplx("1.696359492781173455377823678984493",
          "0"),
    SCplx("2.110270366628489156855336665124357",
          "0"),
    SCplx("2.629291241740224031426914311905221",
          "0"),
    SCplx("3.28087451804580056943950174535497",
          "0"),
    SCplx("4.09980093082211694763429641234838",
          "0"),
    SCplx("5.13017072594778984754837483090598",
          "0"),
    SCplx("6.42794389026929701587559256159515",
          "0"),
    SCplx("8.06418274609244469939216759822727",
          "0"),
    SCplx("10.12919349266613745623731894502107",
          "0"),
    SCplx("12.73781888246401168214257973086751",
          "0"),
    SCplx("16.03620569947336609486204857396681",
          "0"),
    SCplx("20.21046262979290476007619382770105",
          "0"),
    SCplx("25.49774237567921543004649141192089",
          "0"),
    SCplx("32.2004340683276525293750252642113",
          "0"),
    SCplx("40.7043479993849544261839477735578",
          "0"),
    SCplx("51.5020270926591664254769080674608",
          "0"),
    SCplx("65.2226447485694157670420268606118",
          "0"),
    SCplx("82.6703678686616107329863006118874",
          "0") };

static Cplx li3s11[64] = {
    SCplx("0.25",
          "0.5"),
    SCplx("60.",
          "0"),
    SCplx("0.946485272509870360527499180127552",
          "0"),
    SCplx("0.2202068651524365912017839870085781",
          "0.528433440029193445510714518509417"),
    SCplx("1.031423192566026497092803703938974",
          "0.1465409278734912338527041914769179"),
    SCplx("0.1231744181221255188996856471946395",
          "0.0691504900396833739034923808292017"),
    SCplx("0.02553046101339891874771989032737283",
          "0.0379564386087785288117288216987402"),
    SCplx("0.001693480667463497962082930101124613",
          "0.02108896322952393523393818998903934"),
    SCplx("-0.00524013098955243377943956459425527",
          "0.01068508356662138092238740451400882"),
    SCplx("-0.00640333923545116998693985697149842",
          "0.00405412665637408361492021973328978"),
    SCplx("-0.00525880724266812476214295431115055",
          "0.00002527275921044617760803028421377986"),
    SCplx("-0.00329022524973001792951514071707067",
          "-0.002067564685917349889036509629111986"),
    SCplx("-0.001281948839461499621737109924197916",
          "-0.002726486283584531534528897994162264"),
    SCplx("0.000324045728255428054939234192787467",
          "-0.002404482909414259271143336608838024"),
    SCplx("0.001313061163834221820129678374655706",
          "-0.00152808699327977892935710891519651"),
    SCplx("0.001647662051926154901819891233214842",
          "-0.000479444567618786764355626941547751"),
    SCplx("0.001428034623748237431980781580904399",
          "0.000435614410036429375378366362616829"),
    SCplx("0.000846340971735961894385982519185092",
          "0.001016525056856477395920377141914569"),
    SCplx("0.0001341194890769081326378432487525235",
          "0.001182743619269718585015068423083298"),
    SCplx("-0.000491035742757554781243836805638457",
          "0.000968459231610891188575780972025614"),
    SCplx("-0.000870547957846814789314856470613845",
          "0.000496960995044287537713567908851435"),
    SCplx("-0.000933275370397347591334659718382478",
          "-0.0000604295266820383541792002457718903"),
    SCplx("-0.000701997339115703443226103800234378",
          "-0.000532007948619348657020308191697902"),
    SCplx("-0.0002774536116639194684637092889890572",
          "-0.000789258264116751501074313176414964"),
    SCplx("0.0001954181474946038541311766390179681",
          "-0.00077648561177989523145642553621796"),
    SCplx("0.000570174787181998881046199527020224",
          "-0.000519943985823103488706669442245244"),
    SCplx("0.000739469620714664779412285119120855",
          "-0.0001149353690452920490484300684815392"),
    SCplx("0.000663129886340888186569800321525634",
          "0.0003050825683390525451064969696113072"),
    SCplx("0.000376565782435949676328680002997234",
          "0.000608699615054332524379840576738498"),
    SCplx("-0.0000223962635064197274287928098503158",
          "0.000704929244797022869244392841481125"),
    SCplx("-0.000404306570584354865274349778111649",
          "0.000569097724208207097887363732663719"),
    SCplx("-0.00064765441371045721735181956084373",
          "0.0002489855141694746774414256480121138"),
    SCplx("-0.000675777986317810167078802674551744",
          "-0.0001505398063702044147336075159654084"),
    SCplx("-0.000480293849313711698886855179187325",
          "-0.000500014894275008896804523732853008"),
    SCplx("-0.0001239340081347447537252225524780022",
          "-0.000685540534204312870543999098428391"),
    SCplx("0.0002784130447827041893308039988978637",
          "-0.000644663985082394915726661016704748"),
    SCplx("0.000595181201250002299157786999378598",
          "-0.000386974875154767913516908671922834"),
    SCplx("0.00071968125733930672118164842485708",
          "7.33765662747505568517058602544404e-6"),
    SCplx("0.000605039502977816190211190140017935",
          "0.000411240391606359681151942375487225"),
    SCplx("0.0002813388306590844576745752748675717",
          "0.000690328299974478179855281079323237"),
    SCplx("-0.0001511954706283380655151799082567379",
          "0.000746224745462431999576708012377459"),
    SCplx("-0.000551915951304211301756349033325168",
          "0.000550299256334587020088596507872742"),
    SCplx("-0.000784032649559977485976773668165415",
          "0.0001564197453539826600609627290941961"),
    SCplx("-0.000759989083488413259641683028273565",
          "-0.0003125199207123993447603018482612366"),
    SCplx("-0.000473294774630911405967998233041872",
          "-0.000701474074512308718879532397660365"),
    SCplx("-5.59282435063246566291086653185992e-6",
          "-0.000872968816212477503739055541571019"),
    SCplx("0.000494992009598064391827105678340942",
          "-0.000754235094190199870522035649061754"),
    SCplx("0.000859096002356042581028815375782554",
          "-0.000366052264478125743916665316590319"),
    SCplx("0.000951705291164063393578443023389595",
          "0.0001775737868631004101003950079504894"),
    SCplx("0.000720409082626983234150912944523282",
          "0.000701012508539166172115332315327642"),
    SCplx("0.000219636499721271172115369220000732",
          "0.001021825548403711802184320809989375"),
    SCplx("-0.000399215676982328083811611275703289",
          "0.001012345524216490064358848022084494"),
    SCplx("-0.000931346535825862554739938186026713",
          "0.000647888238160198391733458103722245"),
    SCplx("-0.001184065690252884788086236029018018",
          "0.00002415752405514321610568476970816838"),
    SCplx("-0.001044065356132930609320151071705105",
          "-0.000664836442726471831340636008539702"),
    SCplx("-0.000523766003527414390398344369558721",
          "-0.001184518912823585269618004161270347"),
    SCplx("0.0002310508140793524220362553907440863",
          "-0.001336887227742848830319664434405021"),
    SCplx("0.000978719211438194809049246192248552",
          "-0.001032586901525585981795474950228097"),
    SCplx("0.001455954928000279130791697603490661",
          "-0.00033272711630302741761838725178971"),
    SCplx("0.001467167347484819112901321100027015",
          "0.000557027044025675527441383279392907"),
    SCplx("0.000959634204489541820395314747730853",
          "0.001343041205942343198663901059595381"),
    SCplx("0.0000570804521875494771675147077197842",
          "0.001736847886356802064934676476760891"),
    SCplx("-0.000964477351155863085864353600716008",
          "0.00155657818261759956139416898791501"),
    SCplx("-0.00175663131252745085884980125429855",
          "0.000802432502709191266664855754397251") };

static Cplx li3s12[64] = {
    SCplx("0.25",
          "0.25"),
    SCplx("60.",
          "0"),
    SCplx("1.080120912604458134302894641485261",
          "0"),
    SCplx("0.2485691777685005863510052162930364",
          "0.2667408109370587326698882456734852"),
    SCplx("1.059824542174400254941314381918305",
          "0.0781869260208145270830734040243191"),
    SCplx("0.1489907493913539915812306714920211",
          "0.0416303576621146205563669155973018"),
    SCplx("0.047841884531976739614040287122262",
          "0.02782017302434574863814668768051208"),
    SCplx("0.01983056901022145788588745473359333",
          "0.02069627714602145498968245591643121"),
    SCplx("0.00823887454154181551774284119675445",
          "0.01620680153487627071991903032819723"),
    SCplx("0.002198855947720866664369240181705127",
          "0.01291998013027485470659123946900322"),
    SCplx("-0.001421492125492603927394985226974932",
          "0.01021891705264849242798248412922722"),
    SCplx("-0.00375495739752731897509288870147932",
          "0.00780545314027256064273169790777891"),
    SCplx("-0.00526638500055450242860542840710871",
          "0.00553071092092162116127550601910111"),
    SCplx("-0.00615622643835432645861858975613864",
          "0.00332828867215909851387638944913759"),
    SCplx("-0.00650896680649213640559638995298394",
          "0.00118509812405073578832354812898718"),
    SCplx("-0.00635754270575266459031105027745129",
          "-0.000872654088138394852165781808951294"),
    SCplx("-0.00571635751565601499962110492355419",
          "-0.002787357026248318354783467575818763"),
    SCplx("-0.0046013841657294090656156441290972",
          "-0.00447590335253153348268934539735484"),
    SCplx("-0.003044392509955975542704885282578308",
          "-0.00583579129642506991294512969668584"),
    SCplx("-0.001103943228782310517317353389830137",
          "-0.00675268877120471975561560802324762"),
    SCplx("0.001126132742838571105578668538508509",
          "-0.00711020955903578092822398864812798"),
    SCplx("0.00351100815635734732192423004772606",
          "-0.00680225384608895214882143261099995"),
    SCplx("0.00587265000976232633557855671333829",
          "-0.00574787021136904306208529714698151"),
    SCplx("0.00799216757382417921898323783530064",
          "-0.00390815197395392161055940195852626"),
    SCplx("0.00961784236316644100855412652400712",
          "-0.001304172464893037888733031646199502"),
    SCplx("0.01047985139363189100762372486515003",
          "0.001965597476310266107192310480644703"),
    SCplx("0.01031236054733951273432468777004634",
          "0.00571052557078342574908367045320957"),
    SCplx("0.00888308096572960331203148802121931",
          "0.00963838149459400098899151083017842"),
    SCplx("0.00602953019701434124268547886703391",
          "0.0133543157171883774108163757444899"),
    SCplx("0.001700125741982260373737486609699244",
          "0.01637152885298492346405109249027395"),
    SCplx("-0.00400309963595350147333089089398633",
          "0.01813674653198775240738045235881113"),
    SCplx("-0.01078484962734876715149971958246758",
          "0.01807298216708561473326913280674739"),
    SCplx("-0.018126150564694666846445163999587",
          "0.01564084830049237965676848504863254"),
    SCplx("-0.02527061860567004653671165720808693",
          "0.01041777945627424692040940778453971"),
    SCplx("-0.03123567379905634789550571145100166",
          "0.002191923677793236276835725516609921"),
    SCplx("-0.0348570159623032560228918213375391",
          "-0.00893580134916789291337578137413611"),
    SCplx("-0.0348736162797576909083852761552049",
          "-0.02245174102293706670557634244095259"),
    SCplx("-0.03005797395777035722625729454538264",
          "-0.0373458057364683264432560732060382"),
    SCplx("-0.01939216268018226577970450000725572",
          "-0.052061853171125283325245553792293"),
    SCplx("-0.002284093405653771943263608757730535",
          "-0.0645026548431708852853557226433562"),
    SCplx("0.02118950426912249987589646805089272",
          "-0.0721109113378583658791040993223922"),
    SCplx("0.0500362971357598772076372811392807",
          "-0.0720461105044877872029271140824105"),
    SCplx("0.082130884288439920016959559009354",
          "-0.0614718030753258071309657979824238"),
    SCplx("0.1140696480721723422696647582950764",
          "-0.0379582881638813791066299309402625"),
    SCplx("0.1411488501720871791114771169308635",
          "8.77957688172353920516469739776425e-6"),
    SCplx("0.157520875816937559229938114432083",
          "0.0524427818129940792892305727367012"),
    SCplx("0.1565811778363308937762650699497007",
          "0.117246171072543078859438183324898"),
    SCplx("0.1316273076078307695343167951965245",
          "0.1896551989716790576537829405526252"),
    SCplx("0.0768091423429313712665557247963392",
          "0.2618447351779394655799113057860344"),
    SCplx("-0.01164564274281069624589331921040893",
          "0.322820862806711257510640986597384"),
    SCplx("-0.1339951452928585164344713654577567",
          "0.35874194977280030442007391603125"),
    SCplx("-0.2854604371680457962320669863131267",
          "0.353806428159818687538779739530924"),
    SCplx("-0.45480948626196180442150313635713",
          "0.2918208654001032272876369443409862"),
    SCplx("-0.623310820101816693292910966515885",
          "0.1585086980145812314424619050717682"),
    SCplx("-0.764381161098024498356211699283714",
          "-0.0554667033652076839785610106844915"),
    SCplx("-0.844290213842420827618432787016068",
          "-0.350913163849435443299482070099766"),
    SCplx("-0.824286084366125243790110543196555",
          "-0.716258628364406262137609029341938"),
    SCplx("-0.664448439367009919429460147335289",
          "-1.123920417725245842729477062227128"),
    SCplx("-0.329445902901668820495448198212302",
          "-1.527563128864445338273329069649166"),
    SCplx("0.2038447650698966518972126089694751",
          "-1.861079939108369261356589614212062"),
    SCplx("0.937214192383621650606887107180179",
          "-2.040243706185346506235564808821263"),
    SCplx("1.841250956685224096800795031696026",
          "-1.967987467411891928131619096191547"),
    SCplx("2.845959043348418004575996950318663",
          "-1.544140122017218320600043387956863"),
    SCplx("3.83358961979082659900927264273002",
          "-0.68011403854082391348220232865446") };

static Cplx li3s13[64] = {
    SCplx("0.25",
          "-0.25"),
    SCplx("60.",
          "0"),
    SCplx("1.080120912604458134302894641485261",
          "0"),
    SCplx("0.2485691777685005863510052162930364",
          "-0.2667408109370587326698882456734852"),
    SCplx("1.059824542174400254941314381918305",
          "-0.0781869260208145270830734040243191"),
    SCplx("0.1489907493913539915812306714920211",
          "-0.0416303576621146205563669155973018"),
    SCplx("0.047841884531976739614040287122262",
          "-0.02782017302434574863814668768051208"),
    SCplx("0.01983056901022145788588745473359333",
          "-0.02069627714602145498968245591643121"),
    SCplx("0.00823887454154181551774284119675445",
          "-0.01620680153487627071991903032819723"),
    SCplx("0.002198855947720866664369240181705127",
          "-0.01291998013027485470659123946900322"),
    SCplx("-0.001421492125492603927394985226974932",
          "-0.01021891705264849242798248412922722"),
    SCplx("-0.00375495739752731897509288870147932",
          "-0.00780545314027256064273169790777891"),
    SCplx("-0.00526638500055450242860542840710871",
          "-0.00553071092092162116127550601910111"),
    SCplx("-0.00615622643835432645861858975613864",
          "-0.00332828867215909851387638944913759"),
    SCplx("-0.00650896680649213640559638995298394",
          "-0.00118509812405073578832354812898718"),
    SCplx("-0.00635754270575266459031105027745129",
          "0.000872654088138394852165781808951294"),
    SCplx("-0.00571635751565601499962110492355419",
          "0.002787357026248318354783467575818763"),
    SCplx("-0.0046013841657294090656156441290972",
          "0.00447590335253153348268934539735484"),
    SCplx("-0.003044392509955975542704885282578308",
          "0.00583579129642506991294512969668584"),
    SCplx("-0.001103943228782310517317353389830137",
          "0.00675268877120471975561560802324762"),
    SCplx("0.001126132742838571105578668538508509",
          "0.00711020955903578092822398864812798"),
    SCplx("0.00351100815635734732192423004772606",
          "0.00680225384608895214882143261099995"),
    SCplx("0.00587265000976232633557855671333829",
          "0.00574787021136904306208529714698151"),
    SCplx("0.00799216757382417921898323783530064",
          "0.00390815197395392161055940195852626"),
    SCplx("0.00961784236316644100855412652400712",
          "0.001304172464893037888733031646199502"),
    SCplx("0.01047985139363189100762372486515003",
          "-0.001965597476310266107192310480644703"),
    SCplx("0.01031236054733951273432468777004634",
          "-0.00571052557078342574908367045320957"),
    SCplx("0.00888308096572960331203148802121931",
          "-0.00963838149459400098899151083017842"),
    SCplx("0.00602953019701434124268547886703391",
          "-0.0133543157171883774108163757444899"),
    SCplx("0.001700125741982260373737486609699244",
          "-0.01637152885298492346405109249027395"),
    SCplx("-0.00400309963595350147333089089398633",
          "-0.01813674653198775240738045235881113"),
    SCplx("-0.01078484962734876715149971958246758",
          "-0.01807298216708561473326913280674739"),
    SCplx("-0.018126150564694666846445163999587",
          "-0.01564084830049237965676848504863254"),
    SCplx("-0.02527061860567004653671165720808693",
          "-0.01041777945627424692040940778453971"),
    SCplx("-0.03123567379905634789550571145100166",
          "-0.002191923677793236276835725516609921"),
    SCplx("-0.0348570159623032560228918213375391",
          "0.00893580134916789291337578137413611"),
    SCplx("-0.0348736162797576909083852761552049",
          "0.02245174102293706670557634244095259"),
    SCplx("-0.03005797395777035722625729454538264",
          "0.0373458057364683264432560732060382"),
    SCplx("-0.01939216268018226577970450000725572",
          "0.052061853171125283325245553792293"),
    SCplx("-0.002284093405653771943263608757730535",
          "0.0645026548431708852853557226433562"),
    SCplx("0.02118950426912249987589646805089272",
          "0.0721109113378583658791040993223922"),
    SCplx("0.0500362971357598772076372811392807",
          "0.0720461105044877872029271140824105"),
    SCplx("0.082130884288439920016959559009354",
          "0.0614718030753258071309657979824238"),
    SCplx("0.1140696480721723422696647582950764",
          "0.0379582881638813791066299309402625"),
    SCplx("0.1411488501720871791114771169308635",
          "-8.77957688172353920516469739776425e-6"),
    SCplx("0.157520875816937559229938114432083",
          "-0.0524427818129940792892305727367012"),
    SCplx("0.1565811778363308937762650699497007",
          "-0.117246171072543078859438183324898"),
    SCplx("0.1316273076078307695343167951965245",
          "-0.1896551989716790576537829405526252"),
    SCplx("0.0768091423429313712665557247963392",
          "-0.2618447351779394655799113057860344"),
    SCplx("-0.01164564274281069624589331921040893",
          "-0.322820862806711257510640986597384"),
    SCplx("-0.1339951452928585164344713654577567",
          "-0.35874194977280030442007391603125"),
    SCplx("-0.2854604371680457962320669863131267",
          "-0.353806428159818687538779739530924"),
    SCplx("-0.45480948626196180442150313635713",
          "-0.2918208654001032272876369443409862"),
    SCplx("-0.623310820101816693292910966515885",
          "-0.1585086980145812314424619050717682"),
    SCplx("-0.764381161098024498356211699283714",
          "0.0554667033652076839785610106844915"),
    SCplx("-0.844290213842420827618432787016068",
          "0.350913163849435443299482070099766"),
    SCplx("-0.824286084366125243790110543196555",
          "0.716258628364406262137609029341938"),
    SCplx("-0.664448439367009919429460147335289",
          "1.123920417725245842729477062227128"),
    SCplx("-0.329445902901668820495448198212302",
          "1.527563128864445338273329069649166"),
    SCplx("0.2038447650698966518972126089694751",
          "1.861079939108369261356589614212062"),
    SCplx("0.937214192383621650606887107180179",
          "2.040243706185346506235564808821263"),
    SCplx("1.841250956685224096800795031696026",
          "1.967987467411891928131619096191547"),
    SCplx("2.845959043348418004575996950318663",
          "1.544140122017218320600043387956863"),
    SCplx("3.83358961979082659900927264273002",
          "0.68011403854082391348220232865446") };

static Cplx li3s14[64] = {
    SCplx("0.25",
          "-0.5"),
    SCplx("60.",
          "0"),
    SCplx("0.946485272509870360527499180127552",
          "0"),
    SCplx("0.2202068651524365912017839870085781",
          "-0.528433440029193445510714518509417"),
    SCplx("1.031423192566026497092803703938974",
          "-0.1465409278734912338527041914769179"),
    SCplx("0.1231744181221255188996856471946395",
          "-0.0691504900396833739034923808292017"),
    SCplx("0.02553046101339891874771989032737283",
          "-0.0379564386087785288117288216987402"),
    SCplx("0.001693480667463497962082930101124613",
          "-0.02108896322952393523393818998903934"),
    SCplx("-0.00524013098955243377943956459425527",
          "-0.01068508356662138092238740451400882"),
    SCplx("-0.00640333923545116998693985697149842",
          "-0.00405412665637408361492021973328978"),
    SCplx("-0.00525880724266812476214295431115055",
          "-0.00002527275921044617760803028421377986"),
    SCplx("-0.00329022524973001792951514071707067",
          "0.002067564685917349889036509629111986"),
    SCplx("-0.001281948839461499621737109924197916",
          "0.002726486283584531534528897994162264"),
    SCplx("0.000324045728255428054939234192787467",
          "0.002404482909414259271143336608838024"),
    SCplx("0.001313061163834221820129678374655706",
          "0.00152808699327977892935710891519651"),
    SCplx("0.001647662051926154901819891233214842",
          "0.000479444567618786764355626941547751"),
    SCplx("0.001428034623748237431980781580904399",
          "-0.000435614410036429375378366362616829"),
    SCplx("0.000846340971735961894385982519185092",
          "-0.001016525056856477395920377141914569"),
    SCplx("0.0001341194890769081326378432487525235",
          "-0.001182743619269718585015068423083298"),
    SCplx("-0.000491035742757554781243836805638457",
          "-0.000968459231610891188575780972025614"),
    SCplx("-0.000870547957846814789314856470613845",
          "-0.000496960995044287537713567908851435"),
    SCplx("-0.000933275370397347591334659718382478",
          "0.0000604295266820383541792002457718903"),
    SCplx("-0.000701997339115703443226103800234378",
          "0.000532007948619348657020308191697902"),
    SCplx("-0.0002774536116639194684637092889890572",
          "0.000789258264116751501074313176414964"),
    SCplx("0.0001954181474946038541311766390179681",
          "0.00077648561177989523145642553621796"),
    SCplx("0.000570174787181998881046199527020224",
          "0.000519943985823103488706669442245244"),
    SCplx("0.000739469620714664779412285119120855",
          "0.0001149353690452920490484300684815392"),
    SCplx("0.000663129886340888186569800321525634",
          "-0.0003050825683390525451064969696113072"),
    SCplx("0.000376565782435949676328680002997234",
          "-0.000608699615054332524379840576738498"),
    SCplx("-0.0000223962635064197274287928098503158",
          "-0.000704929244797022869244392841481125"),
    SCplx("-0.000404306570584354865274349778111649",
          "-0.000569097724208207097887363732663719"),
    SCplx("-0.00064765441371045721735181956084373",
          "-0.0002489855141694746774414256480121138"),
    SCplx("-0.000675777986317810167078802674551744",
          "0.0001505398063702044147336075159654084"),
    SCplx("-0.000480293849313711698886855179187325",
          "0.000500014894275008896804523732853008"),
    SCplx("-0.0001239340081347447537252225524780022",
          "0.000685540534204312870543999098428391"),
    SCplx("0.0002784130447827041893308039988978637",
          "0.000644663985082394915726661016704748"),
    SCplx("0.000595181201250002299157786999378598",
          "0.000386974875154767913516908671922834"),
    SCplx("0.00071968125733930672118164842485708",
          "-7.33765662747505568517058602544404e-6"),
    SCplx("0.000605039502977816190211190140017935",
          "-0.000411240391606359681151942375487225"),
    SCplx("0.0002813388306590844576745752748675717",
          "-0.000690328299974478179855281079323237"),
    SCplx("-0.0001511954706283380655151799082567379",
          "-0.000746224745462431999576708012377459"),
    SCplx("-0.000551915951304211301756349033325168",
          "-0.000550299256334587020088596507872742"),
    SCplx("-0.000784032649559977485976773668165415",
          "-0.0001564197453539826600609627290941961"),
    SCplx("-0.000759989083488413259641683028273565",
          "0.0003125199207123993447603018482612366"),
    SCplx("-0.000473294774630911405967998233041872",
          "0.000701474074512308718879532397660365"),
    SCplx("-5.59282435063246566291086653185992e-6",
          "0.000872968816212477503739055541571019"),
    SCplx("0.000494992009598064391827105678340942",
          "0.000754235094190199870522035649061754"),
    SCplx("0.000859096002356042581028815375782554",
          "0.000366052264478125743916665316590319"),
    SCplx("0.000951705291164063393578443023389595",
          "-0.0001775737868631004101003950079504894"),
    SCplx("0.000720409082626983234150912944523282",
          "-0.000701012508539166172115332315327642"),
    SCplx("0.000219636499721271172115369220000732",
          "-0.001021825548403711802184320809989375"),
    SCplx("-0.000399215676982328083811611275703289",
          "-0.001012345524216490064358848022084494"),
    SCplx("-0.000931346535825862554739938186026713",
          "-0.000647888238160198391733458103722245"),
    SCplx("-0.001184065690252884788086236029018018",
          "-0.00002415752405514321610568476970816838"),
    SCplx("-0.001044065356132930609320151071705105",
          "0.000664836442726471831340636008539702"),
    SCplx("-0.000523766003527414390398344369558721",
          "0.001184518912823585269618004161270347"),
    SCplx("0.0002310508140793524220362553907440863",
          "0.001336887227742848830319664434405021"),
    SCplx("0.000978719211438194809049246192248552",
          "0.001032586901525585981795474950228097"),
    SCplx("0.001455954928000279130791697603490661",
          "0.00033272711630302741761838725178971"),
    SCplx("0.001467167347484819112901321100027015",
          "-0.000557027044025675527441383279392907"),
    SCplx("0.000959634204489541820395314747730853",
          "-0.001343041205942343198663901059595381"),
    SCplx("0.0000570804521875494771675147077197842",
          "-0.001736847886356802064934676476760891"),
    SCplx("-0.000964477351155863085864353600716008",
          "-0.00155657818261759956139416898791501"),
    SCplx("-0.00175663131252745085884980125429855",
          "-0.000802432502709191266664855754397251") };

static Double rli3s1[64] = {
     SDouble("-1."),
     SDouble("60."),
     SDouble("0.428906220392100540146530350746658"),
     SDouble("-0.901542677369695714049803621133587"),
     SDouble("0.822467033424113218236207583323013"),
     SDouble("0.064659926432083954409487730932418"),
     SDouble("0.01091542086139841803678646704524925"),
     SDouble("0.002507633932720037742820506829088888"),
     SDouble("0.000682081451512098056728132723695616"),
     SDouble("0.0002065507464841269555879287766960163"),
     SDouble("0.0000673884042892839916809519326082544"),
     SDouble("0.00002322651042076677693692601023145053"),
     SDouble("8.3502898456739751596256660908476e-6"),
     SDouble("3.104210327322716393994025078742775e-6"),
     SDouble("1.185821578005572871073406368103275e-6"),
     SDouble("4.63333346871331013776926993618023e-7"),
     SDouble("1.845179316876127426736867579713624e-7"),
     SDouble("7.46888897381088391121101241375321e-8"),
     SDouble("3.066139954409583873363345888232584e-8"),
     SDouble("1.27430851286229176679159476071358e-8"),
     SDouble("5.3538990246644734615886584483433e-9"),
     SDouble("2.271182602338407480276976477430797e-9"),
     SDouble("9.71801564175745785514506212000899e-10"),
     SDouble("4.19055164015686366217139589222656e-10"),
     SDouble("1.819748414590891734954900506473183e-10"),
     SDouble("7.95281140915881642700456664897803e-11"),
     SDouble("3.49589371347629056697716780953473e-11"),
     SDouble("1.544945807088958242368699386099118e-11"),
     SDouble("6.86120591473045674753792473503369e-12"),
     SDouble("3.060948095928747817472178466387716e-12"),
     SDouble("1.371305376072359884269096420276435e-12"),
     SDouble("6.16744265463583967451413954394309e-13"),
     SDouble("2.783891369123969115837058649614259e-13"),
     SDouble("1.260871508973192719518392088263861e-13"),
     SDouble("5.72883183030740446393364571195469e-14"),
     SDouble("2.610671363310647598504363488170274e-14"),
     SDouble("1.19302960641337584653993955131498e-14"),
     SDouble("5.46628156100651194555912099540348e-15"),
     SDouble("2.510784879991430238796238481089816e-15"),
     SDouble("1.155963513906717988465591738537496e-15"),
     SDouble("5.33385342796999643351015917049303e-16"),
     SDouble("2.466322648123928136887419107989695e-16"),
     SDouble("1.142678296304085999952426915317684e-16"),
     SDouble("5.30420425565206049053413397789332e-17"),
     SDouble("2.466599972428467919397347749191308e-17"),
     SDouble("1.149006070745624721400450154869351e-17"),
     SDouble("5.36113227673245460306405312074152e-18"),
     SDouble("2.505354293144225334792573359639917e-18"),
     SDouble("1.172546768430359744206753072960686e-18"),
     SDouble("5.49555448906547190105768542553967e-19"),
     SDouble("2.579211128349652579322460406051322e-19"),
     SDouble("1.212081021980944628111738831120978e-19"),
     SDouble("5.70325311444493518789120045467814e-20"),
     SDouble("2.686817198918444756126513284080277e-20"),
     SDouble("1.26723625351229805639099657187494e-20"),
     SDouble("5.98358892890643236361821568805594e-21"),
     SDouble("2.828345034490377928389603639582158e-21"),
     SDouble("1.338296369471195715868944278975699e-21"),
     SDouble("6.33877321462002465224029147365816e-22"),
     SDouble("3.005216268983857797292514269880188e-22"),
     SDouble("1.42609763393759305837203350238931e-22"),
     SDouble("6.77348165429897277710390030409471e-23"),
     SDouble("3.21996159689420665713587850077772e-23"),
     SDouble("1.53197957849552570884574770609893e-23") };

static Double rli3s2[64] = {
     SDouble("-0.5"),
     SDouble("60."),
     SDouble("0.570681515425557045484379679066931"),
     SDouble("-0.472597844658896874618623193126548"),
     SDouble("0.896828413847292404886128811831549"),
     SDouble("0.0858981976309636409301025809028504"),
     SDouble("0.01835523047484345638056373169577942"),
     SDouble("0.00543122008656452711867996210972213"),
     SDouble("0.001921087807415540867042263274572104"),
     SDouble("0.000761022710826660221193899462893456"),
     SDouble("0.000326095507767814049175830060716084"),
     SDouble("0.0001480317057256813566325361906146358"),
     SDouble("0.0000702398468758811253309362501053971"),
     SDouble("0.0000345166403728543038272376351313486"),
     SDouble("0.00001745120816170509007752672436238687"),
     SDouble("9.03343930226572364971880773744345e-6"),
     SDouble("4.76974998018252370276471651095801e-6"),
     SDouble("2.561494462087344556674761298165445e-6"),
     SDouble("1.395871462359307326428358237127334e-6"),
     SDouble("7.70446654402581164841076910041103e-7"),
     SDouble("4.30052577878536204429636834718956e-7"),
     SDouble("2.424553214324696478441564010896848e-7"),
     SDouble("1.379147974213437460997894656736608e-7"),
     SDouble("7.90801013389141856268085601321454e-8"),
     SDouble("4.5673656712247419739310960049823e-8"),
     SDouble("2.65532612133568368817397423473469e-8"),
     SDouble("1.55300515846521498379228331570961e-8"),
     SDouble("9.13296904954765473997803360463844e-9"),
     SDouble("5.39812318133135426397459756331697e-9"),
     SDouble("3.20549709953160595456064822937068e-9"),
     SDouble("1.911696355282062245192899020215779e-9"),
     SDouble("1.14466605023512906165954521322586e-9"),
     SDouble("6.87946290818947825662546778109173e-10"),
     SDouble("4.14894547089541011777207099087083e-10"),
     SDouble("2.510328573288240922069578994260305e-10"),
     SDouble("1.523507093496036721080556024118993e-10"),
     SDouble("9.27254578410466589818118738697994e-11"),
     SDouble("5.65875325017135438904215679182915e-11"),
     SDouble("3.46212532831367352116974589854816e-11"),
     SDouble("2.123262449652822970006862441872118e-11"),
     SDouble("1.305109801737841232457809916810484e-11"),
     SDouble("8.03935095757067865893899985617128e-12"),
     SDouble("4.96223798682981466310849886745939e-12"),
     SDouble("3.068828100985464925013035363434558e-12"),
     SDouble("1.901362270119824613156875400346937e-12"),
     SDouble("1.180093516635033538272409760835518e-12"),
     SDouble("7.33654855223608254230066324798881e-13"),
     SDouble("4.56833545436369836936049300277579e-13"),
     SDouble("2.848945919589153452769674524672815e-13"),
     SDouble("1.779269258432814697107063083933737e-13"),
     SDouble("1.112765016162859564060280487886683e-13"),
     SDouble("6.96858057593652268412803360919458e-14"),
     SDouble("4.36958879314763788806169369377183e-14"),
     SDouble("2.743278656185582398264102981637609e-14"),
     SDouble("1.724294483440539377573790670648215e-14"),
     SDouble("1.085039053702971969756268068715313e-14"),
     SDouble("6.83522943719820091628755829233526e-15"),
     SDouble("4.31039466057932788444967434202502e-15"),
     SDouble("2.720950021595141261330930026815656e-15"),
     SDouble("1.719285313783963251882453997711202e-15"),
     SDouble("1.087387415175993227450516803567857e-15"),
     SDouble("6.88359775685601878870093685262058e-16"),
     SDouble("4.36142182049511407901634131348057e-16"),
     SDouble("2.765727512263024064146828283294596e-16") };

static Double rli3s3[64] = {
     SDouble("0"),
     SDouble("60."),
     SDouble("0.854544147572749789985743353149954"),
     SDouble("0"),
     SDouble("1."),
     SDouble("0.125"),
     SDouble("0.037037037037037037037037037037037"),
     SDouble("0.015625"),
     SDouble("0.008"),
     SDouble("0.00462962962962962962962962962962963"),
     SDouble("0.002915451895043731778425655976676385"),
     SDouble("0.001953125"),
     SDouble("0.001371742112482853223593964334705075"),
     SDouble("0.001"),
     SDouble("0.000751314800901577761081893313298272"),
     SDouble("0.000578703703703703703703703703703704"),
     SDouble("0.000455166135639508420573509330905781"),
     SDouble("0.000364431486880466472303206997084548"),
     SDouble("0.0002962962962962962962962962962962963"),
     SDouble("0.000244140625"),
     SDouble("0.0002035416242621616120496641563199674"),
     SDouble("0.0001714677640603566529492455418381344"),
     SDouble("0.0001457938474996355153812509112115469"),
     SDouble("0.000125"),
     SDouble("0.0001079796998164345103120613324694957"),
     SDouble("0.000093914350112697220135236664162284"),
     SDouble("0.0000821895290539985205884770280266294"),
     SDouble("0.000072337962962962962962962962962963"),
     SDouble("0.000064"),
     SDouble("0.0000568957669549385525716886663632226"),
     SDouble("0.0000508052634252908601331097901742621"),
     SDouble("0.0000455539358600583090379008746355685"),
     SDouble("0.0000410020911066464389683873877567756"),
     SDouble("0.000037037037037037037037037037037037"),
     SDouble("0.0000335671847202175153569870094995133"),
     SDouble("0.000030517578125"),
     SDouble("0.00002782647410746584300303308567771378"),
     SDouble("0.00002544270303277020150620801953999593"),
     SDouble("0.00002332361516034985422740524781341108"),
     SDouble("0.0000214334705075445816186556927297668"),
     SDouble("0.00001974216729512565889483347481886562"),
     SDouble("0.00001822423093745443942265636390144336"),
     SDouble("0.00001685800502368549705827812336688076"),
     SDouble("0.000015625"),
     SDouble("0.00001450936579562107340288156004701035"),
     SDouble("0.00001349746247705431378900766655868697"),
     SDouble("0.00001257750889858754575068861861219767"),
     SDouble("0.0000117392937640871525169045830202855"),
     SDouble("0.0000109739368998628257887517146776406"),
     SDouble("0.00001027369113174981507355962850332868"),
     SDouble("9.63177715920364466447704265914104e-6"),
     SDouble("9.04224537037037037037037037037037e-6"),
     SDouble("8.49985975231408681756751013608275e-6"),
     SDouble("8.e-6"),
     SDouble("7.53857867637635600183941319703583e-6"),
     SDouble("7.11197086936731907146108329540282e-6"),
     SDouble("6.7169542642584146644545497289709e-6"),
     SDouble("6.35065792816135751663872377178276e-6"),
     SDouble("6.01051840721262208865514650638618e-6"),
     SDouble("5.69424198250728862973760932944606e-6"),
     SDouble("5.39977212961613019930558930413137e-6"),
     SDouble("5.12526138833080487104842346959695e-6"),
     SDouble("4.86904698143432385979092312261721e-6"),
     SDouble("4.62962962962962962962962962962963e-6") };

static Double rli3s4[64] = {
     SDouble("0.25"),
     SDouble("60."),
     SDouble("1.138935590953552264079306462206453"),
     SDouble("0.2584613957965733052880001298736726"),
     SDouble("1.070610556330930427676735313951246"),
     SDouble("0.1602354669523865641602814200481268"),
     SDouble("0.0596522041968614917764690381597247"),
     SDouble("0.0323350071214827174480057541298852"),
     SDouble("0.0215268553343928069326894675547239"),
     SDouble("0.01631265084505647980227993638470218"),
     SDouble("0.01351170727855730686524801829604374"),
     SDouble("0.01194166984164260854485986468792134"),
     SDouble("0.01108808445554238166943477333109527"),
     SDouble("0.0107029428711689125163368503788985"),
     SDouble("0.01065977098738328728859764913283541"),
     SDouble("0.01089413354460406536739294174720872"),
     SDouble("0.01137684196290741969952913890665615"),
     SDouble("0.0121011583482348462644911218539625"),
     SDouble("0.01307659624681051733453914236557704"),
     SDouble("0.01432613865353702312570787668250772"),
     SDouble("0.01588542608703234710893304385477436"),
     SDouble("0.0178032411007251952250774393028556"),
     SDouble("0.02014299105670971568662031816319187"),
     SDouble("0.02298509179731970808109877399397628"),
     SDouble("0.02643027696014330648138997750155348"),
     SDouble("0.03060394547055003325647893191553593"),
     SDouble("0.035661735608380585256187676570772"),
     SDouble("0.0417965907377202124046444018729032"),
     SDouble("0.0492476679219910617190984786846063"),
     SDouble("0.0583115433382267066849886726599019"),
     SDouble("0.0693562947065088615998164118723245"),
     SDouble("0.0828391987615438870498071161174552"),
     SDouble("0.0993289805782151349926828463499112"),
     SDouble("0.1195338030509537960261681935772096"),
     SDouble("0.1443365037885458935297242981611015"),
     SDouble("0.1748389918669661045551933619028474"),
     SDouble("0.2124182321660636906997376987475917"),
     SDouble("0.2587969008948406167747859414849395"),
     SDouble("0.3161326313678809486404941883460194"),
     SDouble("0.387130834012482766835967817323844"),
     SDouble("0.475187432828535881344900789449587"),
     SDouble("0.584569593911706715423732112406567"),
     SDouble("0.720644735060850009269785874908142"),
     SDouble("0.890170933414894858300324359742701"),
     SDouble("1.101665463053812504517406772274432"),
     SDouble("1.365872818030909675952884850620426"),
     SDouble("1.696359492781173455377823678984493"),
     SDouble("2.110270366628489156855336665124357"),
     SDouble("2.629291241740224031426914311905221"),
     SDouble("3.28087451804580056943950174535497"),
     SDouble("4.09980093082211694763429641234838"),
     SDouble("5.13017072594778984754837483090598"),
     SDouble("6.42794389026929701587559256159515"),
     SDouble("8.06418274609244469939216759822727"),
     SDouble("10.12919349266613745623731894502107"),
     SDouble("12.73781888246401168214257973086751"),
     SDouble("16.03620569947336609486204857396681"),
     SDouble("20.21046262979290476007619382770105"),
     SDouble("25.49774237567921543004649141192089"),
     SDouble("32.2004340683276525293750252642113"),
     SDouble("40.7043479993849544261839477735578"),
     SDouble("51.5020270926591664254769080674608"),
     SDouble("65.2226447485694157670420268606118"),
     SDouble("82.6703678686616107329863006118874") };

#define LI2MAXREAL 0.4
#define LI2SERIESN 14  // number of defined series
#define RLI2SERIESN 4  // number of defined series

Cplx li2(Double x)  // x with infinitesimal negative imag. part
{
  if (x==Double(1)) return(PiSonSix);
  Cplx l;
  if (x>1.) { l=log(x)+PiI; return(-li2(1/x)-PiSonSix-.5*l*l); }; 
  if (x<-1.) { l=log(-x); return(-li2(1/x)-PiSonSix-.5*l*l); }; 
  if (x>.51) return(-li2(1-x)+PiSonSix-log(x)*log(1-x));
  if (x>LI2MAXREAL) return(-li2(-x)+.5*li2(x*x));
  Double *li2seriesdata[RLI2SERIESN];
  li2seriesdata[0]=rli2s1;
  li2seriesdata[1]=rli2s2;
  li2seriesdata[2]=rli2s3;
  li2seriesdata[3]=rli2s4;
  return(multiseries(x,li2seriesdata,RLI2SERIESN));
}

// added by A.F. 29.1.02:
Double li2r(Double x)  // dito, but only return real part
{
  if (x==Double(1)) return(PiSonSix);
  Double l;
  if (x>1.) { l=log(x); return(-li2r(1/x)+PiSonThree-.5*l*l); }; 
  if (x<-1.) { l=log(-x); return(-li2r(1/x)-PiSonSix-.5*l*l); }; 
  if (x>.51) return(-li2r(1-x)+PiSonSix-log(x)*log(1-x));
  if (x>LI2MAXREAL) return(-li2r(-x)+.5*li2r(x*x));
  Double *li2seriesdata[RLI2SERIESN];
  li2seriesdata[0]=rli2s1;
  li2seriesdata[1]=rli2s2;
  li2seriesdata[2]=rli2s3;
  li2seriesdata[3]=rli2s4;
  return(multiseries(x,li2seriesdata,RLI2SERIESN));
}


Cplx li2(Cplx x)
{
  if (imag(x)==Double(0)) return(li2(real(x)));
  Cplx l;
  if (abs(x)>NUMUNIT) { l=log(-x); return(-li2(1/x)-PiSonSix-.5*l*l); };
  if (real(x)>.51) return(-li2(1-x)+PiSonSix-log(x)*log(1-x));
  if (real(x)>LI2MAXREAL) return(-li2(-x)+.5*li2(x*x));
  Cplx *li2seriesdata[LI2SERIESN];
  li2seriesdata[0]=li2s1;
  li2seriesdata[1]=li2s2;
  li2seriesdata[2]=li2s3;
  li2seriesdata[3]=li2s4;
  li2seriesdata[4]=li2s5;
  li2seriesdata[5]=li2s6;
  li2seriesdata[6]=li2s7;
  li2seriesdata[7]=li2s8;
  li2seriesdata[8]=li2s9;
  li2seriesdata[9]=li2s10;
  li2seriesdata[10]=li2s11;
  li2seriesdata[11]=li2s12;
  li2seriesdata[12]=li2s13;
  li2seriesdata[13]=li2s14;
  return(multiseries(x,li2seriesdata,LI2SERIESN));
}


#define LI3MAXREAL .4
#define LI3LIMIT1 .5 // not yet well adjusted

static const Double LI3_1=SDouble("1.20205690315959428539973816151145");

Cplx li3(Double x)  // x with infinitesimal negative imag. part
{
  if (x==Double(1.)) return(LI3_1);
  Cplx l;
  if (x>1.) {
    l=log(x)+PiI;
    return(li3(1/x)-(PiSonSix+l*l/6)*l);
  };
  if (x<-1.) {
    l=log(-x);
    return(li3(1/x)-(PiSonSix+l*l/6)*l);
  };
  if (x>LI3LIMIT1) {
    l=log(x);
    return(-li3(1-x)-li3(1-1/x)+LI3_1
           +(PiSonSix+(l/6-.5*log(1-x))*l)*l);
  };
  if (x>LI3MAXREAL) return(-li3(-x)+.25*li3(x*x));
  Double *li3seriesdata[RLI2SERIESN];
  li3seriesdata[0]=rli3s1;
  li3seriesdata[1]=rli3s2;
  li3seriesdata[2]=rli3s3;
  li3seriesdata[3]=rli3s4;
  return(multiseries(x,li3seriesdata,RLI2SERIESN));
}

Cplx li3(Cplx x)
{
  if (imag(x)==Double(0)) return(li3(real(x)));
  Cplx l;
  if (abs(x)>NUMUNIT) {
    l=log(-x);
    return(li3(1/x)-(PiSonSix+l*l/6)*l);
  };
  if (real(x)>LI3LIMIT1) {
    l=log(x);
    return(-li3(1-x)-li3(1-1/x)+LI3_1
           +(PiSonSix+(l/6-.5*log(1-x))*l)*l);
  };
  if (real(x)>LI3MAXREAL) return(-li3(-x)+.25*li3(x*x));
  Cplx *li3seriesdata[LI2SERIESN];
  li3seriesdata[0]=li3s1;
  li3seriesdata[1]=li3s2;
  li3seriesdata[2]=li3s3;
  li3seriesdata[3]=li3s4;
  li3seriesdata[4]=li3s5;
  li3seriesdata[5]=li3s6;
  li3seriesdata[6]=li3s7;
  li3seriesdata[7]=li3s8;
  li3seriesdata[8]=li3s9;
  li3seriesdata[9]=li3s10;
  li3seriesdata[10]=li3s11;
  li3seriesdata[11]=li3s12;
  li3seriesdata[12]=li3s13;
  li3seriesdata[13]=li3s14;
  return(multiseries(x,li3seriesdata,LI2SERIESN));
}

Cplx li2c(Double x) // infinitesimal positive imag. part
{ return(conj(li2(x))); }

Cplx li3c(Double x) // infinitesimal positive imag. part
{ return(conj(li3(x))); }
